
if {![info exists vTcl(sourcing)]} {

    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#


#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    foreach {cmd name newname} [lrange $args 0 2] {}
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- [string tolower $command] {
        "setvar" {
            foreach {varname value} $args {}
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "show" {
            Window [string tolower $command] $w
        }
        "showmodal" {
            ## modal dialog ends when window is destroyed
            Window show $w; raise $w
            grab $w; tkwait window $w; grab release $w
        }
        "startmodal" {
            ## ends when endmodal called
            Window show $w; raise $w
            set ::${w}::_modal 1
            grab $w; tkwait variable ::${w}::_modal; grab release $w
        }
        "endmodal" {
            ## ends modal dialog started with startmodal, argument is var name
            set ::${w}::_modal 0
            Window hide $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }

    set command [lindex $args 0]
    set args [lrange $args 1 end]
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {set _modal 0}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top17
    namespace eval ::widgets::$base {
        set set,origin 0
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.cpd19 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_3_0 $base.cpd19
    namespace eval ::widgets::$site_3_0.01 {
        array set save {-activebackground 1 -activeforeground 1 -anchor 1 -background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -menu 1 -padx 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.01.02 {
        array set save {-activebackground 1 -activeborderwidth 1 -activeforeground 1 -background 1 -borderwidth 1 -cursor 1 -font 1 -foreground 1 -tearoff 1}
    }
    namespace eval ::widgets::$site_3_0.men20 {
        array set save {-activebackground 1 -activeforeground 1 -anchor 1 -background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -menu 1 -padx 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.men20.01 {
        array set save {-activebackground 1 -activeborderwidth 1 -activeforeground 1 -background 1 -borderwidth 1 -cursor 1 -font 1 -foreground 1 -tearoff 1}
        namespace eval subOptions {
            array set save {-accelerator 1 -command 1 -label 1 -variable 1}
        }
    }
    namespace eval ::widgets::$site_3_0.05 {
        array set save {-activebackground 1 -activeforeground 1 -anchor 1 -background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -menu 1 -padx 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.05.06 {
        array set save {-activebackground 1 -activeborderwidth 1 -activeforeground 1 -background 1 -borderwidth 1 -cursor 1 -font 1 -foreground 1 -tearoff 1}
    }
    namespace eval ::widgets::$base.fra21 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_3_0 $base.fra21
    namespace eval ::widgets::$site_3_0.ent22 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -state 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_3_0.ent54 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -state 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.ent55 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -state 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.ent61 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -state 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$base.fra20 {
        array set save {-background 1 -borderwidth 1 -highlightbackground 1 -highlightcolor 1 -relief 1}
    }
    set site_3_0 $base.fra20
    namespace eval ::widgets::$site_3_0.cpd77 {
        array set save {-background 1 -height 1 -width 1}
    }
    set site_4_0 $site_3_0.cpd77
    namespace eval ::widgets::$site_4_0.01 {
        array set save {-background 1}
    }
    set site_5_0 $site_4_0.01
    namespace eval ::widgets::$site_5_0.cpd79 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_6_0 $site_5_0.cpd79
    namespace eval ::widgets::$site_6_0.fra29 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_7_0 $site_6_0.fra29
    namespace eval ::widgets::$site_7_0.051 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_8_0 $site_7_0.051
    namespace eval ::widgets::$site_8_0.052 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.052
    namespace eval ::widgets::$site_9_0.053 {
        array set save {-anchor 1 -background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.054 {
        array set save {-background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_8_0.059 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.059
    namespace eval ::widgets::$site_9_0.fra46 {
        array set save {-height 1 -width 1}
    }
    set site_10_0 $site_9_0.fra46
    namespace eval ::widgets::$site_10_0.lab47 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_10_0.but59 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.but30 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_9_0.061 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.062 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.062
    namespace eval ::widgets::$site_9_0.063 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.064 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_7_0.01 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_8_0 $site_7_0.01
    namespace eval ::widgets::$site_8_0.02 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.02
    namespace eval ::widgets::$site_9_0.03 {
        array set save {-anchor 1 -background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.04 {
        array set save {-background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_8_0.05 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.05
    namespace eval ::widgets::$site_9_0.06 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.06
    namespace eval ::widgets::$site_10_0.07 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -disabledforeground 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -pady 1 -state 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.09 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.09
    namespace eval ::widgets::$site_10_0.011 {
        array set save {-background 1 -highlightbackground 1 -highlightcolor 1}
    }
    namespace eval ::widgets::$site_10_0.fra21 {
        array set save {-background 1 -borderwidth 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::$site_10_0.fra19 {
        array set save {-background 1 -highlightbackground 1 -highlightcolor 1}
    }
    namespace eval ::widgets::$site_8_0.012 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.012
    namespace eval ::widgets::$site_9_0.fra17 {
        array set save {-height 1 -width 1}
    }
    set site_10_0 $site_9_0.fra17
    namespace eval ::widgets::$site_10_0.lab18 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_10_0.but48 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.but22 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_9_0.014 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.015 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.015
    namespace eval ::widgets::$site_9_0.016 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.017 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.018 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.018
    namespace eval ::widgets::$site_9_0.019 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.019
    namespace eval ::widgets::$site_10_0.fra19 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra19
    namespace eval ::widgets::$site_11_0.lab35 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but50 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but20 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.021 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.022 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.022
    namespace eval ::widgets::$site_10_0.fra30 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra30
    namespace eval ::widgets::$site_11_0.lab36 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but51 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but21 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.024 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.025 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.025
    namespace eval ::widgets::$site_10_0.fra26 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra26
    namespace eval ::widgets::$site_11_0.lab37 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but52 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but22 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.027 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.028 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.028
    namespace eval ::widgets::$site_9_0.029 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.029
    namespace eval ::widgets::$site_10_0.fra27 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra27
    namespace eval ::widgets::$site_11_0.lab38 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but53 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but23 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.031 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.032 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.032
    namespace eval ::widgets::$site_10_0.fra28 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra28
    namespace eval ::widgets::$site_11_0.lab39 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but54 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but24 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.034 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.035 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.035
    namespace eval ::widgets::$site_10_0.fra29 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra29
    namespace eval ::widgets::$site_11_0.lab40 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but55 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but25 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.037 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.038 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.038
    namespace eval ::widgets::$site_9_0.039 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.039
    namespace eval ::widgets::$site_10_0.fra31 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra31
    namespace eval ::widgets::$site_11_0.lab41 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but56 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but26 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.041 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.042 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.042
    namespace eval ::widgets::$site_10_0.fra32 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra32
    namespace eval ::widgets::$site_11_0.lab42 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but57 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but27 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.044 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.045 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.045
    namespace eval ::widgets::$site_10_0.fra33 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra33
    namespace eval ::widgets::$site_11_0.lab43 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but58 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but28 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.047 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.048 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.048
    namespace eval ::widgets::$site_9_0.fra34 {
        array set save {-height 1 -width 1}
    }
    set site_10_0 $site_9_0.fra34
    namespace eval ::widgets::$site_10_0.lab44 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_10_0.but60 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.but29 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_9_0.050 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_4_0.02 {
        array set save {-background 1}
    }
    set site_5_0 $site_4_0.02
    namespace eval ::widgets::$site_5_0.cpd78 {
        array set save {-background 1 -highlightbackground 1 -highlightcolor 1}
    }
    set site_6_0 $site_5_0.cpd78
    namespace eval ::widgets::$site_6_0.fra28 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_7_0 $site_6_0.fra28
    namespace eval ::widgets::$site_7_0.fra17 {
        array set save {-height 1 -width 1}
    }
    set site_8_0 $site_7_0.fra17
    namespace eval ::widgets::$site_8_0.but19 {
        array set save {-command 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets::$site_8_0.but18 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -disabledforeground 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -pady 1 -state 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_8_0.but20 {
        array set save {-command 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets::$site_7_0.cpd31 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_8_0 $site_7_0.cpd31
    namespace eval ::widgets::$site_8_0.01 {
        array set save {-background 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$site_8_0.02 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -orient 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::$site_8_0.03 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::$site_6_0.fra17 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_7_0 $site_6_0.fra17
    namespace eval ::widgets::$site_7_0.rad23 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_7_0.cpd71 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_7_0.rad24 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_7_0.rad25 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_6_0.cpd73 {
        array set save {-background 1 -borderwidth 1 -closeenough 1 -height 1 -relief 1}
    }
    namespace eval ::widgets::$site_6_0.fra18 {
        array set save {-height 1 -width 1}
    }
    set site_7_0 $site_6_0.fra18
    namespace eval ::widgets::$site_7_0.ent19 {
        array set save {-textvariable 1}
    }
    namespace eval ::widgets::$site_7_0.but20 {
        array set save {-borderwidth 1 -command 1 -highlightthickness 1 -padx 1 -pady 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_4_0.03 {
        array set save {-background 1 -borderwidth 1 -relief 1}
    }
    set base .top71
    namespace eval ::widgets::$base {
        set set,origin 1
        set set,size 1
        set runvisible 0
    }
    namespace eval ::widgets::$base.fra72 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_3_0 $base.fra72
    namespace eval ::widgets::$site_3_0.lab75 {
        array set save {-background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$base.fra73 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_3_0 $base.fra73
    namespace eval ::widgets::$site_3_0.but74 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -pady 1 -text 1 -textvariable 1}
    }
    set base .top17.fra20.cpd77
    namespace eval ::widgets::$base {
    }
    namespace eval ::widgets::$base.01 {
        array set save {-background 1}
    }
    set site_5_0 $base.01
    namespace eval ::widgets::$site_5_0.cpd79 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_6_0 $site_5_0.cpd79
    namespace eval ::widgets::$site_6_0.fra29 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_7_0 $site_6_0.fra29
    namespace eval ::widgets::$site_7_0.051 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_8_0 $site_7_0.051
    namespace eval ::widgets::$site_8_0.052 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.052
    namespace eval ::widgets::$site_9_0.053 {
        array set save {-anchor 1 -background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.054 {
        array set save {-background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_8_0.059 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.059
    namespace eval ::widgets::$site_9_0.fra46 {
        array set save {-height 1 -width 1}
    }
    set site_10_0 $site_9_0.fra46
    namespace eval ::widgets::$site_10_0.lab47 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_10_0.but59 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.but30 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_9_0.061 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.062 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.062
    namespace eval ::widgets::$site_9_0.063 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.064 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_7_0.01 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_8_0 $site_7_0.01
    namespace eval ::widgets::$site_8_0.02 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.02
    namespace eval ::widgets::$site_9_0.03 {
        array set save {-anchor 1 -background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.04 {
        array set save {-background 1 -borderwidth 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_8_0.05 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.05
    namespace eval ::widgets::$site_9_0.06 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.06
    namespace eval ::widgets::$site_10_0.07 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -disabledforeground 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -pady 1 -state 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.09 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.09
    namespace eval ::widgets::$site_10_0.011 {
        array set save {-background 1 -highlightbackground 1 -highlightcolor 1}
    }
    namespace eval ::widgets::$site_10_0.fra21 {
        array set save {-background 1 -borderwidth 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::$site_10_0.fra19 {
        array set save {-background 1 -highlightbackground 1 -highlightcolor 1}
    }
    namespace eval ::widgets::$site_8_0.012 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.012
    namespace eval ::widgets::$site_9_0.fra17 {
        array set save {-height 1 -width 1}
    }
    set site_10_0 $site_9_0.fra17
    namespace eval ::widgets::$site_10_0.lab18 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_10_0.but48 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.but22 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_9_0.014 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.015 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.015
    namespace eval ::widgets::$site_9_0.016 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_9_0.017 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.018 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.018
    namespace eval ::widgets::$site_9_0.019 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.019
    namespace eval ::widgets::$site_10_0.fra19 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra19
    namespace eval ::widgets::$site_11_0.lab35 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but50 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but20 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.021 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.022 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.022
    namespace eval ::widgets::$site_10_0.fra30 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra30
    namespace eval ::widgets::$site_11_0.lab36 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but51 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but21 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.024 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.025 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.025
    namespace eval ::widgets::$site_10_0.fra26 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra26
    namespace eval ::widgets::$site_11_0.lab37 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but52 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but22 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.027 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.028 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.028
    namespace eval ::widgets::$site_9_0.029 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.029
    namespace eval ::widgets::$site_10_0.fra27 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra27
    namespace eval ::widgets::$site_11_0.lab38 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but53 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but23 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.031 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.032 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.032
    namespace eval ::widgets::$site_10_0.fra28 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra28
    namespace eval ::widgets::$site_11_0.lab39 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but54 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but24 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.034 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.035 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.035
    namespace eval ::widgets::$site_10_0.fra29 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra29
    namespace eval ::widgets::$site_11_0.lab40 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but55 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but25 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.037 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.038 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.038
    namespace eval ::widgets::$site_9_0.039 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.039
    namespace eval ::widgets::$site_10_0.fra31 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra31
    namespace eval ::widgets::$site_11_0.lab41 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but56 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but26 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.041 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.042 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.042
    namespace eval ::widgets::$site_10_0.fra32 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra32
    namespace eval ::widgets::$site_11_0.lab42 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but57 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but27 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.044 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_9_0.045 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_10_0 $site_9_0.045
    namespace eval ::widgets::$site_10_0.fra33 {
        array set save {-height 1 -width 1}
    }
    set site_11_0 $site_10_0.fra33
    namespace eval ::widgets::$site_11_0.lab43 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_11_0.but58 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_11_0.but28 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.047 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$site_8_0.048 {
        array set save {-background 1 -height 1 -highlightbackground 1 -highlightcolor 1 -width 1}
    }
    set site_9_0 $site_8_0.048
    namespace eval ::widgets::$site_9_0.fra34 {
        array set save {-height 1 -width 1}
    }
    set site_10_0 $site_9_0.fra34
    namespace eval ::widgets::$site_10_0.lab44 {
        array set save {-background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_10_0.but60 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_10_0.but29 {
        array set save {-borderwidth 1 -highlightthickness 1 -padx 1 -pady 1}
    }
    namespace eval ::widgets::$site_9_0.050 {
        array set save {-background 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -width 1 -wrap 1}
    }
    namespace eval ::widgets::$base.02 {
        array set save {-background 1}
    }
    set site_5_0 $base.02
    namespace eval ::widgets::$site_5_0.cpd78 {
        array set save {-background 1 -highlightbackground 1 -highlightcolor 1}
    }
    set site_6_0 $site_5_0.cpd78
    namespace eval ::widgets::$site_6_0.fra28 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_7_0 $site_6_0.fra28
    namespace eval ::widgets::$site_7_0.fra17 {
        array set save {-height 1 -width 1}
    }
    set site_8_0 $site_7_0.fra17
    namespace eval ::widgets::$site_8_0.but19 {
        array set save {-command 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets::$site_8_0.but18 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -disabledforeground 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -pady 1 -state 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_8_0.but20 {
        array set save {-command 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets::$site_7_0.cpd31 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_8_0 $site_7_0.cpd31
    namespace eval ::widgets::$site_8_0.01 {
        array set save {-background 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$site_8_0.02 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -orient 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::$site_8_0.03 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::$site_6_0.fra17 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    set site_7_0 $site_6_0.fra17
    namespace eval ::widgets::$site_7_0.rad23 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_7_0.cpd71 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_7_0.rad24 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_7_0.rad25 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -textvariable 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_6_0.cpd73 {
        array set save {-background 1 -borderwidth 1 -closeenough 1 -height 1 -relief 1}
    }
    namespace eval ::widgets::$site_6_0.fra18 {
        array set save {-height 1 -width 1}
    }
    set site_7_0 $site_6_0.fra18
    namespace eval ::widgets::$site_7_0.ent19 {
        array set save {-textvariable 1}
    }
    namespace eval ::widgets::$site_7_0.but20 {
        array set save {-borderwidth 1 -command 1 -highlightthickness 1 -padx 1 -pady 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$base.03 {
        array set save {-background 1 -borderwidth 1 -relief 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist _TopLevel
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
            vTclWindow.
            vTclWindow.top17
            vTclWindow.top71
        }
        set compounds {
        }
        set projectType single
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {

}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {

}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 200x200+66+66; update
    wm maxsize $top 1028 753
    wm minsize $top 104 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl"
    bindtags $top "$top Vtcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top17 {base} {
    if {$base == ""} {
        set base .top17
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -background #dcdcdc -highlightbackground #dcdcdc \
        -highlightcolor #000000 
    wm focusmodel $top passive
    wm geometry $top [expr [winfo screenwidth .]-0]x[expr [winfo screenheight .]-50]+0+0; update
#    wm maxsize $top 1028 753
    wm minsize $top 115 115
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm deiconify $top
    wm title $top "Wizard of Oz - Session"
    vTcl:DefineAlias "$top" "main" vTcl:Toplevel:WidgetProc "" 0
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    frame $top.cpd19 \
        -borderwidth 1 -relief sunken -background #dcdcdc -height 30 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 30 
    set site_3_0 $top.cpd19
    menubutton $site_3_0.01 \
        -activebackground #dcdcdc -activeforeground #000000 -anchor w \
        -background #dcdcdc -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -menu "$site_3_0.01.02" -padx 4 -pady 3 \
        -text Datei 
    vTcl:DefineAlias "$site_3_0.01" "mm_file" vTcl:WidgetProc "main" 0
    menu $site_3_0.01.02 \
        -activebackground #dcdcdc -activeborderwidth 1 \
        -activeforeground #000000 -background #dcdcdc -borderwidth 1 \
        -cursor {} -font {Tahoma 8} -foreground #000000 -tearoff 0 
    vTcl:DefineAlias "$site_3_0.01.02" "m_file" vTcl:WidgetProc "" 0
    $site_3_0.01.02 add command \
        -command {menuCommand file,exit} -label Beenden 
    menubutton $site_3_0.men20 \
        -activebackground #dcdcdc -activeforeground #000000 -anchor w \
        -background #dcdcdc -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -menu "$site_3_0.men20.01" -padx 4 -pady 3 \
        -text Ausfhren 
    vTcl:DefineAlias "$site_3_0.men20" "mm_run" vTcl:WidgetProc "main" 0
    menu $site_3_0.men20.01 \
        -activebackground #dcdcdc -activeborderwidth 1 \
        -activeforeground #000000 -background #dcdcdc -borderwidth 1 \
        -cursor {} -font {Tahoma 8} -foreground #000000 -tearoff 0 
    vTcl:DefineAlias "$site_3_0.men20.01" "m_run" vTcl:WidgetProc "" 0
    $site_3_0.men20.01 add command \
        -accelerator F2 -command {menuCommand run,restart} -label Neustart 
    $site_3_0.men20.01 add separator \
        
    $site_3_0.men20.01 add command \
        -accelerator <Delete> -command {menuCommand run,undo} -label Zurck 
    $site_3_0.men20.01 add command \
        -accelerator <Insert> -command {menuCommand run,redo} -label Vorwrts 
    $site_3_0.men20.01 add separator \
        
    $site_3_0.men20.01 add checkbutton \
        -variable plugin(restrictive) -accelerator {} \
        -command {menuCommand run,restart} -label Restriktiv 
    $site_3_0.men20.01 add checkbutton \
        -variable plugin(exc) -accelerator {} -command {} -label Ausnahmen 
    $site_3_0.men20.01 add checkbutton \
        -variable plugin(autoplay) -accelerator {} -command {} \
        -label Autoplay 
    $site_3_0.men20.01 add checkbutton \
        -variable plugin(autostop) -accelerator {} -command {} \
        -label Autostop 
    $site_3_0.men20.01 add separator \
        
    $site_3_0.men20.01 add checkbutton \
        -variable var(tts) -accelerator {} -command {} -label Textsynthese 
    menubutton $site_3_0.05 \
        -activebackground #dcdcdc -activeforeground #000000 -anchor w \
        -background #dcdcdc -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -menu "$site_3_0.05.06" -padx 4 -pady 3 \
        -text Hilfe 
    vTcl:DefineAlias "$site_3_0.05" "mm_help" vTcl:WidgetProc "main" 0
    menu $site_3_0.05.06 \
        -activebackground #dcdcdc -activeborderwidth 1 \
        -activeforeground #000000 -background #dcdcdc -borderwidth 1 \
        -cursor {} -font {Tahoma 8} -foreground #000000 -tearoff 0 
    vTcl:DefineAlias "$site_3_0.05.06" "m_help" vTcl:WidgetProc "" 0
    $site_3_0.05.06 add command \
        -accelerator F1 -command {menuCommand help,about} -label ber 
    pack $site_3_0.01 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.men20 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.05 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    frame $top.fra21 \
        -borderwidth 1 -background #dcdcdc -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 125 
    set site_3_0 $top.fra21
    entry $site_3_0.ent22 \
        -background #c0c0c0 -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff -state disabled -textvariable status(msg) 
    vTcl:DefineAlias "$site_3_0.ent22" "status,bar" vTcl:WidgetProc "main" 0
    entry $site_3_0.ent54 \
        -background #c0c0c0 -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff -state disabled -textvariable status(turns) \
        -width 10 
    entry $site_3_0.ent55 \
        -background #c0c0c0 -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff -state disabled -textvariable status(time) \
        -width 10 
    entry $site_3_0.ent61 \
        -background #c0c0c0 -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff -state disabled -textvariable status(date) \
        -width 25 
    pack $site_3_0.ent22 \
        -in $site_3_0 -anchor center -expand 1 -fill x -side left 
    pack $site_3_0.ent54 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.ent55 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.ent61 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    frame $top.fra20 \
        -borderwidth 1 -relief sunken -background #dcdcdc \
        -highlightbackground #dcdcdc -highlightcolor #000000 
    set site_3_0 $top.fra20
    frame $site_3_0.cpd77 \
        -background #000000 -height 100 -width 200 
    vTcl:DefineAlias "$site_3_0.cpd77" "Frame4" vTcl:WidgetProc "main" 0
    set site_4_0 $site_3_0.cpd77
    frame $site_4_0.01 \
        -background #9900991B99FE 
    vTcl:DefineAlias "$site_4_0.01" "Frame1" vTcl:WidgetProc "main" 0
    set site_5_0 $site_4_0.01
    frame $site_5_0.cpd79 \
        -borderwidth 1 -relief groove -background #dcdcdc -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 125 
    set site_6_0 $site_5_0.cpd79
    frame $site_6_0.fra29 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    vTcl:DefineAlias "$site_6_0.fra29" "area" vTcl:WidgetProc "main" 0
    set site_7_0 $site_6_0.fra29
    frame $site_7_0.051 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    vTcl:DefineAlias "$site_7_0.051" "p" vTcl:WidgetProc "main" 0
    set site_8_0 $site_7_0.051
    frame $site_8_0.052 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.052
    label $site_9_0.053 \
        -anchor w -background #dec8de -borderwidth 1 \
        -font {helvetica 24 bold} -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text Prompt -textvariable label(opt,p_header) 
    label $site_9_0.054 \
        -background #c69fc6 -borderwidth 1 -font {helvetica 12 bold} \
        -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -textvariable curobj(p_title) 
    pack $site_9_0.053 \
        -in $site_9_0 -anchor center -expand 1 -fill x -side left 
    pack $site_9_0.054 \
        -in $site_9_0 -anchor center -expand 0 -fill both -ipadx 20 \
        -side left 
    frame $site_8_0.059 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.059
    frame $site_9_0.fra46 \
        -height 75 -width 125 
    vTcl:DefineAlias "$site_9_0.fra46" "label,p_prompt" vTcl:WidgetProc "main" 0
    set site_10_0 $site_9_0.fra46
    label $site_10_0.lab47 \
        -background #ddff78 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text Prompt-Text -textvariable label(opt,p_prompt) 
    vTcl:DefineAlias "$site_10_0.lab47" "label,p_prompt" vTcl:WidgetProc "main" 0
    button $site_10_0.but59 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_10_0.but59" "ls,p_prompt" vTcl:WidgetProc "main" 0
    button $site_10_0.but30 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_10_0.but30" "stop,p_prompt" vTcl:WidgetProc "main" 0
    pack $site_10_0.lab47 \
        -in $site_10_0 -anchor center -expand 1 -fill x -side left 
    pack $site_10_0.but59 \
        -in $site_10_0 -anchor center -expand 0 -fill none -side left 
    pack $site_10_0.but30 \
        -in $site_10_0 -anchor center -expand 0 -fill none -side left 
    text $site_9_0.061 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_9_0.061" "p_prompt" vTcl:WidgetProc "main" 0
    pack $site_9_0.fra46 \
        -in $site_9_0 -anchor center -expand 0 -fill x -side top 
    pack $site_9_0.061 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side top 
    frame $site_8_0.062 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.062
    label $site_9_0.063 \
        -background #ddff78 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text Kommentar -textvariable label(opt,p_memo) 
    vTcl:DefineAlias "$site_9_0.063" "label,p_memo" vTcl:WidgetProc "main" 0
    text $site_9_0.064 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_9_0.064" "p_memo" vTcl:WidgetProc "main" 0
    pack $site_9_0.063 \
        -in $site_9_0 -anchor center -expand 0 -fill x -side top 
    pack $site_9_0.064 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.052 \
        -in $site_8_0 -anchor center -expand 0 -fill x -side top 
    pack $site_8_0.059 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.062 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    frame $site_7_0.01 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    vTcl:DefineAlias "$site_7_0.01" "q" vTcl:WidgetProc "main" 0
    set site_8_0 $site_7_0.01
    frame $site_8_0.02 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.02
    label $site_9_0.03 \
        -anchor w -background #dec8de -borderwidth 1 \
        -font {helvetica 24 bold} -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text Frage -textvariable label(opt,q_header) 
    label $site_9_0.04 \
        -background #c69fc6 -borderwidth 1 -font {helvetica 12 bold} \
        -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -textvariable curobj(q_title) 
    pack $site_9_0.03 \
        -in $site_9_0 -anchor center -expand 1 -fill x -side left 
    pack $site_9_0.04 \
        -in $site_9_0 -anchor center -expand 0 -fill both -ipadx 20 \
        -side left 
    frame $site_8_0.05 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.05
    frame $site_9_0.06 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.06
    button $site_10_0.07 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #c69fc6 \
        -command {set curobj(q_concepts) [dia::chooseCmulti $curobj(q_concepts)]} \
        -disabledforeground #000040 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -pady 0 \
        -state disabled -text {Verstandene Konzepte} \
        -textvariable label(opt,q_concepts) 
    pack $site_10_0.07 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    frame $site_9_0.09 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.09
    frame $site_10_0.011 \
        -background #dcdcdc -highlightbackground #dcdcdc \
        -highlightcolor #000000 
    vTcl:DefineAlias "$site_10_0.011" "q_concepts_alw" vTcl:WidgetProc "main" 0
    frame $site_10_0.fra21 \
        -borderwidth 2 -relief raised -background #c69fc6 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 10 
    frame $site_10_0.fra19 \
        -background #dcdcdc -highlightbackground #dcdcdc \
        -highlightcolor #000000 
    vTcl:DefineAlias "$site_10_0.fra19" "q_concepts" vTcl:WidgetProc "main" 0
    pack $site_10_0.011 \
        -in $site_10_0 -anchor center -expand 0 -fill both -side left 
    pack $site_10_0.fra21 \
        -in $site_10_0 -anchor center -expand 0 -fill both -side left 
    pack $site_10_0.fra19 \
        -in $site_10_0 -anchor center -expand 0 -fill both -side left 
    pack $site_9_0.06 \
        -in $site_9_0 -anchor center -expand 0 -fill none -side left 
    pack $site_9_0.09 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    frame $site_8_0.012 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.012
    frame $site_9_0.fra17 \
        -height 75 -width 125 
    set site_10_0 $site_9_0.fra17
    label $site_10_0.lab18 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {Initiales Prompt} -textvariable label(opt,q_init) 
    vTcl:DefineAlias "$site_10_0.lab18" "label,q_init" vTcl:WidgetProc "main" 0
    button $site_10_0.but48 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_10_0.but48" "ls,q_init" vTcl:WidgetProc "main" 0
    button $site_10_0.but22 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_10_0.but22" "stop,q_init" vTcl:WidgetProc "main" 0
    pack $site_10_0.lab18 \
        -in $site_10_0 -anchor center -expand 1 -fill x -side left 
    pack $site_10_0.but48 \
        -in $site_10_0 -anchor center -expand 0 -fill none -side left 
    pack $site_10_0.but22 \
        -in $site_10_0 -anchor center -expand 0 -fill none -side left 
    text $site_9_0.014 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_9_0.014" "q_init" vTcl:WidgetProc "main" 0
    pack $site_9_0.fra17 \
        -in $site_9_0 -anchor center -expand 0 -fill x -side top 
    pack $site_9_0.014 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side top 
    frame $site_8_0.015 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.015
    label $site_9_0.016 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text Kommentar -textvariable label(opt,q_memo) 
    vTcl:DefineAlias "$site_9_0.016" "label,q_memo" vTcl:WidgetProc "main" 0
    text $site_9_0.017 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_9_0.017" "q_memo" vTcl:WidgetProc "main" 0
    pack $site_9_0.016 \
        -in $site_9_0 -anchor center -expand 0 -fill x -side top 
    pack $site_9_0.017 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side top 
    frame $site_8_0.018 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.018
    frame $site_9_0.019 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.019
    frame $site_10_0.fra19 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra19
    label $site_11_0.lab35 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {NV 1} -textvariable label(opt,q_nu1) 
    vTcl:DefineAlias "$site_11_0.lab35" "label,q_nu1" vTcl:WidgetProc "main" 0
    button $site_11_0.but50 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but50" "ls,q_nu1" vTcl:WidgetProc "main" 0
    button $site_11_0.but20 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but20" "stop,q_nu1" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab35 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but50 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but20 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.021 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.021" "q_nu1" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra19 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.021 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    frame $site_9_0.022 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.022
    frame $site_10_0.fra30 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra30
    label $site_11_0.lab36 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {NV 2} -textvariable label(opt,q_nu2) 
    vTcl:DefineAlias "$site_11_0.lab36" "label,q_nu2" vTcl:WidgetProc "main" 0
    button $site_11_0.but51 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but51" "ls,q_nu2" vTcl:WidgetProc "main" 0
    button $site_11_0.but21 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but21" "stop,q_nu2" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab36 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but51 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but21 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.024 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.024" "q_nu2" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra30 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.024 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    frame $site_9_0.025 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.025
    frame $site_10_0.fra26 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra26
    label $site_11_0.lab37 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {NV 3} -textvariable label(opt,q_nu3) 
    vTcl:DefineAlias "$site_11_0.lab37" "label,q_nu3" vTcl:WidgetProc "main" 0
    button $site_11_0.but52 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but52" "ls,q_nu3" vTcl:WidgetProc "main" 0
    button $site_11_0.but22 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but22" "stop,q_nu3" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab37 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but52 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but22 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.027 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.027" "q_nu3" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra26 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.027 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    pack $site_9_0.019 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    pack $site_9_0.022 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    pack $site_9_0.025 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    frame $site_8_0.028 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.028
    frame $site_9_0.029 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.029
    frame $site_10_0.fra27 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra27
    label $site_11_0.lab38 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {NA 1} -textvariable label(opt,q_nr1) 
    vTcl:DefineAlias "$site_11_0.lab38" "label,q_nr1" vTcl:WidgetProc "main" 0
    button $site_11_0.but53 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but53" "ls,q_nr1" vTcl:WidgetProc "main" 0
    button $site_11_0.but23 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but23" "stop,q_nr1" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab38 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but53 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but23 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.031 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.031" "q_nr1" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra27 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.031 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    frame $site_9_0.032 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.032
    frame $site_10_0.fra28 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra28
    label $site_11_0.lab39 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {NA 2} -textvariable label(opt,q_nr2) 
    vTcl:DefineAlias "$site_11_0.lab39" "label,q_nr2" vTcl:WidgetProc "main" 0
    button $site_11_0.but54 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but54" "ls,q_nr2" vTcl:WidgetProc "main" 0
    button $site_11_0.but24 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but24" "stop,q_nr2" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab39 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but54 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but24 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.034 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.034" "q_nr2" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra28 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.034 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    frame $site_9_0.035 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.035
    frame $site_10_0.fra29 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra29
    label $site_11_0.lab40 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {NA 3} -textvariable label(opt,q_nr3) 
    vTcl:DefineAlias "$site_11_0.lab40" "label,q_nr3" vTcl:WidgetProc "main" 0
    button $site_11_0.but55 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but55" "ls,q_nr3" vTcl:WidgetProc "main" 0
    button $site_11_0.but25 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but25" "stop,q_nr3" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab40 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but55 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but25 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.037 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.037" "q_nr3" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra29 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.037 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    pack $site_9_0.029 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    pack $site_9_0.032 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    pack $site_9_0.035 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    frame $site_8_0.038 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.038
    frame $site_9_0.039 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.039
    frame $site_10_0.fra31 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra31
    label $site_11_0.lab41 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {ZL 1} -textvariable label(opt,q_tl1) 
    vTcl:DefineAlias "$site_11_0.lab41" "label,q_tl1" vTcl:WidgetProc "main" 0
    button $site_11_0.but56 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but56" "ls,q_tl1" vTcl:WidgetProc "main" 0
    button $site_11_0.but26 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but26" "stop,q_tl1" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab41 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but56 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but26 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.041 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.041" "q_tl1" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra31 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.041 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    frame $site_9_0.042 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.042
    frame $site_10_0.fra32 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra32
    label $site_11_0.lab42 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {ZL 2} -textvariable label(opt,q_tl2) 
    vTcl:DefineAlias "$site_11_0.lab42" "label,q_tl2" vTcl:WidgetProc "main" 0
    button $site_11_0.but57 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but57" "ls,q_tl2" vTcl:WidgetProc "main" 0
    button $site_11_0.but27 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but27" "stop,q_tl2" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab42 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but57 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but27 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.044 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.044" "q_tl2" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra32 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.044 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    frame $site_9_0.045 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_10_0 $site_9_0.045
    frame $site_10_0.fra33 \
        -height 75 -width 125 
    set site_11_0 $site_10_0.fra33
    label $site_11_0.lab43 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text {ZL 3} -textvariable label(opt,q_tl3) 
    vTcl:DefineAlias "$site_11_0.lab43" "label,q_tl3" vTcl:WidgetProc "main" 0
    button $site_11_0.but58 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but58" "ls,q_tl3" vTcl:WidgetProc "main" 0
    button $site_11_0.but28 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_11_0.but28" "stop,q_tl3" vTcl:WidgetProc "main" 0
    pack $site_11_0.lab43 \
        -in $site_11_0 -anchor center -expand 1 -fill x -side left 
    pack $site_11_0.but58 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    pack $site_11_0.but28 \
        -in $site_11_0 -anchor center -expand 0 -fill none -side left 
    text $site_10_0.047 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_10_0.047" "q_tl3" vTcl:WidgetProc "main" 0
    pack $site_10_0.fra33 \
        -in $site_10_0 -anchor center -expand 0 -fill x -side top 
    pack $site_10_0.047 \
        -in $site_10_0 -anchor center -expand 1 -fill both -side top 
    pack $site_9_0.039 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    pack $site_9_0.042 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    pack $site_9_0.045 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side left 
    frame $site_8_0.048 \
        -background #dcdcdc -height 75 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -width 125 
    set site_9_0 $site_8_0.048
    frame $site_9_0.fra34 \
        -height 75 -width 125 
    set site_10_0 $site_9_0.fra34
    label $site_10_0.lab44 \
        -background #ffa850 -borderwidth 1 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -text Kontexthilfe -textvariable label(opt,q_ctxhelp) 
    vTcl:DefineAlias "$site_10_0.lab44" "label,q_ctxhelp" vTcl:WidgetProc "main" 0
    button $site_10_0.but60 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_10_0.but60" "ls,q_ctxhelp" vTcl:WidgetProc "main" 0
    button $site_10_0.but29 \
        -borderwidth 0 -highlightthickness 0 -padx 0 -pady 0 
    vTcl:DefineAlias "$site_10_0.but29" "stop,q_ctxhelp" vTcl:WidgetProc "main" 0
    pack $site_10_0.lab44 \
        -in $site_10_0 -anchor center -expand 1 -fill x -side left 
    pack $site_10_0.but60 \
        -in $site_10_0 -anchor center -expand 0 -fill none -side left 
    pack $site_10_0.but29 \
        -in $site_10_0 -anchor center -expand 0 -fill none -side left 
    text $site_9_0.050 \
        -background #ffffff -foreground #000000 -height 1 \
        -highlightbackground #ffffff -highlightcolor #000000 \
        -selectbackground #547098 -selectforeground #ffffff -width 1 \
        -wrap word 
    vTcl:DefineAlias "$site_9_0.050" "q_ctxhelp" vTcl:WidgetProc "main" 0
    pack $site_9_0.fra34 \
        -in $site_9_0 -anchor center -expand 0 -fill x -side top 
    pack $site_9_0.050 \
        -in $site_9_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.02 \
        -in $site_8_0 -anchor center -expand 0 -fill x -side top 
    pack $site_8_0.05 \
        -in $site_8_0 -anchor center -expand 0 -fill x -side top 
    pack $site_8_0.012 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.015 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.018 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.028 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.038 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    pack $site_8_0.048 \
        -in $site_8_0 -anchor center -expand 1 -fill both -side top 
    pack $site_7_0.051 \
        -in $site_7_0 -anchor center -expand 1 -fill both -side top 
    pack $site_7_0.01 \
        -in $site_7_0 -anchor center -expand 1 -fill both -side top 
    pack $site_6_0.fra29 \
        -in $site_6_0 -anchor center -expand 1 -fill both -side top 
    pack $site_5_0.cpd79 \
        -in $site_5_0 -anchor center -expand 1 -fill both -side top 
    frame $site_4_0.02 \
        -background #9900991B99FE 
    vTcl:DefineAlias "$site_4_0.02" "Frame2" vTcl:WidgetProc "main" 0
    set site_5_0 $site_4_0.02
    frame $site_5_0.cpd78 \
        -background #9900991B99FE -highlightbackground #dcdcdc \
        -highlightcolor #000000 
    set site_6_0 $site_5_0.cpd78
    frame $site_6_0.fra28 \
        -borderwidth 1 -relief groove -background #dcdcdc -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 0 
    set site_7_0 $site_6_0.fra28
    frame $site_7_0.fra17 \
        -height 75 -width 125 
    set site_8_0 $site_7_0.fra17
    button $site_8_0.but19 \
        -command {menuCommand run,restart} -pady 0 -text {| <} -width 3 
    button $site_8_0.but18 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dec8de \
        -command {set curobj(q_follows) [dia::choosePQmulti $curobj(q_follows)]} \
        -disabledforeground #000040 -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -pady 0 \
        -state disabled -text Folgeaktionen \
        -textvariable label(opt,p_follows) 
    button $site_8_0.but20 \
        -command {menuCommand run,undo} -pady 0 -text < -width 3 
    pack $site_8_0.but19 \
        -in $site_8_0 -anchor center -expand 0 -fill none -side left 
    pack $site_8_0.but18 \
        -in $site_8_0 -anchor center -expand 1 -fill x -side left 
    pack $site_8_0.but20 \
        -in $site_8_0 -anchor center -expand 0 -fill none -side left 
    frame $site_7_0.cpd31 \
        -borderwidth 1 -relief raised -background #dcdcdc -height 30 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 30 
    set site_8_0 $site_7_0.cpd31
    listbox $site_8_0.01 \
        -background #dcdcdc \
        -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* \
        -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff -xscrollcommand "$site_8_0.02 set" \
        -yscrollcommand "$site_8_0.03 set" 
    vTcl:DefineAlias "$site_8_0.01" "followlist" vTcl:WidgetProc "main" 0
    bind $site_8_0.01 <ButtonRelease-1> {
        getAndSwitch
    }
    scrollbar $site_8_0.02 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$site_8_0.01 xview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -orient horizontal -troughcolor #dcdcdc -width 10 
    scrollbar $site_8_0.03 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$site_8_0.01 yview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -troughcolor #dcdcdc -width 10 
    grid $site_8_0.01 \
        -in $site_8_0 -column 0 -row 0 -columnspan 1 -rowspan 1 -sticky nesw 
    grid $site_8_0.02 \
        -in $site_8_0 -column 0 -row 1 -columnspan 1 -rowspan 1 -sticky ew 
    grid $site_8_0.03 \
        -in $site_8_0 -column 1 -row 0 -columnspan 1 -rowspan 1 -sticky ns 
    pack $site_7_0.fra17 \
        -in $site_7_0 -anchor center -expand 0 -fill x -side top 
    pack $site_7_0.cpd31 \
        -in $site_7_0 -anchor center -expand 1 -fill both -side top 
    grid columnconf $site_7_0.cpd31 0 -weight 1
    grid rowconf $site_7_0.cpd31 0 -weight 1
    frame $site_6_0.fra17 \
        -borderwidth 2 -relief groove -background #dcdcdc -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 125 
    set site_7_0 $site_6_0.fra17
    radiobutton $site_7_0.rad23 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -command resortList -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -text Name \
        -textvariable label(opt,run_namesort) -value 2 -variable woz(sort) 
    bind $site_7_0.rad23 <ButtonRelease-1> {
        resortList
    }
    radiobutton $site_7_0.cpd71 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -command resortList -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -text Name \
        -textvariable label(opt,run_condsort) -value 1 -variable woz(sort) 
    bind $site_7_0.cpd71 <ButtonRelease-1> {
        resortList
    }
    radiobutton $site_7_0.rad24 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -command resortList -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -text Name \
        -textvariable label(opt,run_textsort) -value 3 -variable woz(sort) 
    bind $site_7_0.rad24 <ButtonRelease-1> {
        resortList
    }
    radiobutton $site_7_0.rad25 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -command resortList -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -text Index \
        -textvariable label(opt,run_indexsort) -value 0 -variable woz(sort) 
    bind $site_7_0.rad25 <ButtonRelease-1> {
        resortList
    }
    pack $site_7_0.rad23 \
        -in $site_7_0 -anchor center -expand 0 -fill none -side left 
    pack $site_7_0.cpd71 \
        -in $site_7_0 -anchor center -expand 0 -fill none -side left 
    pack $site_7_0.rad24 \
        -in $site_7_0 -anchor center -expand 0 -fill none -side left 
    pack $site_7_0.rad25 \
        -in $site_7_0 -anchor center -expand 0 -fill none -side left 
    canvas $site_6_0.cpd73 \
        -background #ffffff -borderwidth 2 -closeenough 1.0 -height 133 \
        -relief sunken 
    vTcl:DefineAlias "$site_6_0.cpd73" "overview,c" vTcl:WidgetProc "main" 0
    frame $site_6_0.fra18 \
        -height 75 -width 125 
    set site_7_0 $site_6_0.fra18
    entry $site_7_0.ent19 \
        -textvariable logMessage 
    vTcl:DefineAlias "$site_7_0.ent19" "logEntry" vTcl:WidgetProc "main" 0
    button $site_7_0.but20 \
        -borderwidth 1 \
        -command {if {$logMessage!=""} {
  log "Log|$logMessage"
  logDia "" "" "Caller" $logMessage
  set logMessage ""
}} \
        -highlightthickness 0 -padx 0 -pady 0 -text Log \
        -textvariable label(opt,run_log) 
    vTcl:DefineAlias "$site_7_0.but20" "logButton" vTcl:WidgetProc "main" 0
    pack $site_7_0.ent19 \
        -in $site_7_0 -anchor center -expand 1 -fill x -side left 
    pack $site_7_0.but20 \
        -in $site_7_0 -anchor center -expand 0 -fill none -side left 
    pack $site_6_0.fra28 \
        -in $site_6_0 -anchor center -expand 1 -fill both -side top 
    pack $site_6_0.fra17 \
        -in $site_6_0 -anchor center -expand 0 -fill x -side top 
    pack $site_6_0.cpd73 \
        -in $site_6_0 -anchor center -expand 0 -fill none -side top 
    pack $site_6_0.fra18 \
        -in $site_6_0 -anchor center -expand 0 -fill x -side top 
    pack $site_5_0.cpd78 \
        -in $site_5_0 -anchor center -expand 1 -fill both -side top 
    frame $site_4_0.03 \
        -borderwidth 2 -relief raised -background #ff0000 
    vTcl:DefineAlias "$site_4_0.03" "Frame3" vTcl:WidgetProc "main" 0
    bind $site_4_0.03 <B1-Motion> {
        set root [ split %W . ]
    set nb [ llength $root ]
    incr nb -1
    set root [ lreplace $root $nb $nb ]
    set root [ join $root . ]
    set width [ winfo width $root ].0
    
    set val [ expr (%X - [winfo rootx $root]) /$width ]

    if { $val >= 0 && $val <= 1.0 } {
    
        place $root.01 -relwidth $val
        place $root.03 -relx $val
        place $root.02 -relwidth [ expr 1.0 - $val ]
    }
    }
    place $site_4_0.01 \
        -in $site_4_0 -x -5 -y 0 -width -1 -relwidth 0.6595 -relheight 1 \
        -anchor nw -bordermode ignore 
    place $site_4_0.02 \
        -in $site_4_0 -x 0 -relx 1 -y 0 -width -1 -relwidth 0.3405 \
        -relheight 1 -anchor ne -bordermode ignore 
    place $site_4_0.03 \
        -in $site_4_0 -x 0 -relx 0.6595 -y 0 -rely 0.9 -width 10 -height 10 \
        -anchor s -bordermode ignore 
    pack $site_3_0.cpd77 \
        -in $site_3_0 -anchor center -expand 1 -fill both -side top 
    ###################
    # SETTING GEOMETRY
    ###################
    pack $top.cpd19 \
        -in $top -anchor center -expand 0 -fill x -side top 
    pack $top.fra21 \
        -in $top -anchor center -expand 0 -fill x -side top 
    pack $top.fra20 \
        -in $top -anchor center -expand 1 -fill both -side top 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top71 {base} {
    if {$base == ""} {
        set base .top71
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -background #dcdcdc -highlightbackground #dcdcdc \
        -highlightcolor #000000 
    wm withdraw $top
    wm focusmodel $top passive
    wm geometry $top 569x119+121+253; update
    wm maxsize $top 1009 738
    wm minsize $top 115 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm title $top "Ausnahme"
    vTcl:DefineAlias "$top" "winexc" vTcl:Toplevel:WidgetProc "" 0
    bindtags $top "$top Toplevel all _TopLevel"
    bind $top <Key-Escape> {
        $widget(b,exclose) invoke
    }
    bind $top <Key-Return> {
        $widget(b,exclose) invoke
    }
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    frame $top.fra72 \
        -borderwidth 2 -relief groove -background #dcdcdc -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 125 
    set site_3_0 $top.fra72
    label $site_3_0.lab75 \
        -background #dcdcdc -borderwidth 1 -font {Helvetica 24 bold} \
        -foreground #f80000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -text Ausnahme -textvariable label(exc) 
    pack $site_3_0.lab75 \
        -in $site_3_0 -anchor center -expand 1 -fill none -side top 
    frame $top.fra73 \
        -borderwidth 2 -relief groove -background #dcdcdc -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -width 125 
    set site_3_0 $top.fra73
    button $site_3_0.but74 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc \
        -command {global widget
grab release $widget(winexc)
Window destroy $widget(winexc)} \
        -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -pady 0 -text Schlieen \
        -textvariable label(close) 
    vTcl:DefineAlias "$site_3_0.but74" "b,exclose" vTcl:WidgetProc "winexc" 0
    pack $site_3_0.but74 \
        -in $site_3_0 -anchor center -expand 0 -fill none -padx 10 -pady 10 \
        -side top 
    ###################
    # SETTING GEOMETRY
    ###################
    pack $top.fra72 \
        -in $top -anchor center -expand 1 -fill both -side top 
    pack $top.fra73 \
        -in $top -anchor center -expand 0 -fill x -side top 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    if {[set ::%W::_modal]} {
                vTcl:Toplevel:WidgetProc %W endmodal
            } else {
                destroy %W; if {$_topcount == 0} {exit}
            }
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}

Window show .
Window show .top17
Window show .top71

main $argc $argv
