#==========================================================================================
#
# 	Written by Richard Breuer (richard.breuer@gmx.de)
#
#==========================================================================================
# Feb 19, 2000	First version [RB]
#==========================================================================================

namespace eval dia {

proc listChoose {w title inList {preSelection {}} {matchMode exact} {mode multiple}} {
  # show a listbox to choose some elements from a list
  global dia::exit widget

	if {[info exists widget(list)]} {
		# save the selection in the list
		set cs [$widget(list) curselection]
	}

  # geometry
#	toplevel $w -borderwidth 5
  toplevel $w
#	wm overrideredirect $w 1
  wm title $w $title
  frame $w.1
  frame $w.2
  pack $w.1 -expand 1 -fill both
  pack $w.2 -fill x

  set b $w.1.b
  listbox $b -selectmode $mode -yscrollcommand "$w.1.s set"
  pack $b -expand 1 -fill both -side left
  scrollbar $w.1.s \
        -background #dcdcdc -borderwidth 1 \
        -command "$b yview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -troughcolor #dcdcdc -width 10
  pack $w.1.s -fill y -side left

  button $w.2.1 -textvar label(ok)  -command "set dia::exit 1"
  button $w.2.3 -textvar label(none) -command "$b selection clear 0 end"
  button $w.2.9 -textvar label(cancel) -command {set dia::exit 0}  
  if {$mode!="browse"} {
  	button $w.2.2 -textvar label(all)  -command "$b selection set 0 end"
	pack $w.2.1 $w.2.2 $w.2.3 $w.2.9 -side left -expand 1 -pady 5 -padx 5
  } else {
	pack $w.2.1 $w.2.3 $w.2.9 -side left -expand 1 -pady 5 -padx 5
  }

  # starting position --> middle of the screen
  set sw [winfo screenwidth .]
  set sh [winfo screenheight .]
  set x [expr {($sw - 200)/2}]
  set y [expr {($sh - 250)/2}]
  wm geometry $w +$x+$y

  # contents at startup
  set i 0
  foreach e $inList {
    $b insert end $e
    set tmp($i) $e
    incr i
  }

  # selection at startup
  foreach e $preSelection {
    case $matchMode {
      start {
        set p [lsearch -regexp $inList "^$e"]
        if {$p!=-1} {$b selection set $p}
      }
      default {
        set p [lsearch -exact $inList $e]
        if {$p!=-1} {$b selection set $p}
      }
    }
  }
 
  # bindings
	set dia::exit -1
  bind $w <Escape> "$w.2.9 invoke"
  bind $w <Return> "$w.2.1 invoke"
  if {$mode=="browse"} {bind $b <Double-ButtonPress-1> "$w.2.1 invoke"}
  
  # dialog
  grab $w
  raise $w
  focus -force $w
  tkwait variable dia::exit
  grab release $w

  # return the selection
  if {$dia::exit} {
    set ret {}
    foreach s [$b curselection] {
      lappend ret [$b get $s]
    }
  } else {
    set ret $preSelection
  }
  
  catch {destroy $w}
  
  # set selection in the list window again
	if {[info exists widget(list)]} {
	  if {$cs!=""} {
	 		$widget(list) selection set $cs
		}
	}

  return $ret
}

proc choosePQmulti {{preSelected {}}} {
  # return a list of {P001 Q001 ...} of prompt and question ids
  # preSelected contains the startup selections
  global curobj

  set inList {}

  # get a list of currently possible P and Q
  foreach ix [allEntries P] {
    lappend inList [visibleName $ix]
  }
  foreach ix [allEntries Q] {
    lappend inList [visibleName $ix]
  }

  # nothing to do
  if {$inList=={}} {return $preSelected}

  # choice
  set tmp [listChoose .c [res::Str win_pqchoice] $inList $preSelected start]
  set ret {}
  foreach n $tmp {
    lappend ret [lindex [split $n " "] 0]
  }

  # Return sorted
  return [lsort $ret]
}

proc choosePQsingle {inList} {
  # return a list of {P001 Q001 ...} of prompt and question ids from $inList
  global curobj

  # nothing to do
  if {$inList=={}} {return [list]}

	# change name into visible name
	set newList {}
	foreach n $inList {
		lappend newList [visibleName $n]
	}

  # choice
  set tmp [listChoose .c [res::Str win_pqsingle] $newList {} start browse]
  set ret {}
  foreach n $tmp {
    lappend ret [lindex [split $n " "] 0]
  }

  # Return sorted
  return [lsort $ret]
}

proc chooseFollowPQsingle {id inList {markOnly 1}} {
  # return a list of {P001 Q001 ...} of prompt and question ids from $inList
  # followups of $id are treated specially: if $markOnly, they are highligted, if not, all others are skipped
  # the followups must be contained in $inList
  global curobj
  set MARK "<"

  # nothing to do
  if {$inList=={}} {return [list]}

	# change name into visible name
	set newList {}
	foreach n $inList {
		if {[isConnected $id $n]} {
			lappend newList "$MARK[visibleName $n]"
		} elseif {$markOnly} {
			lappend newList "[visibleName $n]"
		}
	}
  if {$newList=={}} {return [list]}

  # choice
  set tmp [listChoose .c [res::Str win_pqsingle] $newList {} start browse]
  set ret {}
  foreach n $tmp {
		set v [lindex [split $n " "] 0]
		if {[string index $v 0]==$MARK} {set v [string range $v 1 end]}
    lappend ret $v
  }

  # Return sorted
  return [lsort $ret]
}

proc chooseSingle {inList} {
  # return one string from $inList
  global curobj

  # nothing to do
  if {$inList=={}} {return [list]}

  # choice
  return [listChoose .c [res::Str win_pqsingle] $inList {} start browse]
}

proc chooseCmulti {{preSelected {}}} {
  # return a list of {C001 C002 ...} of concept ids
  # preSelected contains the startup selections
  global curobj

  set inList {}

  # get a list of currently possible C
  foreach ix [allEntries C] {
    lappend inList [visibleName $ix]
  }

  # nothing to do
  if {$inList=={}} {return $preSelected}

  # choice
  set tmp [listChoose .c [res::Str win_cchoice] $inList $preSelected start]
  set ret {}
  foreach n $tmp {
    lappend ret [lindex [split $n " "] 0]
  }

  # Return sorted
  return [lsort $ret]
}

proc chooseSmulti {{preSelected {}}} {
  # return a list of {S001 S002 ...} of call ids
  # preSelected contains the startup selections
  global curobj

  set inList {}

  # get a list of currently possible S
  foreach ix [allEntries S] {
    lappend inList [visibleName $ix]
  }

  # nothing to do
  if {$inList=={}} {return $preSelected}

  # choice
  set tmp [listChoose .c [res::Str win_cchoice] $inList $preSelected start]
  set ret {}
  foreach n $tmp {
    lappend ret [lindex [split $n " "] 0]
  }

  # Return sorted
  return [lsort $ret]
}

proc stringEntry {w title {defaultValue ""} {allowEmpty 1} {allowEscape 1}} {
  # show an entry field and return the string input
  global dia::exit widget

  # geometry
  toplevel $w -borderwidth 5
	wm overrideredirect $w 1
  wm title $w $title
	entry $w.1 -width 30 -textvar dia::string
	set dia::string $defaultValue
	$w.1 selection range 0 end
	pack $w.1 -expand 1 -fill x
 
  # starting position --> middle of the screen
  set sw [winfo screenwidth .]
  set sh [winfo screenheight .]
  set x [expr {($sw - 200)/2}]
  set y [expr {($sh - 250)/2}]
  wm geometry $w +$x+$y
	
  # bindings
	set dia::exit -1
  if {$allowEscape} {bind $w <Escape> "set dia::exit 1"}
  bind $w <Return> "if {$allowEmpty||\$dia::string!=\"\"} {set dia::exit 0}"
  
  # dialog
  grab $w
  raise $w
  focus -force $w.1
  tkwait variable dia::exit
  grab release $w

  # return the selection
  if {$dia::exit} {
    set ret {}
  } else {
    set ret $dia::string
  }
  
  catch {destroy $w}
  
  return $ret
}

}
