#
# play audio and picture files
#
namespace eval play {

	# sound package already required in main program
	#package require snack

	proc chooseFilename {fnlist} {
		global woz
  	return [dia::listChoose .c $woz(win_choose) $fnlist {} start browse]
	}

	proc getString {default} {
		global woz
  	return [dia::stringEntry .c $woz(win_entertts) $default]
	}

	proc tts {str} {
		global woz
		if {$str==""} return
		if {[catch {$woz(sapi) Speak $str} msg]} {
			tk_messageBox -type ok -message "ERROR: SAPI does not work ($msg)"
		} else {
			log "tts=$str"
			if {[info command logDia]=="logDia"} {
				logDia "" "tts" "System" $str
			}
		}
	}
	
	proc getIndices {str ind} {
		set ret {}

		# find select indices
		set start 0
		while {[regexp -nocase -start $start -indices -- "\\\[[set ind]:(\[^\\\]\]*)\\\]" $str p]} {
			lappend ret [concat $p select]
			set start [expr 1+[lindex $p 1]]
		}

		# find random indices
		set start 0
		while {[regexp -nocase -start $start -indices -- "\{[set ind]:(\[^\\\]\]*)\}" $str p]} {
			lappend ret [concat $p random]
			set start [expr 1+[lindex $p 1]]
		}

		return [lsort -integer -index 0 $ret]
	}

	proc getAudioIndices {str} {
		return [getIndices $str "A"]
	}
	
	proc getPictureIndices {str} {
		return [getIndices $str "P"]
	}

	proc getAllIndices {str} {
		return [lsort -integer -index 0 [concat [getIndices $str "P"] [getIndices $str "A"]]]
	}
	
	proc getAudioFilenames {str} {
		set ret {}
		set ind [getAudioIndices $str]
		foreach i $ind {
			lappend ret [string range $str [expr 3+[lindex $i 0]] [expr [lindex $i 1]-1]]
		}
		return $ret
	}
	
	proc getPictureFilenames {str} {
		set ret {}
		set ind [getPictureIndices $str]
		foreach i $ind {
			lappend ret [string range $str [expr 3+[lindex $i 0]] [expr [lindex $i 1]-1]]
		}
		return $ret
	}
	
	proc removeFilenames {str {askForDynamicParts 1}} {
		set ret {}
		set start 0
		set audioIndices [getAudioIndices $str]
		set pictureIndices [getPictureIndices $str]
		set ind [lsort -integer -index 0 [concat $audioIndices $pictureIndices]]
		foreach i $ind {
			set end [expr [lindex $i 0]-1]
			if {$end>=$start} {
				append ret [string range $str $start $end]
			}

			#tk_messageBox -message "$str / [string range $str [expr 4+$end] [expr 6+$end]]" -type ok

			# if we have an audio file starting with ..., ask for the dynamic part
			if {$askForDynamicParts && [string range $str [expr 4+$end] [expr 6+$end]]=="..."} {
				set p1 [string first "," $str $end]
				set p2 [string first "\]" $str $end]
				if {$p1>0 && $p1<$p2} {set p2 $p1}
				append ret [getString [string range $str [expr 7+$end] [expr $p2-1]]]
			}

			set start [expr [lindex $i 1]+1]
		}
		if {$start<[string length $str]} {
			append ret [string range $str $start end]
		}
		return $ret
	}

	proc processPrompt {str {random 0} {forceRandom 0}} {
		global woz plugin var

		set ret ""

		# get all occurrences of file names in str
		set plist [lsort -integer -index 0 [concat [play::getAudioIndices $str] [play::getPictureIndices $str]]]

		# loop over the indices
		set start 0
		set alltext ""
		foreach p $plist {
			# process the part before the index
			if {[lindex $p 0]>$start} {
				append alltext "[string range $str $start [expr [lindex $p 0]-1]] "
			}
			set start [expr 1+[lindex $p 1]]

			# process audio files only if possible
			if {$woz(snack)!=""} {
				# process only audio files, pics are skipped here
				if {[string tolower [string index $str [expr 1+[lindex $p 0]]]]=="a"} {
	
					# process the file name list
					set fnlist [split [string range $str [expr 3+[lindex $p 0]] [expr [lindex $p 1]-1]] ","]
		
					# choose one if necessary
					if {[llength $fnlist]>1} {
						if {$forceRandom || ($random && [string index $str [lindex $p 0]]=="\{")} {
							set fn [lindex $fnlist [expr [util::ranint 1 [llength $fnlist]]-1]]
						} else {
							set fn [chooseFilename $fnlist]
						}
	
						# if cancelled, return w/o prompt
						if {$fn==""} {
							catch {$ret destroy}
							return ""
						}
					} else {
						set fn [lindex $fnlist 0]
					}
					
					# if the filename starts with "...", open an entry field for input
					if {[string range $fn 0 2]=="..."} {
						#set fn [getString [string range $fn 3 end]]
						set fn ""
					}

					if {$fn!=""} {
						set sub [snack::sound]
						set dfn $woz(wav_dir)/$fn
						if {[catch {$sub read $dfn}]} {
					    tk_messageBox -type ok -message "Audio file '$dfn' cannot be read!"
						} else {
							if {$ret==""} {
								set ret $sub
							} else {
								if {[catch {$ret concatenate $sub}]} {
							    tk_messageBox -type ok -message "Audio file '$dfn'
has a different audio format!"
								}
								$sub destroy
							}
						}
					}
				}
			}
		}
		return $ret
	}
	
	proc prompt {str {random 0}} {
		# prompt can be a text containing expressions like [A:<filename>]

		# if no tts is to be used
		# 	each filename is played using the sound package
		# 	the result of this function is a "sound" object
		# 	the "choose" function is called with a list of filenames to choose one from,
		# 		if an expression like [A:a.wav,b.wav] is found
		# else
		# 	The prompt without filenames spoken using the computer's standard tts voice

		global woz plugin var
		
		# create the return sound object
		set ret ""

		if {$var(tts)==0 && [regexp {\[A:TTS\]} $str]==0} {
			set ret [play::processPrompt $str $random 0]
		} else {
			play::tts [play::removeFilenames $str]
		}
		return $ret
	}

	proc picture {str} {
		# str can be a text containing expressions like [P:<filename>]
		# chooseFilename is called with a list of filenames to choose one from,
		# 	if an expression like [P:a.jpg,b.jpg] is found
		# if there is more than one pic, only the first is displayed
		# the path name of the new toplevel is returned
		global woz
		
		# get all occurrences of file names in str
		set plist [play::getPictureIndices $str]

		# loop over the indices
		set start 0
		foreach p $plist {
			# process the file name list
			set fnlist [split [string range $str [expr 3+[lindex $p 0]] [expr [lindex $p 1]-1]] ","]

			# choose one if necessary
			if {[llength $fnlist]>1} {
				if {$random && [string index $str [lindex $p 0]]=="\{"} {
					set fn [lindex $fnlist [expr [util::ranint 1 [llength $fnlist]]-1]]
				} else {
					set fn [chooseFilename $fnlist]
				}

				# if cancelled, return w/o prompt
				if {$fn==""} {
					catch {$ret destroy}
					return ""
				}
			} else {
				set fn [lindex $fnlist 0]
			}
			
			# if the filename starts with "...", open an entry field for input
			if {[string range $fn 0 2]=="..."} {
				#set fn [getString [string range $fn 3 end]]
				set fn ""
			}

			if {$fn!=""} {
				catch {destroy .picture}
				set dfn $woz(wav_dir)/$fn

				#
				#	ideally, this toplevel should be opened on a different visual
				#
				if {[catch {
				toplevel .picture -borderwidth 3
				wm overrideredirect .picture 1
				image create photo pictureImage -file $dfn
				button .picture.b -image pictureImage -command { catch {destroy .picture} }
				pack .picture.b}]} {
					catch {destroy .picture}
			    tk_messageBox -type ok -message "Picture file '$dfn' cannot be read!"
				} else {
					return .picture
				}

			}
		}

		return ""
	}
}
