	proc wozInit {} {
  global plugin options

  array set plugin {
		pix,vars	{p_id p_follows p_start p_title p_prompt_bi p_endstate p_reachable p_vxml}
		pix,vlist	{0 1 0 0 0 0 0 0}
		pix,yesno	{0 0 1 0 1 1 1 1}
		pix,text	{p_prompt p_memo}
		pix,phr		{p_prompt}

		qix,vars	{q_id q_follows q_concepts q_title q_init_bi q_nu1_bi q_nu2_bi q_nu3_bi q_nr1_bi q_nr2_bi q_nr3_bi q_tl1_bi q_tl2_bi q_tl3_bi q_ctxhelp_bi q_endstate q_reachable q_vxml}
		qix,vlist	{0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0}
		qix,yesno	{0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1}
		qix,text	{q_init q_memo q_nu1 q_nu2 q_nu3 q_nr1 q_nr2 q_nr3 q_tl1 q_tl2 q_tl3 q_ctxhelp}
		qix,phr		{q_init q_nu1 q_nu2 q_nu3 q_nr1 q_nr2 q_nr3 q_tl1 q_tl2 q_tl3 q_ctxhelp}

		cix,vars	{c_id c_name c_always c_title}
		cix,vlist	{0 0 0 0}
		cix,yesno	{0 0 1 0}
		cix,text	{c_memo}

		six,vars	{s_id s_name s_call}
		six,vlist	{0 0 1}
		six,yesno	{0 0 0}
		six,text	{s_memo}
  }
  array set options {
		ix,version	0
		ix,options	1
		ix,woz		2
  }
}

proc visibleName {id} {
  global plugin

  # return a name for a list
  if {[isPrompt $id]} {
		if {![promptExists $id]} {
			set ret "$id - new prompt"
		} else {
	    if {$plugin($id,p_start)==1} {
	      set ret "$id[res::Str p_start $plugin($id,p_title) $plugin($id,p_prompt)]"
	    } else {
	      set ret "$id[res::Str p_normal $plugin($id,p_title) $plugin($id,p_prompt)]"
	    }
		}
	} elseif {[isQuestion $id]} {
		if {![questionExists $id]} {
			set ret "$id - new question"
		} else {
	    set ret "$id[res::Str q_normal $plugin($id,q_title) $plugin($id,q_init)]"
		}
  } elseif {[isConcept $id]} {
		if {![conceptExists $id]} {
			set ret "$id - new concept"
		} else {
	    if {$plugin($id,c_always)==1} {
	      set ret "$id[res::Str c_always $plugin($id,c_title) $plugin($id,c_name)]"
	    } else {
	      set ret "$id[res::Str c_normal $plugin($id,c_title) $plugin($id,c_name)]"
	    }
		}
  } elseif {[isSampleCall $id]} {
		if {![sampleCallExists $id]} {
			set ret "$id - new sample call"
		} else {
	    set ret "$id[res::Str s_normal $plugin($id,s_name)]"
		}
  } else {
		set ret "$id - unknown object"
  }

  # cut the length if necessary
  if {[string length $ret]>[ini::Str common.textDisplayLength]} {
    set ret "[string range $ret 0 [expr [ini::Str common.textDisplayLength]-3]].."
  } 

  return $ret
}

proc id2title {idlist} {
	global plugin
	
	# calculate the titles from a list of id's
	set ret ""
	foreach f $idlist {
		# find $f in prompts, concepts and questions
		if {[isPrompt $f]}   {lappend ret $plugin($f,p_title)}
		if {[isQuestion $f]} {lappend ret $plugin($f,q_title)}
		if {[isConcept $f]}  {lappend ret $plugin($f,c_title)}
	}
	return $ret
}

proc cleanUpBookmarkName {bookmark} {
  regsub -all {[+-*/!$%&()=., "'#~]} $bookmark "_" bookmark
	return $bookmark
}

proc id2crossreference {idlist} {
	global plugin

	# calculate the titles from a list of id's
	set ret ""
	set backslash "<<BACKSLASH>>"
#    regsub -all {[+-*/!$%&()=., "'#~]} "${f}_$plugin($f,p_title)" "_" bookmarkName
	foreach f $idlist {
		# find $f in prompts, concepts and questions
		if {[isPrompt $f]}   	{lappend ret "{\\field{\\*\\fldinst { REF ${f}_$plugin($f,p_title) ${backslash}${backslash}h }{}}{\\fldrslt {$f $plugin($f,p_title)}}}"}
		if {[isConcept $f]} 	{lappend ret "{\\field{\\*\\fldinst { REF ${f}_$plugin($f,c_title) ${backslash}${backslash}h }{}}{\\fldrslt {$f $plugin($f,c_title)}}}"}
		if {[isQuestion $f]}  {lappend ret "{\\field{\\*\\fldinst { REF ${f}_$plugin($f,q_title) ${backslash}${backslash}h }{}}{\\fldrslt {$f $plugin($f,q_title)}}}"}
	}
	return $ret
}

proc id2text {idlist} {
	global plugin
	
	# calculate texts from a list of id's
	set ret ""
	foreach f $idlist {
		# find $f in prompts, concepts and questions
		if {[isPrompt $f]}   {lappend ret $plugin($f,p_prompt)}
		if {[isConcept $f]} {lappend ret $plugin($f,c_name)}
		if {[isQuestion $f]}  {lappend ret $plugin($f,q_init)}
	}

	# strip white spaces, limit length
	set tmp {}
	set len [ini::Str common.textPreviewLength]
	foreach f $ret {
		regsub -all "\n" $f " " x
		if {[string length $x]>$len} {
			set x "[string range $x 0 $len]..."
		}
		lappend tmp $x
	}

	return $tmp
}

proc wozLog {type str {subtype DIALOG}} {
  global widget
  $widget(log) insert end "$str\n" $type-$subtype
  log "Analysis: $str"
}

proc wozAnalyze {{autoCloseOnSuccess 0}} {
  # analyze the data, return 1 for no errors
  global widget plugin

  # fill the log window
  set w $widget(log)
  $widget(log) configure -state normal
  $w delete 0.0 end

	$w tag configure HEADER-ALL     -foreground white  -background #404040 -font {Helvetica 10 bold}
  $w tag configure NORMAL-DIALOG  -foreground black  -background white
  $w tag configure ERROR-DIALOG   -foreground red    -background white
  $w tag configure WARNING-DIALOG -foreground black  -background white
  $w tag configure INFO-DIALOG    -foreground green  -background white
  $w tag configure NORMAL-S       -foreground black  -background [ini::Str Common.colorS]
  $w tag configure ERROR-S        -foreground red    -background [ini::Str Common.colorS]
  $w tag configure WARNING-S      -foreground black  -background [ini::Str Common.colorS]
  $w tag configure INFO-S         -foreground green  -background [ini::Str Common.colorS]
  $w tag configure NORMAL-C       -foreground black  -background [ini::Str Common.colorC]
  $w tag configure ERROR-C        -foreground red    -background [ini::Str Common.colorC]
  $w tag configure WARNING-C      -foreground black  -background [ini::Str Common.colorC]
  $w tag configure INFO-C         -foreground green  -background [ini::Str Common.colorC]
  $w tag configure NORMAL-P       -foreground black  -background [ini::Str Common.colorP]
  $w tag configure ERROR-P        -foreground red    -background [ini::Str Common.colorP]
  $w tag configure WARNING-P      -foreground black  -background [ini::Str Common.colorP]
  $w tag configure INFO-P         -foreground green  -background [ini::Str Common.colorP]
  $w tag configure NORMAL-Q       -foreground black  -background [ini::Str Common.colorQ]
  $w tag configure ERROR-Q        -foreground red    -background [ini::Str Common.colorQ]
  $w tag configure WARNING-Q      -foreground black  -background [ini::Str Common.colorQ]
  $w tag configure INFO-Q         -foreground green  -background [ini::Str Common.colorQ]

  # analyse the woz data
  set ret 1
  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]
  set allS [allEntries S]

  wozLog HEADER [res::Str ana_i_header] ALL

  if {$allP=={} && $allQ=={}} {
    wozLog ERROR [res::Str ana_e_noprompt]
    set ret 0
  } else {
    # ------------------------------------------------------
    # check for start prompts
    set start 0
    set tmp {}
    foreach n $allP {
      if {$plugin($n,p_start)==1} {
        incr start
        lappend tmp $n
      }
    }
    if {$start==0} {
      wozLog ERROR [res::Str ana_e_nostart] P
      set ret 0
    } elseif {$start>1} {
      wozLog ERROR [res::Str ana_e_multstart $tmp] P
      set ret 0
    }

    # ------------------------------------------------------
    # check for unreachable entries
    foreach n $allP { set tmp [concat $tmp $plugin($n,p_follows)] }
    foreach n $allQ { set tmp [concat $tmp $plugin($n,q_follows)] }
    set tmp [lsort -uniq $tmp]
    foreach n [concat $allP $allQ] {
      if {![isAlwaysReachable $n] && [lsearch -exact $tmp $n]==-1} {
        wozLog WARNING [res::Str ana_w_notreached $n]
      }
    }

    # ------------------------------------------------------
    # check for unused concepts
    set tmp {}
    foreach n $allC {
      if {$plugin($n,c_always)==1} {lappend tmp $n}
    }
    foreach n $allQ {
      set tmp [concat $tmp $plugin($n,q_concepts)]
    }
    set tmp [lsort -uniq $tmp]
    foreach n $allC {
      if {[lsearch -exact $tmp $n]==-1} {
        wozLog WARNING [res::Str ana_w_notused $n] C
      }
    }

    # ------------------------------------------------------
    # check for initial prompts, titles & names
    set title {}
    foreach n $allP {
      if {$plugin($n,p_prompt)==""} {
        wozLog WARNING [res::Str ana_w_noprompt $n] P
      }
      if {$plugin($n,p_title)==""} {
        wozLog ERROR [res::Str ana_e_notitle $n] P
        set ret 0
      }
      set lo [string tolower $plugin($n,p_title)]
      if {[lsearch -exact $title $lo]!=-1} {
        wozLog ERROR [res::Str ana_e_sameptitle $n] P
        set ret 0
      } else {
        lappend title $lo
      }
    }
    set title {}
    foreach n $allC {
      if {$plugin($n,c_name)==""} {
        wozLog WARNING [res::Str ana_w_noname $n] C
      }
      if {$plugin($n,c_title)==""} {
        wozLog ERROR [res::Str ana_e_notitle $n] C
        set ret 0
      }
      set lo [string tolower $plugin($n,c_title)]
      if {[lsearch -exact $title $lo]!=-1} {
        wozLog ERROR [res::Str ana_e_samectitle $n] C
        set ret 0
      } else {
        lappend title $lo
      }
    }
    set title {}
    foreach n $allQ {
      if {$plugin($n,q_init)==""} {
        wozLog WARNING [res::Str ana_w_noinit $n] Q
      }
      if {$plugin($n,q_title)==""} {
        wozLog ERROR [res::Str ana_e_notitle $n] Q
        set ret 0
      }
      set lo [string tolower $plugin($n,q_title)]
      if {[lsearch -exact $title $lo]!=-1} {
        wozLog ERROR [res::Str ana_e_sameqtitle $n] Q
        set ret 0
      } else {
        lappend title $lo
      }
    }

    # ------------------------------------------------------
    # check for missing event handlers
    foreach n $allQ {
      if {$plugin($n,q_nu3)!="" && $plugin($n,q_nu2)==""} {
        wozLog WARNING [res::Str ana_w_nu $n 3 2] Q
      } elseif {$plugin($n,q_nu2)!="" && $plugin($n,q_nu1)==""} {
        wozLog WARNING [res::Str ana_w_nu $n 2 1] Q
      } elseif {$plugin($n,q_nu3)!="" && $plugin($n,q_nu1)==""} {
        wozLog WARNING [res::Str ana_w_nu $n 3 1] Q
      }
      if {$plugin($n,q_nr3)!="" && $plugin($n,q_nr2)==""} {
        wozLog WARNING [res::Str ana_w_nr $n 3 2] Q
      } elseif {$plugin($n,q_nr2)!="" && $plugin($n,q_nr1)==""} {
        wozLog WARNING [res::Str ana_w_nr $n 2 1] Q
      } elseif {$plugin($n,q_nr3)!="" && $plugin($n,q_nr1)==""} {
        wozLog WARNING [res::Str ana_w_nr $n 3 1] Q
      }
      if {$plugin($n,q_tl3)!="" && $plugin($n,q_tl2)==""} {
        wozLog WARNING [res::Str ana_w_tl $n 3 2] Q
      } elseif {$plugin($n,q_tl2)!="" && $plugin($n,q_tl1)==""} {
        wozLog WARNING [res::Str ana_w_tl $n 2 1] Q
      } elseif {$plugin($n,q_tl3)!="" && $plugin($n,q_tl1)==""} {
        wozLog WARNING [res::Str ana_w_tl $n 3 1] Q
      }
    }

    # ------------------------------------------------------
    # check for nonexisting ref'd files
    foreach n $allP {
			foreach x $plugin(pix,phr) {
				set tmplist [play::getAudioFilenames $plugin($n,$x)]
				foreach tmp2 $tmplist {
					foreach tmp [split $tmp2 ,] {
						if {![file exists [ini::Str files.WavDir]/$tmp]} {
			        wozLog WARNING [res::Str ana_w_missingaudio $tmp $n $x] P
						}
					}
				}
				set tmplist [play::getPictureFilenames $plugin($n,$x)]
				foreach tmp2 $tmplist {
					foreach tmp [split $tmp2 ,] {
						if {![file exists [ini::Str files.WavDir]/$tmp]} {
			        wozLog WARNING [res::Str ana_w_missingpic $tmp $n $x] P
						}
					}
				}
			}
    }

    foreach n $allQ {
			foreach x $plugin(qix,phr) {
				set tmplist [play::getAudioFilenames $plugin($n,$x)]
				foreach tmp2 $tmplist {
					foreach tmp [split $tmp2 ,] {
						if {![file exists [ini::Str files.WavDir]/$tmp]} {
			        wozLog WARNING [res::Str ana_w_missingaudio $tmp $n $x] Q
						}
					}
				}
				set tmplist [play::getPictureFilenames $plugin($n,$x)]
				foreach tmp2 $tmplist {
					foreach tmp [split $tmp2 ,] {
						if {![file exists [ini::Str files.WavDir]/$tmp]} {
			        wozLog WARNING [res::Str ana_w_missingpic $tmp $n $x] Q
						}
					}
				}
			}
    }

    # ------------------------------------------------------
    # check sample calls
		foreach n $allS {
			set prev_id ""
			foreach turn $plugin($n,s_call) {
				set id [lindex $turn 0]
				if {[isPrompt $id] && $id!="Pnew"} {
					if {![promptExists $id]} {
		        wozLog WARNING [res::Str ana_w_sc_missing_p $id $n] S
		        set id ""
					} else {
						if {[lindex $turn 1]!=$plugin($id,p_prompt)} {
			        wozLog WARNING [res::Str ana_w_sc_changed_p $id $n] S
						}
						if {$prev_id!="" && ![isConnected $prev_id $id]} {
			        wozLog WARNING [res::Str ana_w_sc_missing_o $prev_id $id $n] S
						}
					}
				} elseif {$id!="Qnew"} {
					if {![questionExists $id]} {
		        wozLog WARNING [res::Str ana_w_sc_missing_q $id $n] S
		        set id ""
					} else {
						if {[lindex $turn 2]!=$plugin($id,[lindex $turn 1])} {
			        wozLog WARNING [res::Str ana_w_sc_changed_q $id $n] S
						}
						if {$prev_id!="" && ![isConnected $prev_id $id]} {
			        wozLog WARNING [res::Str ana_w_sc_missing_o $prev_id $id $n] S
						}
					}
				} else {
					set id ""
				}
				set prev_id $id
			}
		}


    set tmp {}
    foreach n $allC {
      if {$plugin($n,c_always)==1} {lappend tmp $n}
    }
    foreach n $allQ {
      set tmp [concat $tmp $plugin($n,q_concepts)]
    }
    set tmp [lsort -uniq $tmp]
    foreach n $allC {
      if {[lsearch -exact $tmp $n]==-1} {
        wozLog WARNING [res::Str ana_w_notused $n] C
      }
    }
  }

  # final message
  if {$ret==1} {
    wozLog HEADER [res::Str ana_i_fine] ALL
  } else {
    wozLog HEADER [res::Str ana_i_notfine] ALL
  }

  $widget(log) configure -state disabled
  if {$ret==0 || !$autoCloseOnSuccess} {
    ::vTcl:Toplevel:WidgetProc $widget(winlog) startmodal
  }
  return $ret
}

proc scAnalyze {{sList ""}} {
  # analyze sample call data, return 1 for no errors
  global widget plugin

  # fill the log window
  set w $widget(log)
  $widget(log) configure -state normal
  $w delete 0.0 end

	$w tag configure HEADER-ALL -foreground white  -background #404040 -font {Helvetica 10 bold}
  $w tag configure WARNING-S  -foreground black  -background [ini::Str Common.colorS]

	if {$sList==""} {
		set sList [allEntries S]
	}

  wozLog HEADER [res::Str ana_i_sc_header] ALL

  # ------------------------------------------------------
  # check sample calls
	foreach n $sList {
		foreach tmp [sampleCallWarnings $n] {
		  wozLog WARNING $tmp S
		}
	}

  # final message
  wozLog HEADER [res::Str ana_i_sc_end] ALL

  $widget(log) configure -state disabled
  ::vTcl:Toplevel:WidgetProc $widget(winlog) startmodal

  return 1
}

proc correctFN {fn} {
	regsub -all {[^a-zA-Z0-9 ._-]} $fn "" fn
	return $fn
}

proc noLF {str} {
  regsub -all "\n" $str " " str
  return $str
}

proc updateDiaLog {fn} {
  global plugin statusMsg

  set allP [allEntries P]
  set allQ [allEntries Q]

	# (1) rename the original file to *.bak
  # (2) open the backup file to patch it
  # (3) open the original file name for writing
  if {[catch {file copy -force $fn $fn.bak} statusMsg]} {return 0}
  if {[catch {set f [open $fn.bak r]} statusMsg]} {return 0}
  if {[catch {set o [open $fn w]} statusMsg]} {return 0}

	# loop over all lines
	while {![eof $f]} {
		set ll [gets $f]
		if {$ll!=""} {
			if {[string index $ll 0]=="#"} {
				puts $o "$ll"
			} else {
				set l [split $ll \t]
				if {[info exists plugin([lindex $l 0],[lindex $l 1])]} {
					set tmp [util::oneLine $plugin([lindex $l 0],[lindex $l 1])]
					puts $o "[lindex $l 0]\t[lindex $l 1]\t[lindex $l 2]\t$tmp"
				} else {
					puts $o $ll
				}
			}
		}
	}	

	close $o
  close $f
  set statusMsg [res::Str prjupdlog "$fn"]
  return 1
}

#######
#        #    #  #####    ####   #####    #####   ####
#         #  #   #    #  #    #  #    #     #    #
#####      ##    #    #  #    #  #    #     #     ####
#          ##    #####   #    #  #####      #         #
#         #  #   #       #    #  #   #      #    #    #
#######  #    #  #        ####   #    #     #     ####

proc wozExportStudioWorks {fn} {
  global plugin statusMsg

	# ask whether to remove filenames from prompts
	set remove [tk_messageBox -message [res::Str remove_fnames] -type yesno]

  set allP [allEntries P]
  set allQ [allEntries Q]

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}
	fconfigure $f -encoding utf-8

  # collect all exportable strings
  set exp {}

  foreach n $allP {
		foreach name {p_prompt} {
			set tmp $plugin($n,$name)
			if {$remove=="yes"} {set tmp [play::removeFilenames $tmp 0]}
			regsub -all "\n" $tmp "\\n" tmpplugin($n,$name)
			regsub -all "\t" $tmpplugin($n,$name) "\\t" tmpplugin($n,$name)
		}
   	if {$tmpplugin($n,p_prompt)!=""} {lappend exp "$n[ini::Str files.p_prompt]\n\n$tmpplugin($n,p_prompt)\n"}
  }

  foreach n $allQ {
		foreach name [concat $plugin(qix,vars) $plugin(qix,text)] {
			set tmp $plugin($n,$name)
			regsub -all -nocase "{REPROMPT}" $tmp "$plugin($n,q_init)" tmp
			if {$remove=="yes"} {set tmp [play::removeFilenames $tmp 0]}
			regsub -all "\n" $tmp "\\n" tmpplugin($n,$name)
			regsub -all "\t" $tmpplugin($n,$name) "\\t" tmpplugin($n,$name)
		}

		foreach tmp_n $plugin(qix,phr) {
			if {$tmpplugin($n,$tmp_n)!=""} {lappend exp "$n[ini::Str files.$tmp_n]\n\n$tmpplugin($n,$tmp_n)\n"}
		}
  }

  # remove double entries, sort, and export
  set exp [lsort -uniq $exp]
  if {[lindex $exp 0]==""} {set exp [lreplace $exp 0 0]}

	puts $f "Begin script\n"
  foreach n $exp {puts $f $n}
	puts $f "End script"

  close $f
  set statusMsg [res::Str prjexptxt "$fn"]
  return 1
}

proc wozExportPhraseList {fn} {
  global plugin statusMsg

	# ask whether to remove filenames from prompts
	set remove [tk_messageBox -message [res::Str remove_fnames] -type yesno]

  set allP [allEntries P]
  set allQ [allEntries Q]

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}
	fconfigure $f -encoding utf-8

	array unset double

  # collect all exportable strings
	puts $f "# all prompts"
  foreach n $allP {
		foreach name $plugin(pix,phr) {
			set tmp [util::oneLine $plugin($n,$name)]
			if {$remove=="yes"} {set tmp [play::removeFilenames $tmp 0]}
			if {[string trim $tmp]!=""} {
				set fn "$n[ini::Str files.$name][ini::Str files.audioExtension]"
				puts $f "$fn\t$tmp"
				if {[info exists double($tmp)]} {
					lappend double($tmp) $fn
				} else {
					set double($tmp) $fn
				}
			}
		}
  }
  foreach n $allQ {
		foreach name $plugin(qix,phr) {
			set tmp [util::oneLine $plugin($n,$name)]
			regsub -all -nocase "{REPROMPT}" $tmp "$plugin($n,q_init)" tmp
			if {$remove=="yes"} {set tmp [play::removeFilenames $tmp 0]}
			if {[string trim $tmp]!=""} {
				set fn "$n[ini::Str files.$name][ini::Str files.audioExtension]"
				puts $f "$fn\t$tmp"
				if {[info exists double($tmp)]} {
					lappend double($tmp) $fn
				} else {
					set double($tmp) $fn
				}
			}
		}
  }

	puts $f "\n# unique prompts"
	foreach n [lsort [array names double]] {
		puts $f "[join $double($n) ,]\t$n"
	}

  close $f
  set statusMsg [res::Str prjexpphr "$fn"]
  return 1
}

proc wozExportTclTk {fn} {
  global plugin statusMsg label options woz tcl_platform var

  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]

  # open the Tcl skeleton file
  if {[catch {set f [open [ini::Str files.TclTkSkelFile] r]} statusMsg]} {return 0}
  set tcl [read $f]
  close $f

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}

  # find the start prompt
  set start ""
  foreach n $allP {
    if {$plugin($n,p_start)==1} {
      set start $n
      break
    }
  }

  # replace slots
  set tmp [concat 	[array get plugin Q*,*] \
			[array get plugin P*,*] \
			[array get plugin O,*,*] \
			[array get plugin C*,*] ]

	# the export reads an ini file, but not a res file
	# therefore, res:: strings must be passed by text replacements

  set tcl [util::save_regsub_all "{VERSION}" $tcl [res::Str about]]
  set tcl [util::save_regsub_all "{VERSION_DATE}" $tcl [res::Str date]]

  set tcl [util::save_regsub_all "{PLUGINARRAY}" $tcl $tmp]
  set tcl [util::save_regsub_all "{LABELARRAY}" $tcl [array get label]]
  set tcl [util::save_regsub_all "{OPTIONSARRAY}" $tcl [array get options]]
  set tcl [util::save_regsub_all "{STARTPROMPT}" $tcl $start]
  set tcl [util::save_regsub_all "{WOZDIR}" $tcl $woz(DIR)/export]
  set tcl [util::save_regsub_all "{WAVDIR}" $tcl [file normalize [ini::Str files.wavDir]]]

  set tcl [util::save_regsub_all "{MENU_FILE}" $tcl [res::Str m_main_file]]
  set tcl [util::save_regsub_all "{MENU_RUN}"  $tcl [res::Str m_main_run]]
  set tcl [util::save_regsub_all "{MENU_HELP}" $tcl [res::Str m_main_help]]

  set tcl [util::save_regsub_all "{MENU_FILE_EXIT}" $tcl [res::Str m_file_exit]]
  set tcl [util::save_regsub_all "{MENU_RUN_RESTART}" $tcl [res::Str m_run_restart]]
  set tcl [util::save_regsub_all "{MENU_RUN_UNDO}" $tcl [res::Str m_run_undo]]
  set tcl [util::save_regsub_all "{MENU_RUN_REDO}" $tcl [res::Str m_run_redo]]
  set tcl [util::save_regsub_all "{MENU_RUN_EXC}" $tcl [res::Str m_run_exc]]
  set tcl [util::save_regsub_all "{MENU_RUN_RESTRICTIVE}"	$tcl [res::Str m_run_restrictive]]
  set tcl [util::save_regsub_all "{MENU_RUN_AUTOPLAY}" $tcl [res::Str m_run_autoplay]]
  set tcl [util::save_regsub_all "{MENU_RUN_AUTOSTOP}" $tcl [res::Str m_run_autostop]]
  set tcl [util::save_regsub_all "{MENU_RUN_TTS}" $tcl [res::Str m_run_tts]]
  set tcl [util::save_regsub_all "{MENU_RUN_TTS_ON}" $tcl $var(tts)]
  set tcl [util::save_regsub_all "{MENU_HELP_ABOUT}" $tcl [res::Str m_help_about]]

  set tcl [util::save_regsub_all "{TITLE_MAIN}" $tcl [res::Str win_main $plugin(name) [file tail $plugin(prj,loaded)]]]
  set tcl [util::save_regsub_all "{TITLE_EXC}"  $tcl [res::Str win_exc]]
  set tcl [util::save_regsub_all "{TITLE_PROMPT}"  $tcl [res::Str win_chaudio]]
  set tcl [util::save_regsub_all "{TTS_PROMPT}"  $tcl [res::Str win_entertts]]

  set tcl [util::save_regsub_all "{NU}"  $tcl [res::Str label_nu]]
  set tcl [util::save_regsub_all "{NR}"  $tcl [res::Str label_nr]]
  set tcl [util::save_regsub_all "{TL}"  $tcl [res::Str label_tl]]
  set tcl [util::save_regsub_all "{RE}"  $tcl [res::Str label_re]]

  set tcl [util::save_regsub_all "{TURNS}"   $tcl [res::Str turns]]

  puts $f $tcl
  close $f
  set statusMsg [res::Str prjexptcl "$fn"]
  return 1
}

proc wozExportVoiceXML {fn} {
  global plugin statusMsg label options woz

	proc _audioFileNames {names} {
		set ret1 {}
		set ret2 {}
		set ret3 {}
		set ret4 {}

		# remove ... from the file names
		set names [play::getAudioFilenames $names]
		foreach nnn $names {
			set tmp {}
			foreach nnnn [split $nnn ,] {
				if {$nnnn!="..."} {
					lappend tmp $nnnn
				}
			}
			if {$tmp!={}} {lappend ret1 $tmp}
		}
		
		# calc equidistant thresholds for randomization
		foreach nnn $ret1 {
			if {$nnn!={}} {
				set th [expr 1.0/(0.0+[llength $nnn])]
				set ix 1
				set tmplo {}
				set tmphi {}
				foreach nnnn $nnn {
					lappend tmplo [expr round(($ix-1)*$th*100-0)/100.0]
					lappend tmphi [expr round($ix*$th*100-0)/100.0]
					incr ix
				}
				lappend ret2 $tmplo
				lappend ret3 $tmphi
			}
		}

		# create a list of unique indices
		set ix 1
		foreach nnn $ret1 {
			lappend ret4 $ix
			incr ix
		}

		return [list $ret1 $ret2 $ret3 $ret4]
	}

	# remove filenames from prompts
	set remove "yes"

  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]

  # open the VXML skeleton file
  if {[catch {set f [open [ini::Str files.VxmlSkelFile] r]} statusMsg]} {return 0}
  set VXML [read $f]
  close $f

	# By default, no global VXML code is generated.
	# The comment of the welcome prompt may supersede.
	set global ""

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}
	fconfigure $f -encoding utf-8

  # ---------------------------------------------------------------------- PROMPTS
  # init the LIST:: lists
	set LIST [concat $plugin(pix,vars) $plugin(pix,text) "p_prompt_isvar" "p_previous" "p_cond" "p_cond_id" "p_prompt_file" "p_prompt_hiscore" "p_prompt_loscore" "p_prompt_ix"]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allP {
    foreach x [concat $plugin(pix,vars) $plugin(pix,text)] {
      if {$x=="p_start"} {
        if {$plugin($n,$x)==1} {
					set pStart $n
          lappend lTmp($x) [res::Str yes]
        } else {
          lappend lTmp($x) [res::Str no]
        }
			} elseif {$x=="p_follows"} {
				if {$plugin($n,p_endstate)==1} {
					lappend lTmp($x) {}
					lappend lTmp(p_cond) {}
					lappend lTmp(p_cond_id) {}
				} else {
					set cond {}
					set cond_id {}
					# (1) all connections with conditions
					foreach tmp $plugin($n,p_follows) {
						if {[info exists plugin(O,$n,$tmp)] && [ini::Str VoiceXML.generateCondition]==1 && $plugin(O,$n,$tmp)!=""} {
							lappend cond [util::save_regsub_all_nocase "{VALUE:Q(\[0-9\]\[0-9\]\[0-9\])}" $plugin(O,$n,$tmp) "global_Q\\1"]
							lappend cond_id $tmp
						}
					}
					# (2) all connections without conditions
					foreach tmp $plugin($n,p_follows) {
						if {!([info exists plugin(O,$n,$tmp)] && [ini::Str VoiceXML.generateCondition]==1 && $plugin(O,$n,$tmp)!="")} {
							lappend cond "true"
							lappend cond_id $tmp
						}
					}
					lappend lTmp($x) $plugin($n,p_follows)
					lappend lTmp(p_cond) $cond
					lappend lTmp(p_cond_id) $cond_id
				}
			} elseif {$x=="p_prompt_bi"} {
        lappend lTmp($x) [boolean $plugin($n,$x)]
			} elseif {$x=="p_vxml"} {
				if {$plugin($n,$x)==1} {
					# special case: the vxml block of the welcome prompt becomes global code
					if {$plugin($n,p_start)==1} {
						set global $plugin($n,p_memo)
		        lappend lTmp($x) ""
					} else {
		        lappend lTmp($x) [list $plugin($n,p_memo)]
					}
	      } else {
	        lappend lTmp($x) ""
	      }
      } else {
				set tmp [string trim $plugin($n,$x)]
				set names [_audioFileNames $tmp]
				if {$remove=="yes"} {set tmp [play::removeFilenames $tmp 0]}
				if {$tmp=="" && [res::Exists vxml_def_$x]} {
					set tmp [res::Str vxml_def_$x]
					# recalc names from the default entry if no names have been found yet
					if {$names=={}} {
						set names [_audioFileNames $tmp]
					}
				}
				set xtmp [util::xmlSave $tmp " " " "]
				regsub -all -nocase "{VALUE:Q(\[0-9\]\[0-9\]\[0-9\])}" $xtmp "<value expr=\"global_Q\\1\"/>" xtmp
				if {$x=="p_title"} {regsub -all " " $xtmp "_" xtmp}

				# special handling of prompts
				if {$x=="p_prompt"} {
					# create the text prompt
					if {[ini::Str VoiceXML.ttsStrategy]!="audio_only"} {
		        lappend lTmp($x) $xtmp
		       } else {
		        lappend lTmp($x) " "
		       }
	
					# create the audio prompts
					if {[ini::Str VoiceXML.ttsStrategy]!="tts_only"} {
						lappend lTmp(p_prompt_file) [concat [objectStandardAudioFilename $n $x] [lindex $names 0]]
						lappend lTmp(p_prompt_loscore) [concat -1 [lindex $names 1]]
						lappend lTmp(p_prompt_hiscore) [concat 1 [lindex $names 2]]
						lappend lTmp(p_prompt_ix) [concat 0 [lindex $names 3]]
					}

					# create the variable flag
					lappend lTmp(p_prompt_isvar) [boolean [expr	[regexp -nocase "\{value" $plugin($n,$x)]||\
																											[regexp -nocase "\{inline" $plugin($n,$x)]]]
				} else {
	        lappend lTmp($x) $xtmp
				}
      }
    }
    lappend lTmp(p_previous) [calcPredecessors $n]
  }

  # store the lists
  set rpList {}
  set byList {}

  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set VXML [replace::repString $VXML $rpList $byList "PSUB" 0]

  # ---------------------------------------------------------------------- QUESTIONS
  # init the LIST:: lists
  set LIST [concat $plugin(qix,vars) $plugin(qix,text) "q_previous" "q_cond" "q_cond_id" "q_conf"]
  foreach x $LIST {
    set lTmp($x) {}
    set lTmp([set x]_file) {}
    set lTmp([set x]_loscore) {}
    set lTmp([set x]_hiscore) {}
    set lTmp([set x]_ix) {}
    set lTmp([set x]_isvar) {}
  }

  # build the lists
  foreach n $allQ {
    foreach x [concat $plugin(qix,vars) $plugin(qix,text)] {
			if {[string range $x end-2 end]=="_bi"} {
        lappend lTmp($x) [boolean $plugin($n,$x)]
			} elseif {$x=="q_vxml"} {
				if {$plugin($n,$x)==1} {
	        lappend lTmp($x) [list $plugin($n,q_memo)]
	      } else {
	        lappend lTmp($x) ""
	      }
			} elseif {$x=="q_follows"} {
				if {$plugin($n,q_endstate)==1} {
					lappend lTmp($x) {}
					lappend lTmp(q_cond) {}
					lappend lTmp(q_cond_id) {}
				} else {
					set cond {}
					set cond_id {}
					# (1) all connections with conditions
					foreach tmp $plugin($n,q_follows) {
						if {[info exists plugin(O,$n,$tmp)] && [ini::Str VoiceXML.generateCondition]==1 && $plugin(O,$n,$tmp)!=""} {
							set tmp2 [util::save_regsub_all_nocase "{VALUE}" $plugin(O,$n,$tmp) field_$n]
							set tmp2 [util::save_regsub_all_nocase "{VALUE:Q(\[0-9\]\[0-9\]\[0-9\])}" $tmp2 "global_Q\\1"]
							lappend cond $tmp2
							lappend cond_id $tmp
						}
					}
					# (2) all connections without conditions
					foreach tmp $plugin($n,q_follows) {
						if {!([info exists plugin(O,$n,$tmp)] && [ini::Str VoiceXML.generateCondition]==1 && $plugin(O,$n,$tmp)!="")} {
							lappend cond "true"
							lappend cond_id $tmp
						}
					}
					lappend lTmp($x) $plugin($n,q_follows)
					lappend lTmp(q_cond) $cond
					lappend lTmp(q_cond_id) $cond_id
				}
			} elseif {$x!="q_concepts"} {
				set tmp [string trim $plugin($n,$x)]
				regsub -all -nocase "{REPROMPT}" $tmp "$plugin($n,q_init)" xtmp
				set names [_audioFileNames $xtmp]
				if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
				if {$xtmp=="" && [res::Exists vxml_def_$x]} {
					set xtmp [res::Str vxml_def_$x]
					regsub -all -nocase "{REPROMPT}" $xtmp "$plugin($n,q_init)" xtmp
					# recalc names from the default entry if no names have been found yet
					if {$names=={}} {
						set names [_audioFileNames $xtmp]
					}
					if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
				}
				set xtmp [util::xmlSave $xtmp " " " "]
				regsub -all -nocase "{VALUE}" $xtmp "<value expr=\"field_$n\"/>" xtmp
				regsub -all -nocase "{VALUE:Q(\[0-9\]\[0-9\]\[0-9\])}" $xtmp "<value expr=\"global_Q\\1\"/>" xtmp
				if {$x=="q_title"} {regsub -all " " $xtmp "_" xtmp}

				# special handling of prompts
				if {[lsearch {q_init q_nu1 q_nu2 q_nu3 q_nr1 q_nr2 q_nr3 q_tl1 q_tl2 q_tl3 q_ctxhelp} $x]!=-1} {
					# create the text prompt
					if {[ini::Str VoiceXML.ttsStrategy]!="audio_only"} {
			      lappend lTmp($x) $xtmp
					} else {
						lappend lTmp($x) " "
					}
	
					# create the audio prompts
					if {[ini::Str VoiceXML.ttsStrategy]!="tts_only"} {
						lappend lTmp([set x]_file) [concat [objectStandardAudioFilename $n $x] [lindex $names 0]]
						lappend lTmp([set x]_loscore) [concat -1 [lindex $names 1]]
						lappend lTmp([set x]_hiscore) [concat 1 [lindex $names 2]]
						lappend lTmp([set x]_ix) [concat 0 [lindex $names 3]]
					}

					# create the variable flag
					lappend lTmp([set x]_isvar) [boolean [expr	[regexp -nocase "\{value" $plugin($n,$x)]||\
																											[regexp -nocase "\{inline" $plugin($n,$x)]]]
				} else {
	        lappend lTmp($x) $xtmp
				}
			}
    }
    lappend lTmp(q_previous) [calcPredecessors $n]
    lappend lTmp(q_concepts) [calcActiveConcepts $n]

		# if the confirmation string is empty, no confirmation will be generated
		if {$plugin($n,q_tl1)==""} {
			lappend lTmp(q_conf) "0.0"
		} else {
			lappend lTmp(q_conf) [ini::Str VoiceXML.confirmConfidence]
		}
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
    lappend rpList "{LIST::[set x]_file}"
    lappend byList $lTmp([set x]_file)
    lappend rpList "{LIST::[set x]_loscore}"
    lappend byList $lTmp([set x]_loscore)
    lappend rpList "{LIST::[set x]_hiscore}"
    lappend byList $lTmp([set x]_hiscore)
    lappend rpList "{LIST::[set x]_ix}"
    lappend byList $lTmp([set x]_ix)
    lappend rpList "{LIST::[set x]_isvar}"
    lappend byList $lTmp([set x]_isvar)
  }

  # perform the replacement
  set VXML [replace::repString $VXML $rpList $byList "QSUB" 0]

  # ---------------------------------------------------------------------- STR::
  # fill the list of STR replacements
  set rpList {}
  set byList {}
  
  lappend rpList "{STR::Date}"
  lappend byList "[date::nowS]"

  lappend rpList "{STR::Project}"
  lappend byList "$plugin(name)"

  lappend rpList "{STR::DialogId}"
  lappend byList "WOz"

  lappend rpList "{STR::IntroPromptId}"
  lappend byList $pStart

  lappend rpList "{STR::FileName}"
  lappend byList "[file tail $plugin(prj,loaded)]"

  lappend rpList "{STR::FilePath}"
  lappend byList "$plugin(prj,loaded)"

  lappend rpList "{STR::Version}"
  lappend byList "[res::Str about]"

  lappend rpList "{STR::VersionDate}"
  lappend byList "[res::Str date]"

  lappend rpList "{STR::Comment}"
  lappend byList "[ini::Str Files.Comment]"

  lappend rpList "{STR::LanguageID}"
  lappend byList "$plugin(language)"

  lappend rpList "{STR::VxmlVersion}"
  lappend byList "[ini::Str VoiceXML.vxmlVersion]"

  lappend rpList "{STR::GlobalCode}"
  lappend byList "$global"

  lappend rpList "{STR::Prefix}"
	set pre [file rootname [file tail $fn]]
  lappend byList "$pre"

  set VXML [replace::repString $VXML $rpList $byList "SOMETHING" 0]

  puts $f $VXML
  close $f

  # ---------------------------------------------------------------------- CONCEPTS
	# each concept becomes one file in the same directory as the VXML file
	set dir [file dirname $fn]
  foreach n $allC {
		set fn "grammar_$n.grxml"
    if {[catch {set f [open $dir/[set pre]_$fn w]} statusMsg]} {return 0}
		fconfigure $f -encoding utf-8

		# the grammar strategy determines how to process grammars:
		#		do_nothing and use_skeleton		copy the contents of the concept
		#		bnf_2_srgs										parse the contents and replace GRM_ROOT_RULE in the skeleton file
		switch [ini::Str VoiceXML.grammarStrategy] {
			"use_skeleton"	{set tmp $plugin($n,c_memo)}
			"do_nothing"		{set tmp $plugin($n,c_memo)}
			"bnf_2_srgs"		{
				# if the grammar is already XML, use it
				if {[string range $plugin($n,c_memo) 0 5]=="<?xml "} {
					set tmp $plugin($n,c_memo)
				} else {
					set tmp [BNF2SRGS $n $plugin($n,c_memo) 1]
				}
			}
		}

		puts $f $tmp
		close $f
  }

  set statusMsg [res::Str prjexpvxml "$fn"]
  return 1
}

proc wozExportRTF {dir} {
  global plugin statusMsg

	# ask whether to remove filenames from prompts
	set remove [tk_messageBox -message [res::Str remove_fnames] -type yesno]

  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]
  set allS [allEntries S]

  # read the RTF skeleton files for prompts and questions
  if {[catch {set f [open [ini::Str files.RTFskelFileP] r]} statusMsg]} {return 0}
  set rtfP [read $f]
  close $f
  if {[catch {set f [open [ini::Str files.RTFskelFileQ] r]} statusMsg]} {return 0}
  set rtfQ [read $f]
  close $f
  if {[catch {set f [open [ini::Str files.RTFskelFileC] r]} statusMsg]} {return 0}
  set rtfC [read $f]
  close $f
  if {[catch {set f [open [ini::Str files.RTFskelFileS] r]} statusMsg]} {return 0}
  set rtfS [read $f]
  close $f

  # create the necessary export dir if necessary
  if {![file exists $dir]} {
    if {[catch {file mkdir $dir} statusMsg]} {return 0}
  }
  
  # ---------------------------------------------------------------------- PROMPTS
  # loop over all prompts
  foreach n $allP {
    # create the output
	  set tmp $rtfP

		# loop over the texts
		foreach name $plugin(pix,text) {
			set xtmp $plugin($n,$name)
			if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
		}

		# loop over the yesno variables
		set ix 0
		foreach name $plugin(pix,vars) {
			if {[lindex $plugin(pix,yesno) $ix]==1} {
				set xtmp $plugin($n,$name)
				if {$xtmp==0} {
					set xtmp [res::Str no]
				} else {
					set xtmp [res::Str yes]
				}
				regsub -all "_" $name "-" namex
				set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
			}
			incr ix
		}

		# special: follow ups (add condition information to each)
		set tmpfu {}
		foreach fu [calcSuccessors $n] {
			if {[info exists plugin(O,$n,$fu)]} {
				append tmpfu "$fu - [id2title [list $fu]] ($plugin(O,$n,$fu))\{\\par\\par\}"
			} else {
				append tmpfu "$fu - [id2title [list $fu]]\{\\par\\par\}"
			}
		}
    set tmp [util::save_regsub_all_nocase "<<P-Followups>>" $tmp $tmpfu]

		# special: predecessors
		set tmpfu {}
		foreach fu [calcPredecessors $n] {
			if {[info exists plugin(O,$fu,$n)]} {
				append tmpfu "$fu - [id2title [list $fu]] ($plugin(O,$fu,$n))\{\\par\\par\}"
			} else {
				append tmpfu "$fu - [id2title [list $fu]]\{\\par\\par\}"
			}
		}
    set tmp [util::save_regsub_all_nocase "<<P-Predecessors>>" $tmp $tmpfu]

		# loop over the other vars
		foreach name $plugin(pix,vars) {
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $plugin($n,$name)]
		}

    # write the output
    set cfn "$n [correctFN $plugin($n,p_title)]"
    if {[catch {set f [open $dir/$cfn[ini::Str files.rtfExt] w]} statusMsg]} {return 0}
    puts $f $tmp
    close $f
  }

  # ---------------------------------------------------------------------- QUESTIONS
  # loop over all questions
  foreach n $allQ {
    # create the output
	  set tmp $rtfQ

		# loop over the texts
		foreach name $plugin(qix,text) {
			set xtmp $plugin($n,$name)
			regsub -all -nocase "{REPROMPT}" $xtmp "$plugin($n,q_init)" xtmp
			if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
		}

		# loop over the yesno variables
		set ix 0
		foreach name $plugin(qix,vars) {
			if {[lindex $plugin(qix,yesno) $ix]==1} {
				set xtmp $plugin($n,$name)
				if {$xtmp==0} {
					set xtmp [res::Str no]
				} else {
					set xtmp [res::Str yes]
				}
				regsub -all "_" $name "-" namex
				set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
			}
			incr ix
		}

		# special: active concepts (must be computed)
		set tmpfu {}
		foreach fu [calcActiveConcepts $n] {
			append tmpfu "$fu - [id2title [list $fu]]\{\\par\\par\}"
		}
    set tmp [util::save_regsub_all_nocase "<<Q-Concepts>>" $tmp $tmpfu]

		# special: follow ups (add condition information to each)
		set tmpfu {}
		foreach fu [calcSuccessors $n] {
			if {[info exists plugin(O,$n,$fu)]} {
				append tmpfu "$fu - [id2title [list $fu]] ($plugin(O,$n,$fu))\{\\par\\par\}"
			} else {
				append tmpfu "$fu - [id2title [list $fu]]\{\\par\\par\}"
			}
		}
    set tmp [util::save_regsub_all_nocase "<<Q-Followups>>" $tmp $tmpfu]

		# special: predecessors
		set tmpfu {}
		foreach fu [calcPredecessors $n] {
			if {[info exists plugin(O,$fu,$n)]} {
				append tmpfu "$fu - [id2title [list $fu]] ($plugin(O,$fu,$n))\{\\par\\par\}"
			} else {
				append tmpfu "$fu - [id2title [list $fu]]\{\\par\\par\}"
			}
		}
    set tmp [util::save_regsub_all_nocase "<<Q-Predecessors>>" $tmp $tmpfu]

		# loop over the other vars
		foreach name $plugin(qix,vars) {
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $plugin($n,$name)]
		}

    # write the output
    set cfn "$n [correctFN $plugin($n,q_title)]"
    if {[catch {set f [open $dir/$cfn[ini::Str files.rtfExt] w]} statusMsg]} {return 0}
    puts $f $tmp
    close $f
  }

  # ---------------------------------------------------------------------- CONCEPTS
  # loop over all concepts
  foreach n $allC {
    # create the output
	  set tmp $rtfC

		# loop over the texts
		foreach name $plugin(cix,text) {
			set xtmp $plugin($n,$name)
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
		}

		# loop over the yesno variables
		set ix 0
		foreach name $plugin(cix,vars) {
			if {[lindex $plugin(cix,yesno) $ix]==1} {
				set xtmp $plugin($n,$name)
				if {$xtmp==0} {
					set xtmp [res::Str no]
				} else {
					set xtmp [res::Str yes]
				}
				regsub -all "_" $name "-" namex
				set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
			}
			incr ix
		}

		set tmpfu {}
		foreach fu [calcUsedBy $n] {
			append tmpfu "$fu - [id2title [list $fu]]\{\\par\\par\}"
		}
    set tmp [util::save_regsub_all_nocase "<<C-UsedBy>>" $tmp $tmpfu]

		# loop over the other vars
		foreach name $plugin(cix,vars) {
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $plugin($n,$name)]
		}

    # write the output
    set cfn "$n [correctFN $plugin($n,c_title)]"
    if {[catch {set f [open $dir/$cfn[ini::Str files.rtfExt] w]} statusMsg]} {return 0}
    puts $f $tmp
    close $f
  }

  # ---------------------------------------------------------------------- SAMPLE CALLS
  # loop over all sample calls
  foreach n $allS {
    # create the output
	  set tmp $rtfS

		# loop over the texts
		foreach name $plugin(six,text) {
			set xtmp $plugin($n,$name)
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
		}

		# loop over the yesno variables
		set ix 0
		foreach name $plugin(six,vars) {
			if {[lindex $plugin(six,yesno) $ix]==1} {
				set xtmp $plugin($n,$name)
				if {$xtmp==0} {
					set xtmp [res::Str no]
				} else {
					set xtmp [res::Str yes]
				}
				regsub -all "_" $name "-" namex
				set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $xtmp]
			}
			incr ix
		}

		# special: call
		set tmpfu {}
		foreach fu $plugin($n,s_call) {
			set fun [lindex $fu 0]
			if {[isPrompt $fun]} {
				append tmpfu "System Prompt $fun: [lindex $fu 1]\{\\par\\par\}"
			} else {
				append tmpfu "System Question $fun.[lindex $fu 1]: [lindex $fu 2]\{\\par\\par\}"
				append tmpfu "Caller.[lindex $fu 3]: [lindex $fu 4]\{\\par\\par\}"
			}
		}
		if {$remove=="yes"} {set tmpfu [play::removeFilenames $tmpfu 0]}
    set tmp [util::save_regsub_all_nocase "<<S-Call>>" $tmp $tmpfu]

		# loop over the other vars
		foreach name $plugin(six,vars) {
			regsub -all "_" $name "-" namex
			set tmp [util::save_regsub_all_nocase "<<$namex>>" $tmp $plugin($n,$name)]
		}

    # write the output
    set sfn "$n [correctFN $plugin($n,s_name)]"
    if {[catch {set f [open $dir/$sfn[ini::Str files.rtfExt] w]} statusMsg]} {return 0}
    puts $f $tmp
    close $f
  }

  set statusMsg [res::Str prjexprtf "$dir" "[expr [llength $allP]+[llength $allQ]+[llength $allC]+[llength $allS]]"]
  return 1
}

proc wozExportOSDM {dir} {
  global plugin statusMsg

  set allQ [allEntries Q]

  # read the OSDM skeleton files for properties and tuning settings
  if {[catch {set f [open [ini::Str files.OSDMskelFile] r]} statusMsg]} {return 0}
  set OSDM [read $f]
  close $f
  if {[catch {set f [open [ini::Str files.OSDMTskelFile] r]} statusMsg]} {return 0}
  set OSDMT [read $f]
  close $f

  # create the necessary export dir if necessary
  if {![file exists $dir]} {
    if {[catch {file mkdir $dir} statusMsg]} {return 0}
  }
  
  # ---------------------------------------------------------------------- QUESTIONS
  # loop over all questions
  foreach n $allQ {
	  set rpList {}
	  set byList {}
  
		# loop over the texts
		foreach name $plugin(qix,text) {
			set xtmp ""
			foreach sf [play::getAudioFilenames $plugin($n,$name)] {
				set sf [lindex [split $sf ","] 0]
				append xtmp "|$sf"
			}
			set xtmp [string replace $xtmp 0 0]
			if {$xtmp==""} {set xtmp "none"}
		  lappend rpList "{STR::[set name]_Prompts}"
		  lappend byList $xtmp
		}

		set fn ""
		foreach name {q_id q_title} {
		  lappend rpList "{STR::$name}"
			regsub -all {[^a-zA-Z0-9_-]} $plugin($n,$name) "" xtmp
		  lappend byList $xtmp
		  append fn _$xtmp
		}
		set fn [string replace $fn 0 0]

		# calc number of noinput's
		set xtmp 3
		if {$plugin($n,q_nr3)==""} {
			set xtmp 2
		} elseif {$plugin($n,q_nr2)==""} {
			set xtmp 1
		} elseif {$plugin($n,q_nr1)==""} {
			set xtmp 1
		}
	  lappend rpList "{STR::Q_num_nr}"
	  lappend byList $xtmp

		# calc number of nomatch's
		set xtmp 3
		if {$plugin($n,q_nu3)==""} {
			set xtmp 2
		} elseif {$plugin($n,q_nu2)==""} {
			set xtmp 1
		} elseif {$plugin($n,q_nu1)==""} {
			set xtmp 1
		}
	  lappend rpList "{STR::Q_num_nu}"
	  lappend byList $xtmp

	  lappend rpList "{STR::Project}"
	  lappend byList "$plugin(name)"

	  lappend rpList "{STR::Q_Conf}"
		lappend byList [ini::Str VoiceXML.confirmConfidence]

	  lappend rpList "{STR::Q_Init_Bi}"
		lappend byList [boolean $plugin($n,q_init_bi)]

		set f [open $dir/$fn.properties w]
		fconfigure $f -encoding utf-8
	  set tmp [replace::repString $OSDM $rpList $byList "CSUB" 0]
	  puts $f $tmp
	  close $f
	
		set f [open $dir/[set fn]_tuning.properties w]
		fconfigure $f -encoding utf-8
	  set tmp [replace::repString $OSDMT $rpList $byList "CSUB" 0]
	  puts $f $tmp
	  close $f
  }

  set statusMsg [res::Str prjexposdm "$dir" "[expr 2*[llength $allQ]]"]
  return 1
}

proc wozExportSampleCalls {dir} {
  global plugin statusMsg

	# ask whether to remove filenames from prompts
	set remove [tk_messageBox -message [res::Str remove_fnames] -type yesno]

  set allS [allEntries S]

  # create the necessary export dir if necessary
  if {![file exists $dir]} {
    if {[catch {file mkdir $dir} statusMsg]} {return 0}
  }
  
  # loop over all sample calls
  foreach n $allS {
    # create the output
    set tmp {}

		foreach turn $plugin($n,s_call) {
			set id [lindex $turn 0]
			if {[isPrompt $id]} {
				append tmp "$id\tp_prompt\tSystem\t[util::oneLine [lindex $turn 1]]\n"
			} else {
				append tmp "$id\t[lindex $turn 1]\tSystem\t[util::oneLine [lindex $turn 2]]\n"
				append tmp "\t[lindex $turn 3]\tCaller\t[util::oneLine [lindex $turn 4]]\n"
			}
		}
		if {$remove=="yes"} {set tmp [play::removeFilenames $tmp 0]}
		
    # write the output
    set sfn "$n [correctFN $plugin($n,s_name)]"
    if {[catch {set f [open $dir/$sfn[ini::Str files.scExt] w]} statusMsg]} {return 0}
		fconfigure $f -encoding utf-8
    puts $f $tmp
    close $f
  }

  set statusMsg [res::Str prjexpscall "$dir" "[llength $allS]"]
  return 1
}

proc wozExportAudio {dir} {
  global plugin statusMsg

  set allS [allEntries S]

  # create the necessary export dir if necessary
  if {![file exists $dir]} {
    if {[catch {file mkdir $dir} statusMsg]} {return 0}
  }
  
  # loop over all sample calls
  foreach n $allS {
    # create the output
		set audio [createSoundObjectFromSampleCall $n 1]
		if {$audio!=""} {
	    # write the output
	    set sfn "$n [correctFN $plugin($n,s_name)]"
	    if {[catch {$audio write $dir/$sfn[ini::Str files.audExt]} statusMsg]} {return 0}
			$audio destroy
		}
  }

  set statusMsg [res::Str prjexpaudio "$dir" "[llength $allS]"]
  return 1
}

proc wozExportPostscript {fn} {
  global plugin statusMsg widget

  # dump the postscript representation to file
  graf::Canvas2PS $widget(canvas) $fn

  set statusMsg [res::Str prjexpps "$fn"]
  return 1
}

proc wozExportGIF {fn} {
  global plugin statusMsg widget

  # dump the postscript representation to file
  layout2image $fn gif

  set statusMsg [res::Str prjexpgif "$fn"]
  return 1
}

proc wozExportXML {fn} {
  global plugin statusMsg label options woz

	# remove filenames from prompts
	set remove "no"

  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]
  set allS [allEntries S]
  set allO [array names plugin O,*]

  # open the XML skeleton file
  if {[catch {set f [open [ini::Str files.XmlSkelFile] r]} statusMsg]} {return 0}
  set XML [read $f]
  close $f

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}
	fconfigure $f -encoding utf-8

  # ---------------------------------------------------------------------- PROMPTS
  # init the LIST:: lists
  set LIST [concat $plugin(pix,vars) $plugin(pix,text) "p_previous" "p_cond" p_x p_y]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allP {
    foreach x [concat $plugin(pix,vars) $plugin(pix,text) x y] {
			if {$x=="p_follows"} {
				set cond {}
				foreach tmp $plugin($n,p_follows) {
					if {[info exists plugin(O,$n,$tmp)] && $plugin(O,$n,$tmp)!=""} {
						lappend cond $plugin(O,$n,$tmp)
					}
				}
				lappend lTmp($x) $plugin($n,p_follows)
				lappend lTmp(p_cond) $cond
      } elseif {$x=="x"} {
				lappend lTmp(p_x) $plugin($n,$x)
      } elseif {$x=="y"} {
				lappend lTmp(p_y) $plugin($n,$x)
      } else {
				if {[lsearch -exact $plugin(pix,text) $x]!=-1 && $x!="p_memo"} {
					set xtmp [util::xmlSaveCDATA $plugin($n,$x)]
				} else {
					set xtmp [util::xmlSave $plugin($n,$x)]
				}
				if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
        lappend lTmp($x) $xtmp
      }
    }
    lappend lTmp(p_previous) [calcPredecessors $n]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XML [replace::repString $XML $rpList $byList "PSUB" 0]

  # ---------------------------------------------------------------------- QUESTIONS
  # init the LIST:: lists
  set LIST [concat $plugin(qix,vars) $plugin(qix,text) "q_previous" "q_cond" "q_conf" q_x q_y]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allQ {
    foreach x [concat $plugin(qix,vars) $plugin(qix,text) x y] {
			if {$x=="q_follows"} {
				set cond {}
				foreach tmp $plugin($n,q_follows) {
					if {[info exists plugin(O,$n,$tmp)] && $plugin(O,$n,$tmp)!=""} {
						lappend cond $plugin(O,$n,$tmp)
					}
				}
				lappend lTmp($x) $plugin($n,q_follows)
				lappend lTmp(q_cond) $cond
      } elseif {$x=="x"} {
				lappend lTmp(q_x) $plugin($n,$x)
      } elseif {$x=="y"} {
				lappend lTmp(q_y) $plugin($n,$x)
			} elseif {$x!="q_concepts"} {
				if {[lsearch -exact $plugin(qix,text) $x]!=-1 && $x!="q_memo"} {
					set xtmp [util::xmlSaveCDATA $plugin($n,$x)]
				} else {
					set xtmp [util::xmlSave $plugin($n,$x)]
				}
				if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
	      lappend lTmp($x) $xtmp
			}
    }
    lappend lTmp(q_previous) [calcPredecessors $n]
    lappend lTmp(q_concepts) [calcActiveConcepts $n]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XML [replace::repString $XML $rpList $byList "QSUB" 0]

  # ---------------------------------------------------------------------- CONCEPTS
  # init the LIST:: lists
  set LIST [concat $plugin(cix,vars) $plugin(cix,text)]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allC {
    foreach x [concat $plugin(cix,vars) $plugin(cix,text)] {
			if {[lsearch -exact $plugin(cix,text) $x]!=-1} {
				set xtmp [util::xmlSaveCDATA $plugin($n,$x)]
			} else {
				set xtmp [util::xmlSave $plugin($n,$x)]
			}
      lappend lTmp($x) $xtmp
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XML [replace::repString $XML $rpList $byList "CSUB" 0]

  # ---------------------------------------------------------------------- SAMPLE CALLS
  # init the LIST:: lists
  set LIST [concat $plugin(six,vars) $plugin(six,text) s_pid s_ptext s_qid s_qtext s_qctx s_qcctx s_qcaller s_pseq s_qseq]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allS {
    foreach x [concat $plugin(six,vars) $plugin(six,text)] {
			if {$x=="s_call"} {
				set pseq {}
				set pid {}
				set ptext {}

				set qseq {}
				set qid {}
				set qtext {}
				set qctx {}
				set qcctx {}
				set qcaller {}

				set ix 0
				foreach turn $plugin($n,$x) {
					if {[isPrompt [lindex $turn 0]]} {
						lappend pseq $ix

						lappend pid [lindex $turn 0]
						lappend ptext [util::xmlSaveCDATA [lindex $turn 1]]
					} else {
						lappend qseq $ix

						lappend qid [lindex $turn 0]
						lappend qctx [lindex $turn 1]
						lappend qtext [util::xmlSaveCDATA [lindex $turn 2]]
						lappend qcctx [lindex $turn 3]
						lappend qcaller [util::xmlSaveCDATA [lindex $turn 4]]
					}
					incr ix
				}
				lappend lTmp($x) $plugin($n,$x)

				lappend lTmp(s_pseq) $pseq
				lappend lTmp(s_pid) $pid
				lappend lTmp(s_ptext) $ptext

				lappend lTmp(s_qseq) $qseq
				lappend lTmp(s_qid) $qid
				lappend lTmp(s_qtext) $qtext
				lappend lTmp(s_qctx) $qctx
				lappend lTmp(s_qcctx) $qcctx
				lappend lTmp(s_qcaller) $qcaller
			} else {
				if {[lsearch -exact $plugin(six,text) $x]!=-1} {
					set xtmp [util::xmlSaveCDATA $plugin($n,$x)]
				} else {
					set xtmp [util::xmlSave $plugin($n,$x)]
				}
	      lappend lTmp($x) $xtmp
			}
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XML [replace::repString $XML $rpList $byList "SSUB" 0]

  # ---------------------------------------------------------------------- CONN DATA
  # init the LIST:: lists
  set LIST [list o_from o_to o_memo]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allO {
		if {$plugin($n)!=""} {
			set tmp [split $n ,]
			lappend lTmp(o_from) [lindex $tmp 1]
			lappend lTmp(o_to) [lindex $tmp 2]
			lappend lTmp(o_memo) [util::xmlSaveCDATA $plugin($n)]
		}
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XML [replace::repString $XML $rpList $byList "OSUB" 0]

  # ---------------------------------------------------------------------- STR::
  # fill the list of STR replacements
  set rpList {}
  set byList {}
  
  lappend rpList "{STR::Date}"
  lappend byList "[date::nowS]"

  lappend rpList "{STR::Project}"
  lappend byList "[util::xmlSave $plugin(name)]"

  lappend rpList "{STR::FileName}"
  lappend byList "[file tail $plugin(prj,loaded)]"

  lappend rpList "{STR::FilePath}"
  lappend byList "$plugin(prj,loaded)"

  lappend rpList "{STR::Version}"
  lappend byList "[util::xmlSave [res::Str about]]"

  lappend rpList "{STR::VersionDate}"
  lappend byList "[res::Str date]"

  lappend rpList "{STR::Comment}"
  lappend byList "[util::xmlSave [ini::Str Files.Comment]]"

  lappend rpList "{STR::LanguageID}"
  lappend byList "$plugin(language)"

  lappend rpList "{STR::Prefix}"
	set pre [file rootname [file tail $fn]]
  lappend byList "$pre"

  set XML [replace::repString $XML $rpList $byList "SOMETHING" 0]

  puts $f $XML
  close $f

  set statusMsg [res::Str prjexpxml "$fn"]
  return 1
}

proc wozExportGML {fn} {
  global plugin statusMsg label options woz

	proc _numId {id} {
		if {[isPrompt $id]} {
			return [expr 1000+[util::noNullNum [string range $id 1 end]]]
		} else {
			return [expr 2000+[util::noNullNum [string range $id 1 end]]]
		}
	}

	proc _GMLsave {str len} {
		regsub -all {\n} $str " " ret
		regsub -all {&amp;&amp;} $ret " and " ret
		regsub -all {&lt;} $ret "<" ret
		regsub -all {&gt;} $ret ">" ret
		regsub -all {\|\|} $ret " or " ret
#		regsub -all {[^A-Za-z0-9 _<>=!+()*/-]} $ret " " ret
		regsub -all {"} $ret "'" ret
		regsub -all "  " $ret " " ret
		if {$len>0 && [string length $ret]>$len} {
			set ret "[string range $ret 0 $len]..."
		}
		return [string trim $ret]
	}

	proc _GMLwrap {str} {
		set str [_GMLsave $str 0]
		set ret "\n\n"
		set len 0
		foreach word [split $str " "] {
			set lw [expr [string length $word]+1]
			if {[expr $len+$lw]<[ini::Str Exports.gmlTextDisplayLength]} {
				append ret "$word "
				incr len $lw
			} else {
				append ret "\n$word "
				set len $lw
			}
		}
		return [string trimright $ret]
	}

	# ask whether to include prompt texts
	set include [tk_messageBox -message [res::Str include_prompts] -type yesno]
	set remove "yes"

  set allP [allEntries P]
  set allQ [allEntries Q]

  # open the GML skeleton file
  if {[catch {set f [open [ini::Str files.GmlSkelFile] r]} statusMsg]} {return 0}
  set GML [read $f]
  close $f

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}

  # ---------------------------------------------------------------------- PROMPTS
  # init the LIST:: lists
  set LIST [concat $plugin(pix,vars) p_nid p_x p_y p_color p_prompt]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allP {
    foreach x [concat $plugin(pix,vars) x y p_prompt] {
			if {$x=="x"} {
				lappend lTmp(p_x) $plugin($n,$x)
      } elseif {$x=="y"} {
				lappend lTmp(p_y) $plugin($n,$x)
      } elseif {$x=="p_id"} {
				lappend lTmp($x) $plugin($n,$x)
				lappend lTmp(p_nid) [_numId $plugin($n,$x)]
			} elseif {$x=="p_prompt"} {
				if {$include=="yes"} {
					if {$remove=="yes"} {
						set xtmp [_GMLwrap [play::removeFilenames $plugin($n,p_prompt) 0]]
					} else {
						set xtmp [_GMLwrap $plugin($n,p_prompt)]
					}
					lappend lTmp(p_prompt) $xtmp
				} else {
					lappend lTmp(p_prompt) ""
				}
			} elseif {$x=="p_start"} {
				if {$plugin($n,p_start)==1} {
					lappend lTmp(p_color) [ini::Str Common.colorP1]
				} else {
					lappend lTmp(p_color) [ini::Str Common.colorP]
				}
      } else {
        lappend lTmp($x) $plugin($n,$x)
      }
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set GML [replace::repString $GML $rpList $byList "PSUB" 0]

  # ---------------------------------------------------------------------- QUESTIONS
  # init the LIST:: lists
  set LIST [concat $plugin(qix,vars) q_nid q_x q_y q_init]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allQ {
    foreach x [concat $plugin(qix,vars) x y q_init] {
			if {$x=="x"} {
				lappend lTmp(q_x) $plugin($n,$x)
      } elseif {$x=="y"} {
				lappend lTmp(q_y) $plugin($n,$x)
      } elseif {$x=="q_id"} {
				lappend lTmp($x) $plugin($n,$x)
				lappend lTmp(q_nid) [_numId $plugin($n,$x)]
			} elseif {$x=="q_init"} {
				if {$include=="yes"} {
					if {$remove=="yes"} {
						set xtmp [_GMLwrap [play::removeFilenames $plugin($n,q_init) 0]]
					} else {
						set xtmp [_GMLwrap $plugin($n,q_init)]
					}
					lappend lTmp(q_init) $xtmp
				} else {
					lappend lTmp(q_init) ""
				}
			} else {
	      lappend lTmp($x) $plugin($n,$x)
			}
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set GML [replace::repString $GML $rpList $byList "QSUB" 0]

  # ---------------------------------------------------------------------- CONN DATA
  # init the LIST:: lists
  set LIST [list o_from o_to o_label]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allP {
  	set nn [_numId $n]
		foreach x $plugin($n,p_follows) {
			lappend lTmp(o_from) $nn
			lappend lTmp(o_to) [_numId $x]
			if {[info exists plugin(O,$n,$x)]} {
				lappend lTmp(o_label) [util::oneLine [_GMLsave $plugin(O,$n,$x) [ini::Str Graphics.connectionDisplayLength]]]
			} else {
				lappend lTmp(o_label) ""
			}
		}
  }
  foreach n $allQ {
  	set nn [_numId $n]
		foreach x $plugin($n,q_follows) {
			lappend lTmp(o_from) $nn
			lappend lTmp(o_to) [_numId $x]
			if {[info exists plugin(O,$n,$x)]} {
				lappend lTmp(o_label) [util::oneLine [_GMLsave $plugin(O,$n,$x) [ini::Str Graphics.connectionDisplayLength]]]
			} else {
				lappend lTmp(o_label) ""
			}
		}
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set GML [replace::repString $GML $rpList $byList "OSUB" 0]

  # ---------------------------------------------------------------------- STR::
  # fill the list of STR replacements
  set rpList {}
  set byList {}
  
  lappend rpList "{STR::Date}"
  lappend byList "[date::nowS]"

  lappend rpList "{STR::Width}"
  lappend byList "[ini::Str Graphics.boxSizeX]"

  lappend rpList "{STR::Height}"
  lappend byList "[expr [ini::Str Graphics.boxSizeY]+[ini::Str Graphics.headerBoxSizeY]]"

  lappend rpList "{STR::PColor}"
  lappend byList "[ini::Str Common.colorP]"

  lappend rpList "{STR::QColor}"
  lappend byList "[ini::Str Common.colorQ]"

  lappend rpList "{STR::OColor}"
  lappend byList "[ini::Str Common.colorO]"

  lappend rpList "{STR::Version}"
  lappend byList "[util::xmlSave [res::Str about]]"

  lappend rpList "{STR::VersionDate}"
  lappend byList "[res::Str date]"

  set GML [replace::repString $GML $rpList $byList "SOMETHING" 0]

  puts $f $GML
  close $f

  set statusMsg [res::Str prjexpgml "$fn"]
  return 1
}

proc wozExportHTML {fn} {
  global plugin statusMsg label options woz

	proc createHyperlinks {str} {
		# calculate the relevant indices
		set plist [lsort -integer -index 0 [concat [play::getAudioIndices $str] [play::getPictureIndices $str]]]

		# loop over the indices
		set start 0
		set ret {}
		foreach p $plist {
			# copy the part outside the references
			if {[lindex $p 0]>$start} {
				append ret [string range $str $start [expr [lindex $p 0]-1]]
			}
			set start [expr [lindex $p 1]+1]

			# create hyperlinks
			set fnlist [split [string range $str [expr 3+[lindex $p 0]] [expr [lindex $p 1]-1]] ,]
			if {$fnlist!=""} {append ret "[string range $str [lindex $p 0] [expr 2+[lindex $p 0]]]"}
			foreach fn $fnlist {
				append ret "<a href=\"../prompts/$fn\">$fn</a>,"
			}
			if {$fnlist!=""} {set ret "[string range $ret 0 [expr [string length $ret]-2]]\]"}
		}
		
		append ret [string range $str $start end]
		return $ret
	}

  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]
  set allS [allEntries S]

  # open the HTML skeleton file
  if {[catch {set f [open [ini::Str files.HtmlSkelFile] r]} statusMsg]} {return 0}
  set HTML [read $f]
  close $f

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}
	fconfigure $f -encoding utf-8

	# init temporary filename lists
	array unset auds
	array unset pics
	set auds(all) {}
	set pics(all) {}
	
  # ---------------------------------------------------------------------- PROMPTS
  # init the LIST:: lists
  set LIST [concat $plugin(pix,vars) $plugin(pix,text) "p_previous"]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allP {
    foreach x $LIST {
      if {$x=="p_start" || $x=="p_endstate" || $x=="p_vxml"} {
        if {$plugin($n,$x)==1} {
          lappend lTmp($x) [res::Str yes]
        } else {
          lappend lTmp($x) [res::Str no]
        }
			} elseif ("$x"=="p_follows") {
				set xtmp "<table border=1>"
				foreach tmp [calcSuccessors $n] {
					if {[info exists plugin(O,$n,$tmp)]} {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a></td><td>$plugin(O,$n,$tmp)</td></tr>"
					} else {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a><td></td></td></tr>"
					}
				}
				append xtmp "</table>"
				lappend lTmp($x) $xtmp
			} elseif ("$x"=="p_previous") {
				set xtmp "<table border=1>"
				foreach tmp [calcPredecessors $n] {
					if {[info exists plugin(O,$tmp,$n)]} {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a></td><td>$plugin(O,$tmp,$n)</td></tr>"
					} else {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a></td><td></td></tr>"
					}
				}
				append xtmp "</table>"
				lappend lTmp($x) $xtmp
      } else {
				set xtmp [util::xmlSave $plugin($n,$x) "<br/>" "&nbsp;&nbsp;&nbsp;"]

				# create hyperlinks for audio and picture files
				set xtmp [createHyperlinks $xtmp]

        lappend lTmp($x) $xtmp

				# store audio and picture file names
				set xtmp [play::getAudioFilenames $plugin($n,$x)]
				foreach tmplist $xtmp {
					foreach tmp [split $tmplist ,] {
						lappend auds(all) $tmp
						if {[info exists auds($tmp)]} {
							lappend auds($tmp) $n
						} else {
							set auds($tmp) $n
						}
					}
				}

				set xtmp [play::getPictureFilenames $plugin($n,$x)]
				foreach tmplist $xtmp {
					foreach tmp [split $tmplist ,] {
						lappend pics(all) $tmp
						if {[info exists pics($tmp)]} {
							lappend pics($tmp) $n
						} else {
							set pics($tmp) $n
						}
					}
				}

      }
    }
  }
  
	#tk_messageBox -message "auds: [array get auds]\n\npics: [array get pics]" -type ok

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

	#tk_messageBox -message "rpList: $rpList\n\nbyList: $byList" -type ok
	
  # perform the replacement
  set HTML [replace::repString $HTML $rpList $byList "PSUB" 0]

  # ---------------------------------------------------------------------- QUESTIONS
  # init the LIST:: lists
  set LIST [concat $plugin(qix,vars) $plugin(qix,text) "q_previous"]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allQ {
    foreach x $LIST {
      if {$x=="q_endstate" || $x=="q_vxml"} {
        if {$plugin($n,$x)==1} {
          lappend lTmp($x) [res::Str yes]
        } else {
          lappend lTmp($x) [res::Str no]
        }
			} elseif ("$x"=="q_follows") {
				set xtmp "<table border=1>"
				foreach tmp [calcSuccessors $n] {
					if {[info exists plugin(O,$n,$tmp)]} {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a></td><td>$plugin(O,$n,$tmp)</td></tr>"
					} else {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a><td></td></td></tr>"
					}
				}
				append xtmp "</table>"
				lappend lTmp($x) $xtmp
			} elseif ("$x"=="q_previous") {
				set xtmp "<table border=1>"
				foreach tmp [calcPredecessors $n] {
					if {[info exists plugin(O,$tmp,$n)]} {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a></td><td>$plugin(O,$tmp,$n)</td></tr>"
					} else {
						append xtmp "<tr><td><a href=\"#$tmp\">$tmp</a></td><td></td></tr>"
					}
				}
				append xtmp "</table>"
				lappend lTmp($x) $xtmp
			} else {
				set xtmp [util::xmlSave $plugin($n,$x) "<br/>" "&nbsp;&nbsp;&nbsp;"]
				regsub -all -nocase "{REPROMPT}" $xtmp "$plugin($n,q_init)" xtmp
	
				# create hyperlinks for audio and picture files
				set xtmp [createHyperlinks $xtmp]
	
	      lappend lTmp($x) $xtmp
	
				# store audio and picture file names
				set xtmp [play::getAudioFilenames $plugin($n,$x)]
				foreach tmplist $xtmp {
					foreach tmp [split $tmplist ,] {
						lappend auds(all) $tmp
						if {[info exists auds($tmp)]} {
							lappend auds($tmp) $n
						} else {
							set auds($tmp) $n
						}
					}
				}
	
				set xtmp [play::getPictureFilenames $plugin($n,$x)]
				foreach tmplist $xtmp {
					foreach tmp [split $tmplist ,] {
						lappend pics(all) $tmp
						if {[info exists pics($tmp)]} {
							lappend pics($tmp) $n
						} else {
							set pics($tmp) $n
						}
					}
				}
			}
    }
  }

	#tk_messageBox -message "auds: [array get auds]\n\npics: [array get pics]" -type ok

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set HTML [replace::repString $HTML $rpList $byList "QSUB" 0]

  # ---------------------------------------------------------------------- CONCEPTS
  # init the LIST:: lists
  set LIST [concat $plugin(cix,vars) $plugin(cix,text) "c_usedby"]
  foreach x $LIST {set lTmp($x) {}}

  foreach n $allC {
    foreach x [concat $plugin(cix,vars) $plugin(cix,text)] {
      if {$x=="c_always"} {
        if {$plugin($n,$x)==1} {
          lappend lTmp($x) [res::Str yes]
        } else {
          lappend lTmp($x) [res::Str no]
        }
      } else {
				set xtmp [util::xmlSave $plugin($n,$x) "<br/>" "&nbsp;&nbsp;&nbsp;"]
        lappend lTmp($x) $xtmp
      }
    }
    lappend lTmp(c_usedby) [calcUsedBy $n]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set HTML [replace::repString $HTML $rpList $byList "CSUB" 0]

  # ---------------------------------------------------------------------- SAMPLE CALLS
  # init the LIST:: lists
  set LIST [concat $plugin(six,vars) $plugin(six,text) "s_usedby"]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allS {
    foreach x $LIST {
			if ("$x"=="s_usedby") {
				set xtmp {}
				foreach tmp [sampleCallUses $n] {
					if {[objectExists $tmp]} {
						append xtmp "<a href=\"#$tmp\">$tmp</a> "
					} else {
						append xtmp "$tmp "
					}
				}
				lappend lTmp($x) $xtmp
			} elseif ("$x"=="s_call") {
				set ix 1
				set xtmp "<table border=1>"
				foreach tmp $plugin($n,s_call) {
					set tmpid [lindex $tmp 0]

					if {[isPrompt $tmpid]} {
						append xtmp "<tr><td>$ix</td><td>Prompt</td>"
					} else {
						append xtmp "<tr><td>$ix</td><td>Question</td>"
					}

					if {[objectExists $tmpid]} {
						append xtmp "<td><a href=\"#$tmpid\">$tmpid</a></td>"
					} else {
						append xtmp "<td>$tmpid</td>"
					}

					if {[isPrompt $tmpid]} {
						append xtmp "<td>p_prompt</td><td>[createHyperlinks [lindex $tmp 1]]</td></tr>"
					} else {
						append xtmp "<td>[lindex $tmp 1]</td><td>[createHyperlinks [lindex $tmp 2]]</td>"
						append xtmp "</tr><tr>"
						append xtmp "<td></td><td>Caller</td><td></td><td>[lindex $tmp 3]</td><td>[lindex $tmp 4]</td></tr>"
					}
					incr ix
				}
				append xtmp "</table>"
				lappend lTmp($x) $xtmp
			} else {
				set xtmp [util::xmlSave $plugin($n,$x) "<br/>" "&nbsp;&nbsp;&nbsp;"]
	      lappend lTmp($x) $xtmp
			}
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set HTML [replace::repString $HTML $rpList $byList "SSUB" 0]

  # ---------------------------------------------------------------------- RECLIST
  # init the LIST:: lists
  set LIST [list r_filename r_reference r_objref]
  foreach x $LIST {set lTmp($x) {}}

	foreach n [lsort -unique $auds(all)] {
    lappend lTmp(r_filename)  $n
    lappend lTmp(r_reference) ../prompts/$n
    lappend lTmp(r_objref)    [lsort -unique $auds($n)]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

	#tk_messageBox -message "rpList: $rpList\n\nbyList: $byList" -type ok

  # perform the replacement
  set HTML [replace::repString $HTML $rpList $byList "RSUB" 0]

  # ---------------------------------------------------------------------- MULTILIST
  # init the LIST:: lists
  set LIST [list m_filename m_reference m_objref]
  foreach x $LIST {set lTmp($x) {}}

	foreach n [lsort -unique $pics(all)] {
    lappend lTmp(m_filename)  $n
    lappend lTmp(m_reference) ../prompts/$n
    lappend lTmp(m_objref)    [lsort -unique $pics($n)]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set HTML [replace::repString $HTML $rpList $byList "MSUB" 0]

  # ---------------------------------------------------------------------- STR::
  # fill the list of STR replacements
  set rpList {}
  set byList {}
  
  lappend rpList "{STR::Date}"
  lappend byList "[date::nowS]"

  lappend rpList "{STR::Project}"
  lappend byList "$plugin(name)"

  lappend rpList "{STR::FileName}"
  lappend byList "[file tail $plugin(prj,loaded)]"

  lappend rpList "{STR::FilePath}"
  lappend byList "$plugin(prj,loaded)"

  lappend rpList "{STR::Version}"
  lappend byList "[res::Str about]"

  lappend rpList "{STR::VersionDate}"
  lappend byList "[res::Str date]"

	set fileroot "[file rootname [file tail $plugin(prj,loaded)]]"
	set picsdir "[set fileroot]_pics"

  lappend rpList "{STR::PicsPath}"
  lappend byList $picsdir

  lappend rpList "{STR::FileRoot}"
  lappend byList $fileroot

  lappend rpList "{STR::Comment}"
  lappend byList "[ini::Str Files.Comment]"
  set HTML [replace::repString $HTML $rpList $byList "SOMETHING" 0]

  # ---------------------------------------------------------------------- LISTEN::
  while {[regexp -nocase -- "{LISTEN::\[A-Z0-9_.\]+}" $HTML substring]} {
		regsub -nocase -- "{LISTEN::" $substring "" filename
		regsub -nocase -- "}$" $filename "" filename
	
		# the play soundfile link will only be included if the file exists
		if {[file exists prompts/$filename]} {
		  regsub -- $substring $HTML "<a href=\"../prompts/$filename\"><img border=\"0\" src=\"../export/share/play.gif\" alt=\"Play soundfile\" align=\"right\" hspace=\"1\" vspace=\"1\" width=\"48\" height=\"24\"></a>" HTML
		} else {
		  regsub -- $substring $HTML "" HTML
		}
  }

  # ---------------------------------------------------------------------- VIEW::
  while {[regexp -nocase -- "{VIEW::\[A-Z0-9_.\]+}" $HTML substring]} {
		regsub -nocase -- "{VIEW::" $substring "" filename
		regsub -nocase -- "}$" $filename "" filename
	
		# the image link will only be included if the file exists
		if {[file exists prompts/$filename]} {
		  regsub -- $substring $HTML "<img border=\"1\" src=\"../prompts/$filename\" align=\"right\" hspace=\"1\" vspace=\"1\">" HTML
		} else {
		  regsub -- $substring $HTML "" HTML
		}
  }

  puts $f $HTML
  close $f

	# create an image from the design
	set dir [file dirname $fn]
	file mkdir $dir/$picsdir
	layout2image $dir/$picsdir/[set fileroot].gif gif

  set statusMsg [res::Str prjexphtml "$fn"]
  return 1
}

proc wozExportXHMI {fn} {
  global plugin statusMsg label options woz

  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]

	# remove filenames from prompts
	set remove "yes"

  # open the XHMI skeleton file
  if {[catch {set f [open [ini::Str files.XhmiSkelFile] r]} statusMsg]} {return 0}
  set XHMI [read $f]
  close $f

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}
	fconfigure $f -encoding utf-8

  # ---------------------------------------------------------------------- PROMPTS
  # init the LIST:: lists
  set LIST [concat $plugin(pix,vars) $plugin(pix,text) "p_previous"]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allP {
    foreach x [concat $plugin(pix,vars) $plugin(pix,text)] {
      if {$x=="p_start"} {
        if {$plugin($n,$x)==1} {
					set pStart $n
          lappend lTmp($x) [res::Str xhmi_p_is_start]
        } else {
          lappend lTmp($x) [res::Str xhmi_p_is_not_start]
        }
      } else {
				set xtmp [util::xmlSave $plugin($n,$x) " " " "]
				if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
				if {$x=="p_title"} {regsub -all " " $xtmp "_" xtmp}
        lappend lTmp($x) $xtmp
      }
    }
    lappend lTmp(p_previous) [calcPredecessors $n]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XHMI [replace::repString $XHMI $rpList $byList "PSUB" 0]

  # ---------------------------------------------------------------------- QUESTIONS
  # init the LIST:: lists
  set LIST [concat $plugin(qix,vars) $plugin(qix,text) "q_previous"]
  foreach x $LIST {set lTmp($x) {}}

  # build the lists
  foreach n $allQ {
    foreach x [concat $plugin(qix,vars) $plugin(qix,text)] {
			set xtmp $plugin($n,$x)
			regsub -all -nocase "{REPROMPT}" $xtmp "$plugin($n,q_init)" xtmp
			set xtmp [util::xmlSave $xtmp " " " "]
			if {$remove=="yes"} {set xtmp [play::removeFilenames $xtmp 0]}
			if {$x=="q_title"} {regsub -all " " $xtmp "_" xtmp}
      lappend lTmp($x) $xtmp
    }
    lappend lTmp(q_previous) [calcPredecessors $n]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XHMI [replace::repString $XHMI $rpList $byList "QSUB" 0]

  # ---------------------------------------------------------------------- CONCEPTS
  # init the LIST:: lists
  set LIST [concat $plugin(cix,vars) $plugin(cix,text) "c_usedby"]
  foreach x $LIST {set lTmp($x) {}}

  foreach n $allC {
    foreach x [concat $plugin(cix,vars) $plugin(cix,text)] {
      if {$x=="c_always"} {
        if {$plugin($n,$x)==1} {
          lappend lTmp($x) [res::Str xhmi_c_is_always]
        } else {
          lappend lTmp($x) [res::Str xhmi_c_is_not_always]
        }
      } else {
				set xtmp [util::xmlSave $plugin($n,$x) " " " "]
				if {$x=="c_title"} {regsub -all " " $xtmp "_" xtmp}
        lappend lTmp($x) $xtmp
      }
    }
    lappend lTmp(c_usedby) [calcUsedBy $n]
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XHMI [replace::repString $XHMI $rpList $byList "CSUB" 0]

  # ---------------------------------------------------------------------- RECLIST
  # init the LIST:: lists
  set LIST [list r_filename r_reference r_objref r_text r_type]
  foreach x $LIST {set lTmp($x) {}}

  foreach n $allP {
    if {$plugin($n,p_prompt)!=""} {
      lappend lTmp(r_type)      [res::Str b_label_p_header]
      lappend lTmp(r_filename)  $n.p_prompt.wav
      lappend lTmp(r_reference) $n.p_prompt
      lappend lTmp(r_objref)    $n
			set xtmp [util::xmlSave $plugin($n,p_prompt) " " " "]
      lappend lTmp(r_text)      $xtmp
    }
  }

  foreach n $allQ {
    foreach x $plugin(qix,phr) {
      if {$plugin($n,$x)!=""} {
        lappend lTmp(r_type)      [res::Str b_label_q_header]
        lappend lTmp(r_filename)  $n.$x.wav
        lappend lTmp(r_reference) $n.$x
        lappend lTmp(r_objref)    $n
				set xtmp [util::xmlSave $plugin($n,$x) " " " "]
        lappend lTmp(r_text)      $xtmp
      }
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)
  }

  # perform the replacement
  set XHMI [replace::repString $XHMI $rpList $byList "RSUB" 0]

  # ---------------------------------------------------------------------- STR::
  # fill the list of STR replacements
  set rpList {}
  set byList {}
  
  lappend rpList "{STR::Date}"
  lappend byList "[date::nowS]"

  lappend rpList "{STR::Project}"
  lappend byList "$plugin(name)"

  lappend rpList "{STR::DialogId}"
  lappend byList "WOz"

  lappend rpList "{STR::IntroPromptId}"
  lappend byList $pStart

  lappend rpList "{STR::FileName}"
  lappend byList "[file tail $plugin(prj,loaded)]"

  lappend rpList "{STR::FilePath}"
  lappend byList "$plugin(prj,loaded)"

  lappend rpList "{STR::Version}"
  lappend byList "[res::Str about]"

  lappend rpList "{STR::VersionDate}"
  lappend byList "[res::Str date]"

  lappend rpList "{STR::Comment}"
  lappend byList "[ini::Str Files.Comment]"
  set XHMI [replace::repString $XHMI $rpList $byList "SOMETHING" 0]

  puts $f $XHMI
  close $f
  set statusMsg [res::Str prjexpxhmi "$fn"]
  return 1
}

proc wozExportVDX {fn} {
  global plugin statusMsg label options woz

  set allP [allEntries P]
  set allQ [allEntries Q]

  # open the VDX skeleton file
  if {[catch {set f [open [ini::Str files.VDXSkelFile] r]} statusMsg]} {return 0}
  set VDX [read $f]
  close $f

  # open the export file
  if {[catch {set f [open $fn w]} statusMsg]} {return 0}

  # ---------------------------------------------------------------------- PROMPTS
  # build the lists
  set LIST [concat $plugin(pix,vars) $plugin(pix,text)]
  foreach x $LIST {
  	set lTmp($x) {}
  	set lTmp(ix,$x) {}
  }
  
  set ix 0
  foreach n $allP {
    foreach x $LIST {
			set xtmp [util::xmlSave $plugin($n,$x) " " " "]
      lappend lTmp($x) $xtmp
      lappend lTmp(ix,$x) $ix
      incr ix
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)

    lappend rpList "{IX::$x}"
    lappend byList $lTmp(ix,$x)
  }

  # perform the replacement
  set VDX [replace::repString $VDX $rpList $byList "PSUB" 0]

  # ---------------------------------------------------------------------- QUESTIONS
  # build the lists
  set LIST [concat $plugin(qix,vars) $plugin(qix,text)]
  foreach x $LIST {
  	set lTmp($x) {}
  	set lTmp(ix,$x) {}
  }

  foreach n $allQ {
    foreach x $LIST {
			set xtmp $plugin($n,$x)
			regsub -all -nocase "{REPROMPT}" $xtmp "$plugin($n,q_init)" xtmp
			set xtmp [util::xmlSave $xtmp " " " "]
			if {$x=="q_title"} {regsub -all " " $xtmp "_" xtmp}
      lappend lTmp($x) $xtmp
      lappend lTmp(ix,$x) $ix
      incr ix
    }
  }

  # store the lists
  set rpList {}
  set byList {}
  foreach x $LIST {
    lappend rpList "{LIST::$x}"
    lappend byList $lTmp($x)

    lappend rpList "{IX::$x}"
    lappend byList $lTmp(ix,$x)
  }

  # perform the replacement
  set VDX [replace::repString $VDX $rpList $byList "QSUB" 0]

  # ---------------------------------------------------------------------- TRANSITIONS
  # build the lists
	set lTmp(ID2ID) {}
	set lTmp(ID2ID,IX) {}

  foreach n $allP {
		foreach nn $plugin($n,p_follows) {
			lappend lTmp(IDID) "$n to $nn"
			lappend lTmp(IDID,IX) $ix
			incr ix
		}
  }
  foreach n $allQ {
		foreach nn $plugin($n,q_follows) {
			lappend lTmp(IDID) "$n to $nn"
			lappend lTmp(IDID,IX) $ix
			incr ix
		}
  }

  # store the lists
	set rpList [list "{LIST::IDID}" "{LIST::IDIDIX}"]
	set byList [list $lTmp(IDID) $lTmp(IDID,IX)]

  # perform the replacement
  set VDX [replace::repString $VDX $rpList $byList "IDID" 0]

  # ---------------------------------------------------------------------- STR::
  # fill the list of STR replacements
  set rpList {}
  set byList {}
  
  lappend rpList "{STR::Date}"
  lappend byList "[date::nowS]"

  lappend rpList "{STR::Project}"
  lappend byList "$plugin(name)"

  lappend rpList "{STR::DialogId}"
  lappend byList "WOz"

  lappend rpList "{STR::FileName}"
  lappend byList "[file tail $plugin(prj,loaded)]"

  lappend rpList "{STR::FilePath}"
  lappend byList "$plugin(prj,loaded)"

  lappend rpList "{STR::Version}"
  lappend byList "[res::Str about]"

  lappend rpList "{STR::VersionDate}"
  lappend byList "[res::Str date]"

  lappend rpList "{STR::Comment}"
  lappend byList "[ini::Str Files.Comment]"

	set VDX [replace::repString $VDX $rpList $byList "SOMETHING" 0]

  puts $f $VDX
  close $f
  set statusMsg [res::Str prjexpvdx "$fn"]
  return 1
}

proc wozExportRTF_Nuance {dir} {
  global plugin statusMsg

  set allP [allEntries P]
  set allQ [allEntries Q]
  set allC [allEntries C]

	tk_messageBox -message "Please note that the Nuance RTF export is way out of date and not recommended!" -type ok

  # read the RTF skeleton files for prompts and questions
  if {[catch {set f [open [ini::Str files.Nuance_RTFskelFileP] r]} statusMsg]} {return 0}
  set rtfP [read $f]
  close $f
  if {[catch {set f [open [ini::Str files.Nuance_RTFskelFileQ] r]} statusMsg]} {return 0}
  set rtfQ [read $f]
  close $f
  if {[catch {set f [open [ini::Str files.Nuance_RTFskelFileC] r]} statusMsg]} {return 0}
  set rtfC [read $f]
  close $f

  # create the necessary export dir if necessary
  if {![file exists $dir]} {
    if {[catch {file mkdir $dir} statusMsg]} {return 0}
  }

  # loop over all prompts
  foreach n $allP {
    # create the output
    set tmp $rtfP
    set tmp [util::save_regsub_all "<<.?P.?-.?Title.?>>" $tmp $plugin($n,p_title)]
    set tmp [util::save_regsub_all "<<.?P.?-.?Description.?>>" $tmp $plugin($n,p_memo)]
    set tmp [util::save_regsub_all "<<.?P.?-.?Prompt.?>>" $tmp $plugin($n,p_prompt)]
    set tmp [util::save_regsub_all "<<.?P.?-.?Followups.?>>" $tmp [id2crossreference [calcSuccessors $n]]]
    set tmp [util::save_regsub_all "<<.?P.?-.?Predecessors.?>>" $tmp [id2crossreference [calcPredecessors $n]]]
    set tmp [util::save_regsub_all "<<.?P.?-.?Id.?>>" $tmp $n]
    if {$plugin($n,p_start)==1} {
      set tmp [util::save_regsub_all "<<.?P.?-.?Start.?>>" $tmp [res::Str yes]]
    } else {
      set tmp [util::save_regsub_all "<<.?P.?-.?Start.?>>" $tmp ""]
    }
    set tmp [util::save_regsub_all "StateTableBookmark" $tmp "${n}_$plugin($n,p_title)" ]
    set tmp [util::save_regsub_all "<<BACKSLASH>>" $tmp "\\"]

    # write the output
    set cfn "$n [correctFN $plugin($n,p_title)]"
    if {[catch {set f [open $dir/$cfn[ini::Str files.rtfExt] w]} statusMsg]} {return 0}
    puts $f $tmp
    close $f
  }

  # loop over all questions
  foreach n $allQ {
    # create the output
    set tmp $rtfQ
    set tmp [util::save_regsub_all "<<.?Q.?-.?Title.?>>" $tmp $plugin($n,q_title)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?Description.?>>" $tmp $plugin($n,q_memo)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?Init.?>>" $tmp $plugin($n,q_init)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?Followups.?>>" $tmp [id2crossreference [calcSuccessors $n]]]
    set tmp [util::save_regsub_all "<<.?Q.?-.?Predecessors.?>>" $tmp [id2crossreference [calcPredecessors $n]]]
    set tmp [util::save_regsub_all "<<.?Q.?-.?Concepts.?>>" $tmp [id2title $plugin($n,q_concepts)]]
    set tmp [util::save_regsub_all "<<.?Q.?-.?InitComment.?>>" $tmp ""]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NU1.?>>" $tmp $plugin($n,q_nu1)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NU2.?>>" $tmp $plugin($n,q_nu2)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NU3.?>>" $tmp $plugin($n,q_nu3)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NUComment.?>>" $tmp ""]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NR1.?>>" $tmp $plugin($n,q_nr1)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NR2.?>>" $tmp $plugin($n,q_nr2)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NR3.?>>" $tmp $plugin($n,q_nr3)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?NRComment.?>>" $tmp ""]
    set tmp [util::save_regsub_all "<<.?Q.?-.?TL1.?>>" $tmp $plugin($n,q_tl1)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?TL2.?>>" $tmp $plugin($n,q_tl2)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?TL3.?>>" $tmp $plugin($n,q_tl3)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?TLComment.?>>" $tmp ""]
    set tmp [util::save_regsub_all "<<.?Q.?-.?Help.?>>" $tmp $plugin($n,q_ctxhelp)]
    set tmp [util::save_regsub_all "<<.?Q.?-.?Id.?>>" $tmp $n]
    set tmp [util::save_regsub_all "StateTableBookmark" $tmp "${n}_$plugin($n,q_title)" ]
    set tmp [util::save_regsub_all "<<BACKSLASH>>" $tmp "\\"]

    # write the output
    set cfn "$n [correctFN $plugin($n,q_title)]"
    if {[catch {set f [open $dir/$cfn[ini::Str files.rtfExt] w]} statusMsg]} {return 0}
    puts $f $tmp
    close $f
  }

  # loop over all concepts
  foreach n $allC {
    # create the output
    set tmp $rtfC
    set tmp [util::save_regsub_all "<<.?C.?-.?Title.?>>" $tmp $plugin($n,c_title)]
    set tmp [util::save_regsub_all "<<.?C.?-.?Description.?>>" $tmp $plugin($n,c_memo)]
    set tmp [util::save_regsub_all "<<.?C.?-.?Id.?>>" $tmp $n]
    if {$plugin($n,c_always)==1} {
      set tmp [util::save_regsub_all "<<.?C.?-.?Always.?>>" $tmp [res::Str yes]]
    } else {
      set tmp [util::save_regsub_all "<<.?C.?-.?Always.?>>" $tmp ""]
    }

    # write the output
    set cfn "$n [correctFN $plugin($n,c_title)]"
    if {[catch {set f [open $dir/$cfn[ini::Str files.rtfExt] w]} statusMsg]} {return 0}
    puts $f $tmp
    close $f
  }

  set statusMsg [res::Str prjexprtf "$dir (Nuance Specific)" "[expr [llength $allP]+[llength $allQ]+[llength $allC]]"]
  return 1
}

###
 #     #    #  #####    ####   #####    #####   ####
 #     ##  ##  #    #  #    #  #    #     #    #
 #     # ## #  #    #  #    #  #    #     #     ####
 #     #    #  #####   #    #  #####      #         #
 #     #    #  #       #    #  #   #      #    #    #
###    #    #  #        ####   #    #     #     ####

proc wozImportText {fn} {
  global plugin statusMsg

  # open the import file
  if {[catch {set f [open $fn r]} statusMsg]} {return 0}

  # read the import file line by line
  set errors 0
  set insert ""
  set lineno 0
  set ignored 0
  set changes 0
	set x 0
	set y 0
	set prev ""

	set undo_cmd ""
	set redo_cmd ""

  while {![eof $f]} {
		set line [gets $f]
		incr lineno
		set ignoreThis 0

		if {$line!="" && [string index $line 0]!="#"} {
			set line [split $line \t]
			set name [split [lindex $line 0] .]
			set curr [lindex $name 0]

			# choose format of line
			if {[llength $name]==1} {
				# P004 p_prompt System Good... -- SAMPLE CALL
				set curr [lindex $line 0]
				set cobj [lindex $line 1]
				set csys [lindex $line 2]
				set text [lindex $line 3]
			} elseif {[llength $line]==2} {
				# P004.p_prompt Good... -- PHRASE LIST
				set curr [lindex $name 0]
				set cobj [lindex $name 1]
				set csys "System"
				set text [lindex $line 1]
			} elseif {[llength $line]>3} {
				# <e> text Caller today... -- CALLER UTTERANCE
				set ignoreThis 1
			} else {
				incr errors
				log [res::Str log_impsc_error $lineno]
				set ignoreThis 1
			}

			#debug "curr $curr; cobj $cobj; csys $csys; text $text; ignoreThis $ignoreThis"

			if {$ignoreThis} {
				incr ignored
			} else {
				# replace placeholders \n and \t in the text
				regsub -all {\\n} $text "\n" text
				regsub -all {~} $text "\n" text
				regsub -all {\\t} $text "\t" text
	
				# does the object already exist?
				if {[info exists plugin($curr,$cobj)]} {
					# check if the text changes; if yes, import
					if {$plugin($curr,$cobj)!=$text} {
						append undo_cmd "set plugin($curr,$cobj) [list $plugin($curr,$cobj)];"
						append redo_cmd "set plugin($curr,$cobj) [list $text];"
						incr changes
					}
				} else {
					# check if the index is syntactically correct
					if {[regexp "^\[PQC\]\[0-9\]\[0-9\]\[0-9\]\$" $curr]} {
						if {$insert==""} {
							set insert [tk_messageBox -type yesno -message [res::Str import_new_objects]]
						}
						if {$insert=="yes"} {
							# create the info slots
							switch [objectType $curr] {
								p {set cmd [createPromptCommands $curr]}
								q {set cmd [createQuestionCommands $curr]}
							}
							append undo_cmd [lindex $cmd 1]
							append redo_cmd [lindex $cmd 0]
							append redo_cmd "set plugin($curr,$cobj) [list $text];"
							append redo_cmd "set plugin($curr,x) [list $x];"
							append redo_cmd "set plugin($curr,y) [list $y];"

							incr y 100
							incr changes
						}
					} else {
						# if the index is invalid, count an error
						incr errors
						set ignoreThis 1
						log [res::Str log_imptxt_error $lineno]
					}
				}
				
				# eventually create the connection
				if {!$ignoreThis && [objectExists $curr]} {
					if {[objectExists $prev]} {
						if {[isPrompt $prev]} {
							if {[lsearch -exact $plugin($prev,p_follows) $curr]==-1} {
								append undo_cmd "set plugin($prev,p_follows) [list $plugin($prev,p_follows)];"
								append redo_cmd "set plugin($prev,p_follows) [list [lsort -uniq [concat $plugin($prev,p_follows) $curr]]];"
								incr changes
							}
						} elseif {[isQuestion $prev]} {
							if {[lsearch -exact $plugin($prev,q_follows) $curr]==-1} {
								append undo_cmd "set plugin($prev,q_follows) [list $plugin($prev,q_follows)];"
								append redo_cmd "set plugin($prev,q_follows) [list [lsort -uniq [concat $plugin($prev,q_follows) $curr]]];"
								incr changes
							}
						}
					}
					set prev $curr
				}
			}
		}
  }

	if {$changes>0} {
		move::add $redo_cmd $undo_cmd [res::Str undo_import [file tail $fn] $changes]
	  updateList
		prjFlags - 1 -
	  set statusMsg [res::Str prjimptxt [file tail $fn] $changes $errors $ignored]
	  return 1
	} else {
	  set statusMsg [res::Str prjimptxtfail [file tail $fn] $errors $ignored]
	  return 0
	}
}

proc wozImportSampleCall {fn} {
  global plugin statusMsg

  # open the import file
  if {[catch {set f [open $fn r]} statusMsg]} {return 0}

#	if {[tk_messageBox -message [res::Str prjnomoreundo] -type yesno]!="yes"} {
#		set statusMsg [res::Str status_opcancelled]
#		return 0
#	} else {
#		move::init
#	}

	# create a new call
	set id [nextId "S"]
	set cmd [createSampleCallCommands $id]

	set undo_cmd [lindex $cmd 1]
	set redo_cmd [lindex $cmd 0]
	append redo_cmd "set plugin($id,s_memo) \"Imported from [file tail $fn]\";"

  # read the import file line by line
  set errors 0
  set lineno 0
	set prev ""
	set turn ""
	set call {}

  while {![eof $f]} {
	set line [gets $f]
		incr lineno
		set ignoreThis 0

		if {$line!="" && [string index $line 0]!="#"} {
			set line [split $line \t]
			set name [split [lindex $line 0] .]
			set curr [lindex $name 0]

			# choose format of line
			if {[llength $name]==1} {
				# P004 p_prompt System Good... -- SAMPLE CALL
				set curr [lindex $line 0]
				set cobj [lindex $line 1]
				set csys [lindex $line 2]
				set text [lindex $line 3]
			} elseif {[llength $line]==2} {
				# P004.p_prompt Good... -- PHRASE LIST
				set curr [lindex $name 0]
				set cobj [lindex $name 1]
				set csys "System"
				set text [lindex $line 1]
			} elseif {[llength $line]>3} {
				# <e> text Caller today... -- CALLER UTTERANCE
				set curr ""
				set cobj ""
				set csys "Caller"
				set text [lindex $line 3]
			} else {
				incr errors
				log [res::Str log_impsc_error $lineno]
				set ignoreThis 1
			}

			#debug "curr $curr; cobj $cobj; csys $csys; text $text; ignoreThis $ignoreThis"

			if {!$ignoreThis} {
				# replace placeholders \n and \t in the text
				regsub -all {\\n} $text "\n" text
				regsub -all {~} $text "\n" text
				regsub -all {\\t} $text "\t" text
	
				# check if the index is syntactically correct
				if {[regexp "^\[PQC\]\[0-9\]\[0-9\]\[0-9\]\$" $curr] || $curr==""} {
					if {$curr==""} {
						if {[llength $turn]<5} {
							incr errors
							log [res::Str log_impsc_error $lineno]
						} else {
							set turn [lreplace $turn 4 4 $text]
						}
					} elseif {[isPrompt $curr]} {
						if {$turn!=""} {lappend call $turn}
						set turn [list $curr $text]
					} elseif {[isQuestion $curr]} {
						if {$turn!=""} {lappend call $turn}
						set turn [list $curr $cobj $text "text" ""]
					}
				} else {
					# if the index is invalid, count an error
					incr errors
					log [res::Str log_impsc_error $lineno]
				}
			}
		}
  }
  
	# store the last turn
	if {$turn!=""} {lappend call $turn}
	append redo_cmd "set plugin($id,s_call) [list $call];"

	move::add $redo_cmd $undo_cmd [res::Str undo_import [file tail $fn] [llength $turn]]
  updateList
	prjFlags - 1 -
  set statusMsg [res::Str prjimpsc [file tail $fn] $errors]
  return 1
}

proc wozImportGML {fn} {
	# this function is not yet offered in the menu, because the result is not too nice
	# (yEd is working great, but the edges are handled differently)
  global plugin statusMsg

  # open the import file
  if {[catch {set f [open $fn r]} statusMsg]} {return 0}

  # read the import file line by line
  set changes 0
  set errors 0
  set label "init"
  set lineno 0
  set ignored 0

  while {![eof $f]} {
		set line [string trim [gets $f]]
		incr lineno

		if {$line!="" && [string range $line 0 6]!="comment"} {
			if {$line=="node"} {
				set label "node"
			} elseif {[string range $line 0 6]=="label\t\"" && $label=="node"} {
				set label [string range $line 7 end]
			} elseif {[string range $line 0 1]=="x\t" && ([isPrompt $label] || [isQuestion $label])} {
				if {[info exists plugin($label,id)]} {
					if {[catch {set plugin($label,x) [expr round([string range $line 2 end])]}]} {
						puts "ERROR: set plugin($label,x) [expr round([string range $line 2 end])]"
						incr errors
						log [res::Str log_impgml_error $lineno]
					} else {
					  set changes 1
					}
				} else {
					incr ignored
				}
			} elseif {[string range $line 0 1]=="y\t" && ([isPrompt $label] || [isQuestion $label])} {
				if {[info exists plugin($label,id)]} {
					if {[catch {set plugin($label,y) [expr round([string range $line 2 end])]}]} {
						puts "ERROR: set plugin($label,y) [expr round([string range $line 2 end])]"
						incr errors
						log [res::Str log_impgml_error $lineno]
					} else {
					  set changes 1
					}
				} else {
					incr ignored
				}
			}
		}
  }

	if {$changes>0} {
		prjFlags - 1 -
	}

  set statusMsg [res::Str prjimpgml "$fn" $changes $errors $ignored]
  return 1
}
