#==========================================================================================
# Legal stuff:
#   FREEWARE. Absolutely no warranties! Use in any way you want and at your own risk!!!
#==========================================================================================
# Dec 06, 2006	Reimplementation
# Jan 02, 2000	Namespace, proc Canvas2PS [RB]
# Dec 13, 1999	Learned about the "winfo rgb" command [RB]
# Nov 12, 1999	First Version [RB]
#==========================================================================================

namespace eval graf {

#------------------------------------------------ inspired by http://wiki.tcl.tk/15476
#
# Capture a canvas into an image
#

proc captureCanvas {win fn {border 0} {type png}} {
	package require Img

	# names for complete and partial images
	set all snapshot_all
	set tmp snapshot_tmp

	# window dimensions, used as raster sizes
	update
	set rasx [winfo width $win]
	set rasy [winfo height $win]

	#puts "rasx $rasx rasy $rasy"

	# move all elements so that the upper left is 0 0
	foreach {x1 y1 x2 y2} [$win bbox all] break
	$win move all [expr $border-$x1] [expr $border-$y1]
	set x2 [expr $x2+2*$border-$x1]
	set x1 0
	set y2 [expr $y2+2*$border-$y1]
	set y1 0
	set allw [expr $x2-$x1+1]
	set allh [expr $y2-$y1+1]

	#puts "x1 $x1 x2 $x2 y1 $y1 y2 $y2"
	#puts "allw $allw allh $allh"

	# define the current box as scrollegion for the window
	$win configure -scrollregion [list $x1 $y1 $x2 $y2]
	
	#puts "scrollregion [$win cget -scrollregion]"

	# take border into account
	set offset [expr [$win cget -borderwidth]+[$win cget -highlightthickness]]

	#puts "offset $offset"
	
	# create big image
	image create photo $all -width $allw -height $allh

	# loop while there are still regions to snapshot
	$win yview moveto 0
	set cury [$win yview]
	set snapy 1
	set lasty 0
	
	while {$snapy} {

		$win xview moveto 0
		set curx [$win xview]
		set snapx 1

		while {$snapx} {

			#puts "current window is $curx, $cury"

			# take a snapshot
			set w [expr 1+$rasx]
			set h [expr 1+$rasy]
			set w $rasx
			set h $rasy
	
			# copy the new snapshot to the right position
			update
			image create photo $tmp -data $win

			set tox [expr round([$win canvasx 0])+$offset]
			set toy [expr round([$win canvasy 0])+$offset]

			#puts "copy snapshot to $tox $toy"

			eval $all copy $tmp -to $tox $toy -from $offset $offset
			#$tmp write -format $type tmp-$tox-$toy.$type
			image delete $tmp
		
			if {[lindex $curx 1]!=1} {
				# goto the next raster position
				$win xview moveto [lindex $curx 1]
				set curx [$win xview]
			} else {
				set snapx 0
			}
		}

		if {[lindex $cury 1]!=1} {
			# goto the next raster position
			$win yview moveto [lindex $cury 1]
			set cury [$win yview]
		} else {
			if {$lasty} {
				set snapy 0
			} else {
				set lasty 1
			}
		}
	}

	$all write -format $type $fn
	image delete $all
}

#-------------------------------------------------------------- from http://wiki.tcl.tk/9127
 #
 # Capture a window into an image
 # Author: David Easton
 #

 proc captureWindow { win } {

   package require Img

#   regexp {([0-9]*)x([0-9]*)\+([0-9]*)\+([0-9]*)} [winfo geometry $win] - w h x y

   # Make the base image based on the window
   set image [image create photo -format window -data $win]

   foreach child [winfo children $win] {
     captureWindowSub $child $image 0 0
   }

   return $image
 }

 proc captureWindowSub { win image px py } {

   if {![winfo ismapped $win]} {
     return
   }

   regexp {([0-9]*)x([0-9]*)\+([0-9]*)\+([0-9]*)} [winfo geometry $win] - w h x y

   incr px $x
   incr py $y

   # Make an image from this widget
   set tempImage [image create photo -format window -data $win]

   # Copy this image into place on the main image
   $image copy $tempImage -to $px $py
   image delete $tempImage

   foreach child [winfo children $win] {
     captureWindowSub $child $image $px $py
   }
 }

proc windowToFile { win fn {type png} } {
   set image [captureWindow $win]
   $image write -format $type $fn
   image delete $image
 }
 
#--------------------------------------------------------------

#--------------------------------------------------------------
proc Canvas2PS {canvas fn} {
  # create a postscript screenshot from $canvas into file $fn
  set xoffset 20
  set yoffset 20

  update
  set bbox [$canvas bbox all]
  $canvas postscript -file $fn \
    -x [expr [lindex $bbox 0]-$xoffset] \
    -y [expr [lindex $bbox 1]-$yoffset] \
    -width [expr [lindex $bbox 2]-[lindex $bbox 0]+2*$xoffset] \
    -height [expr [lindex $bbox 3]-[lindex $bbox 1]+2*$yoffset]

  return [list	[expr [lindex $bbox 2]-[lindex $bbox 0]+1] \
		[expr [lindex $bbox 3]-[lindex $bbox 1]+1]]
}

proc FitAll {can {preserveXY 1}} {
  # perform a "fit all" operation on the given canvase
  update
  set bb [$can bbox all]
  set wi [winfo width $can]
  set he [winfo height $can]

  set dx [expr [lindex $bb 2]-[lindex $bb 0]]
  set dy [expr [lindex $bb 3]-[lindex $bb 1]]
  if {$dx==0 || $dy==0} {return 0}

  set fx [expr (0.0+$wi)/(0.0+$dx)]
  set fy [expr (0.0+$he)/(0.0+$dy)]

  # if x and y are to be preserved in relation to each other, use the smaller factor
  if {$preserveXY} {
    if {$fx<$fy} {
      set fy $fx
    } else {
      set fx $fy
    }
  }

  # perform the scaling and show them all
  $can scale all 0 0 $fx $fy
  graf::Origin $can
}

proc ZoomIn {can {factor 1.5}} {
  # perform a "zoom in" operation on the given canvase
  update
  $can scale all 0 0 $factor $factor
}

proc ZoomOut {can {factor 1.5}} {
  # perform a "zoom in" operation on the given canvase
  update
  $can scale all 0 0 [expr 1.0/(0.0+$factor)] [expr 1.0/(0.0+$factor)]
}

proc Origin {can} {
  # go to the top left corner
  $can xview moveto 0
  $can yview moveto 0
}

proc DefineScroll {can} {
  # define the standard scroll region
  $can configure -scrollregion [$can bbox all]
}

}