#==========================================================================================
#
# 	Written by Richard Breuer (richard.breuer@gmx.de)
#
#==========================================================================================
#	May 05, 2005	Bugfix for xHMI export [RB]
# Nov 03, 2004	First Version [RB]
#==========================================================================================

namespace eval replace {

	proc findSubBlock {string blockName} {
		#
		# finds the first block encapsulated for blockName, e.g. PSUB1,
		# replaces the block with an empty string, and returns
		#
		#		0	the index of the first character after the replaced string
		#			(in the new string)
		# 	1	the resulting string without the block
		#		2	the block itself without the delimiting blockName's
		#		3	the variable name used to specify the iteration
		#
		set lStart "{[set blockName]::Start::(\[a-zA-Z0-9_-\]+)}"
#tk_messageBox -message "lStart = $lStart; regexp = [regexp -indices -nocase -- $lStart $string ind ind2]" -type ok
		if {[regexp -indices -nocase -- $lStart $string ind ind2]} {
			set varname [string range $string [lindex $ind2 0] [lindex $ind2 1]]
			set lEnd "{[set blockName]::End::$varname}"
			set p1 [lindex $ind 0]
#tk_messageBox -message "lStart = $lStart; lEnd = $lEnd; regexp2 = [regexp -indices -- $lEnd $string ind]" -type ok
			if {[regexp -indices -nocase -- $lEnd $string ind]} {
				set p2 [lindex $ind 1]
				set block [string range $string $p1 $p2]
				regsub -nocase -- "^$lStart" $block "" block
				regsub -nocase -- "$lEnd\$" $block "" block
				set string [string replace $string $p1 $p2 ""]
				return [list $p1 $string $block $varname]
			}
			return [list -1 $string "" ""]
		}
		return [list -1 $string "" ""]
	}

	proc repString {ret patternList byList subPrefix byIndex {returnEmpty 0}} {
		set blockName "$subPrefix[expr $byIndex+1]"
		set found 0
		while {$found>=0} {
			set tmp [findSubBlock $ret $blockName]
#tk_messageBox -message "findSubBlock $blockName --> $tmp" -type ok
			set found [lindex $tmp 0]
			if {$found>=0} {
				# calculate the number of necessary iterations
				set len 0
				set ix 0
				foreach p $patternList {
					if {[regexp -nocase -- "::[lindex $tmp 3]\}" $p]} {
						set len [llength [lindex $byList $ix]]
					}
					incr ix
				}
#tk_messageBox -message "iterations for [lindex $tmp 3] = $len" -type ok

				# iterate the block for the maximum number of list items
				set ix 0
				set str ""
				while {$ix<$len} {
					set subList {}
#debug "index $ix; byList = $byList"
					foreach b $byList {
						regsub -all {"} $b "\"" b
						# repeat the last entry if the list is expired
						if {[catch {set nlen [llength $b]}]} {
							lappend subList {}
						} else {
							if {$ix>=$nlen} {
								lappend subList [lindex $b end]
							} else {
								lappend subList [lindex $b $ix]
							}
						}
					}
#tk_messageBox -message "repString [lindex $tmp 2] $patternList $subList $subPrefix [expr 1+$byIndex]" -type ok
					append str [repString [lindex $tmp 2] $patternList $subList $subPrefix [expr 1+$byIndex] 1]
					incr ix
				}

				# insert the contents into string
				set ret "[string range [lindex $tmp 1] 0 [expr $found-1]]$str[string range [lindex $tmp 1] $found end]"
			}
		}

		# now replace all patterns in the list by the respective string
		set ix 0
		set allEmpty 1
		set retSave $ret
		foreach p $patternList {
#tk_messageBox -message "regsub -all $p $ret [lindex $byList $ix] ret" -type ok
			if {[regexp -nocase -- $p $ret] && [lindex $byList $ix]!=""} {set allEmpty 0}
			set ret [util::save_regsub_all_nocase $p $ret [lindex $byList $ix]]
			incr ix
		}

#tk_messageBox -message "ret = '$ret' --- retSave = '$retSave'" -type ok

		if {$allEmpty && $returnEmpty} {
			return ""
		} else {
			return $ret
		}
	}

}
