#==========================================================================================
#
# 	Written by Richard Breuer (richard.breuer@gmx.de)
#
#==========================================================================================
# Sep 10, 2006	arrayValues [RB]
# Jul 14, 2006	value, oneLine [RB]
# Mar 28, 2000	nullNum [RB]
# Feb 07, 2000	forceFloat, negative numbers in forceNum [RB]
# Jan 02, 2000	First Version [RB]
#==========================================================================================

namespace eval util {

proc arrayValues {array index} {
	upvar $array arr
	set ret {}
	foreach n [array names arr $index] {
		lappend ret $arr($n)
	}
	return $ret
}

proc tkPuts {args} {
  toplevel .tkputs
  text .tkputs.l
  .tkputs.l insert end $args
  button .tkputs.ok -text "Schlieen" -command {destroy .tkputs}
  button .tkputs.ex -text "EXIT" -command {exit}
  pack .tkputs.l -side top -expand 1 -fill both
  pack .tkputs.ok .tkputs.ex
  grab .tkputs
  tkwait window .tkputs
}

proc log {msg} {
  if [catch {set f [open c:/0tcllog.txt a]}] {return}
  puts $f "[nowStamp] $msg"
  close $f
}

proc readSkel {fn} {
  # opens $fn and returns its contents
  set f [open $fn r]
  set ret [read $f]
  close $f
  return $ret
}

proc readSkelSubst {fn} {
  set ret [readSkel $fn]
  regsub -all "\&" $ret "GERMAN_AND" ret
  return $ret
}

proc writeSkelSubst {fn ret} {
  # resubst
  regsub -all "GERMAN_AND" $ret {\&} ret

  # opens $fn and write
  set f [open $fn w]
  puts $f $ret
  close $f
}

proc min {args} {
  set t [lindex $args 0]
  foreach a $args {
    if {$a<$t} {set t $a}
  }
  return $t
}

proc max {args} {
  set t [lindex $args 0]
  foreach a $args {
    if {$a>$t} {set t $a}
  }
  return $t
}

proc mixMode {str} {
  # transfer a string to mix mode
  set str [string tolower $str]
  foreach c {a b c d e f g h i j k l m n o p q r s t u v w x y z} {
    regsub -all -- "^$c" $str [string toupper $c] str
    regsub -all -- "(\[^a-zA-Z\])$c" $str "\\1[string toupper $c]" str
  } 
  return $str
}

proc forceNum {strVar {mayNeg 0}} {
  # remove all non-numeric characters from str, eventually returning 0
  upvar $strVar str

  set neg [expr {$mayNeg && [string index $str 0]=="-"}]
  regsub -all {[^0-9]} $str "" str
  if {$neg} {set str "-$str"}
  if {$str=="" || $str=="-"} {set str 0}
}

proc forceFloat {strVar {mayNeg 0}} {
  # remove all non-numeric characters from str, eventually returning 0
  upvar $strVar str

  set neg [expr {$mayNeg && [string index $str 0]=="-"}]
  regsub -all {[^0-9.]} $str "" str

  # check for more than one decimal point
  if {[string first "." $str]!=[string last "." $str]} {
    set str [string range $str 0 [string first "." $str]]
  }

  if {$neg} {set str "-$str"}
  if {$str=="" || $str=="-"} {set str 0}
}

proc nodup { list } {
  # Doppelte Eintraege aus einer unsortierten Liste entfernen. Die Liste ist
  # danach sortiert!

  # Berechne einmalig die Listenlaenge
  set len [llength $list]
  # Sonderfall: Liste ist leer
  if { $len > 0 } {
    # Besetze tempoaere Liste mit der sortierten Ausgangsliste
    set ltmp [lsort -ascii $list]
    # Aktuelles Vergleichselement $vgl
    set vgl [lindex $ltmp 0]
    # Vorbesetzen des Ergebnisses
    set l [list [lindex $ltmp 0]]
    # Schleife ueber die sortierte Liste zum Aufsammeln
    set i 1
    while { $i < $len } {
      set cur [lindex $ltmp $i]
      # Wert nur aufnehmen, wenn er nicht schon da ist
      if { [string compare $cur $vgl] != 0 } {
        lappend l $cur
        set vgl $cur
      }
      incr i
    }
  } else {
    # Leere Liste --> Leeres Ergebnis
    set l {}
  }
  # Gib das Ergebnis zurueck
  return $l
}

proc ranint {lo hi} {
  # returns an integer i with $lo<=$i<=$hi
  return [expr round(rand()*($hi-$lo)+$lo)]
}

proc nullNum {num len} {
  while {[string length $num]<$len} {
    set num "0$num"
  }
  return $num
}

proc noNullNum {num} {
  while {[string index $num 0]=="0"} {
    set num [string range $num 1 end]
  }
	if {$num==""} {return 0}
  return $num
}

proc value {var {maxlen 0}} {
	upvar $var myvar
	if {[info exists myvar]} {
		if {$maxlen>0} {return [string range $myvar 0 [expr $maxlen-1]]}
		return $myvar
	} else {
		return ""
	}
}

proc oneLine {str {maxlen 0}} {
	regsub -all "\n" $str "~" str
	if {$maxlen>0} {set str [string range $str 0 [expr $maxlen-1]]}
	return $str
}

proc save_regsub {exp str subspec} {
	# regsub without special effect &
  regsub -all {\&} $subspec "__SAVE_AMP__" subspec
  regsub -- $exp $str $subspec ret
  regsub -all "__SAVE_AMP__" $ret {\&} ret
  return $ret
}

proc save_regsub_all {exp str subspec} {
	# regsub without special effect &
  regsub -all {\&} $subspec "__SAVE_AMP__" subspec
  regsub -all -- $exp $str $subspec ret
  regsub -all "__SAVE_AMP__" $ret {\&} ret
  return $ret
}

proc save_regsub_all_nocase {exp str subspec} {
	# regsub without special effect &
  regsub -all {\&} $subspec "__SAVE_AMP__" subspec
  regsub -all -nocase -- $exp $str $subspec ret
  regsub -all "__SAVE_AMP__" $ret {\&} ret
  return $ret
}

proc xmlSave {str {newline "<br/>"} {tab "<tab/>"}} {
	# make a string xml save by
	#		replacing < and > by &lt; and gt;
	#		replacing \n by <br/> and \t by <tab/>

	# do not process INLINEs
	set found 1
	set flist {}
	set xtmp $str
	while {$found} {
		set found [regexp -nocase "{INLINE \[^\}\]*}" $xtmp x]
		if {$found} {
			lappend flist [string range $x 8 end-1]
			regsub -nocase "{INLINE \[^\}\]*}" $xtmp "{__REPLACED__}" xtmp
		}
	}

	# replacements
	set xtmp [util::save_regsub_all "<" $xtmp "&lt;"]
	set xtmp [util::save_regsub_all ">" $xtmp "&gt;"]
	set xtmp [util::save_regsub_all "\"" $xtmp "&quot;"]
	set xtmp [util::save_regsub_all "--" $xtmp "__"]
  regsub -all "\n" $xtmp $newline xtmp
  regsub -all "\t" $xtmp $tab xtmp

	# restore the INLINE parts
	foreach inline $flist {
		set xtmp [save_regsub "{__REPLACED__}" $xtmp $inline]
	}

  return $xtmp
}

proc xmlSaveCDATA {str} {
	# make a string xml save by embedding it in CDATA
	set xtmp [util::save_regsub_all "\]\]>" $str "\]\]&gt;"]
  return "<!\[CDATA\[$xtmp\]\]>"
}

}
