proc boolean {b} {
	if {$b} {return "true"}
	return "false"
}

proc notempty {str} {
	if {$str==""} {return 0}
	return 1
}

proc nextId {type {reserved ""}} {
  global plugin

  set tmp "[string tolower $type]_id"
  set max 0

	set look [array names plugin *,$tmp]

  foreach n $look {
    set num [string trimleft [string range $plugin($n) 1 end] "0"]
    if {$num>$max} {set max $num}
  }

	if {$reserved!=""} {
    set num [string trimleft [string range $reserved 1 3] "0"]
    if {$num>$max} {set max $num}
	}

  incr max
  if {$max>999} {return ""}
  return "$type[util::nullNum $max 3]"
}

proc allEntries {{type ""}} {
  global plugin

	if {$type!=""} {
	  # return a list of all ids from a certain type
	  set ret {}
	  set tmp [array names plugin *,[string tolower $type]_id]
	  foreach n [lsort $tmp] {
	    lappend ret [lindex [split $n ","] 0]
	  }
	  return $ret
	} else {
		return [concat [allEntries "P"] [allEntries "Q"] [allEntries "C"]]
	}
}

proc allConnections {} {
  global plugin

  # return a list of all connections
  set ret {}
	foreach n [allEntries P] {
		foreach nn $plugin($n,p_follows) {lappend ret [list $n $nn]}
	}
	foreach n [allEntries Q] {
		foreach nn $plugin($n,q_follows) {lappend ret [list $n $nn]}
	}
  return [lsort -uniq $ret]
}

proc usedInSampleCalls {id} {
	# return a list of sample calls using $id
	global plugin
	
	set ret {}
	foreach n [allEntries S] {
		foreach c $plugin($n,s_call) {
			if {[lindex $c 0]==$id} {lappend ret $n}
		}
	}

	return [lsort -uniq $ret]
}

proc connUsedInSampleCalls {from to} {
	# return a list of sample calls using connection from...to
	global plugin
	
	set ret {}
	set last ""
	foreach n [allEntries S] {
		foreach c $plugin($n,s_call) {
			set curr [lindex $c 0]
			if {$curr==$to && $last==$from} {lappend ret $n}
			set last $curr
		}
	}

	return [lsort -uniq $ret]
}

proc sampleCallUses {id} {
	# return a list of objects used in a sample call
	global plugin
	
	set ret {}
	foreach c $plugin($id,s_call) {
		set tmp [lindex $c 0]
		if {$tmp!="Pnew" && $tmp!="Qnew"} {lappend ret $tmp}
	}

	return [lsort -uniq $ret]
}

proc debug {s {quit 0}} {
	tk_messageBox -message $s -type ok
	puts "DEBUG: $s"
	if {$quit} exit
}

proc objectType {id} {
	return [string tolower [string index $id 0]]
}

proc isPrompt {id} {
	if {[objectType $id]=="p"} {return 1}
	return 0
}

proc isSampleCall {id} {
	if {[objectType $id]=="s"} {return 1}
	return 0
}

proc isQuestion {id} {
	if {[objectType $id]=="q"} {return 1}
	return 0
}

proc isConcept {id} {
	if {[objectType $id]=="c"} {return 1}
	return 0
}

proc isEndState {id} {
	global plugin
	if {[isPrompt $id]} {
		return [expr (\$plugin($id,p_follows)=={} || \$plugin($id,p_endstate)==1)]
	} elseif {[isQuestion $id]} {
		return [expr (\$plugin($id,q_follows)=={} || \$plugin($id,q_endstate)==1)]
	} else {
		return 0
	}
}

proc isStartPrompt {id} {
	global plugin
	if {[isPrompt $id]} {
		if {[info exists plugin($id,p_start)]} {
			return [expr \$plugin($id,p_start)==1]
		}
	}
	return 0
}

proc isConnected {tag1 tag2} {
	# if $tag1 is empty, isConnected returns whether $tag2 is a welcome prompt
	# if $tag2 is empty, isConnected returns whether $tag2 is an end state
	global plugin
	
	if {$tag1==""} {return [isStartPrompt $tag2]}
	if {$tag2==""} {return [isEndState $tag1]}

	# check for always reachable target
	if {[isPrompt $tag2]} {
		if {[info exists plugin($tag2,p_reachable)] && $plugin($tag2,p_reachable)==1} {return 1}
	} else {
		if {[info exists plugin($tag2,q_reachable)] && $plugin($tag2,q_reachable)==1} {return 1}
	}

	# examine the follows list
	if {[isPrompt $tag1]} {set w p_follows} else {set w q_follows}
	if {[info exists plugin($tag1,$w)]} {
		return [expr [lsearch -exact $plugin($tag1,$w) $tag2]!=-1]
	} else {
		return 0
	}
}

proc calcPredecessors {id} {
	# return a list of id's having $id as follow up
	global plugin
	
	set ret {}
	foreach n [concat [allEntries P] [allEntries Q]] {
		if {[isConnected $n $id]} {lappend ret $n}
	}

	return [lsort -uniq $ret]
}

proc calcSuccessors {id} {
	# return a list of follow up id's
	global plugin

	if {[isEndState $id]} return {}
	set ret {}
	foreach n [concat [allEntries P] [allEntries Q]] {
		if {[isConnected $id $n]} {lappend ret $n}
	}

	return [lsort -uniq $ret]
}

proc calcUsedBy {c_id} {
	# return a list of questions using concept c_id
	global plugin

	if {$plugin($c_id,c_always)==1} {
		set ret [allEntries Q]
	} else {
		set ret {}
		foreach n [allEntries Q] {
			if {[lsearch -exact $plugin($n,q_concepts) $c_id]!=-1} {
				lappend ret $n
			}
		}
	}
	return [util::nodup $ret]
}

proc calcActiveConcepts {q_id} {
	# return a list of concepts used in q_id
	global plugin

	# add always active concepts to the hardcoded ones
	set ret $plugin($q_id,q_concepts)
	foreach n [allEntries C] {
		if {$plugin($n,c_always)==1} {
			lappend ret $n
		}
	}
	
	return [lsort -uniq $ret]
}

proc isAlwaysReachable {id} {
	global plugin

	if {[isPrompt $id]} {return [notempty $plugin($id,p_reachable)]}
	if {[isQuestion $id]} {return [notempty $plugin($id,q_reachable)]}
	return 0
}

proc promptExists {id} {
	global plugin
	return [info exists plugin($id,p_id)]
}

proc questionExists {id} {
	global plugin
	return [info exists plugin($id,q_id)]
}

proc conceptExists {id} {
	global plugin
	return [info exists plugin($id,c_id)]
}

proc sampleCallExists {id} {
	global plugin
	return [info exists plugin($id,s_id)]
}

proc objectExists {id} {
	global plugin
	return [info exists plugin($id,id)]
}

proc getStartPrompt {} {
	# returns the start prompt ID, or empty
	global plugin

	foreach e [allEntries P] {
		if {$plugin($e,p_start)==1} {return $e}
	}
	return ""
}

proc sampleCallWarnings {id} {
	# returns the warnings, counting
	# - uses a deleted object
	# - has Pnew or Qnew objects
	# - contains text changes vs the design
	# - uses a non existing connection
	global plugin

	set ret 0
	set warnings {}
	set last ""

	foreach turn $plugin($id,s_call) {
		set oid [lindex $turn 0]

		# check object & text
		if {![objectExists $oid]} {
			lappend warnings [res::Str ana_w_sc_notexisting $oid $id]
			set oid ""
			incr ret
		} elseif {[isPrompt $oid]} {
			if {[lindex $turn 1]!=$plugin($oid,p_prompt)} {
				lappend warnings [res::Str ana_w_sc_textchanged $oid p_prompt $id]
				incr ret
			}
		} else {
			if {[lindex $turn 2]!=$plugin($oid,[lindex $turn 1])} {
				lappend warnings [res::Str ana_w_sc_textchanged $oid [lindex $turn 1] $id]
				incr ret
			}
		}

		# check connection
		if {$last!="" && $oid!=""} {
			if {![isConnected $last $oid]} {
				lappend warnings [res::Str ana_w_sc_missingconn $last $oid $id]
				incr ret
			}
		}

		set last $oid
	}

	return [lsort -uniq $warnings]
}

proc startFile {file} {
	# ----------------------------
	# from: http://wiki.tcl.tk/557
	# ----------------------------
	
	# On Win95, even if there is a web browser installed, it cannot
	# open an internet address, only a local .html file.
	
	# Win98 doesn't like "/"
	if {[lindex [array get ::tcl_platform] 1]=="4.10"} {
	    regsub -all "/" $file "\\\\" file
	}
	# Substitute & with ^&
	# (Example: http://www.ideogramic.com?a=1&b=1 => http://www.ideogramic.com?a=1^&b=1
	#  Otherwise, it will only open http://www.ideogramic.com?a=1)
	regsub -all "&" $file "^&" file
	regsub -all "&" $file "^&" file
	# Open file
	eval exec [auto_execok start] \"\" [list $file] &
}
