# =============================================================================
# Wizard of Oz
# =============================================================================
#
# Copyright (c) 2001-09 Richard Breuer
#
# =============================================================================

#-------------------------------------------------------------------------- RES
# check tcl version
if {$tcl_version<"8.4"} {
  puts "FATAL ERROR:\n\nTcl/Tk must be at least version 8.4!"
  exit
}
# check tk availability
if {[info commands button]==""} {
  puts "FATAL ERROR:\n\nThis program requires wish!"
  exit
}

wm withdraw .

# since ActiveStateTCL 8.5, some packages must be installed first
catch {
	if {[package require tcl++]=="" && [package require Itcl]} {
		teacup install Itcl
	}
	if {[package require snack]==""} {
		teacup install snack
	}
	if {[package require tcom]==""} {
		teacup install tcom
	}
	if {[package require Img]==""} {
		teacup install Img
	}
}

# ----------------------------------------------------------------------- ITCL
if {[catch {package present tcl++ 2.3}]} {
  if {[catch {package require Itcl 3.0}]} {
		if {[catch {package require tcl++ 2.3}]} {
	    tk_messageBox -type ok -message "FATAL ERROR in YETI initialization: neither \[incr Tcl\] nor tcl++ available!"
			exit
		}
  } else {
		namespace import -force itcl::*
  }
}

# ----------------------------------------------------------------------- RBLIB
# set lib
set woz(RBLIB) ./src/rblib
if {[info exists env(RBLIB)]} {set woz(RBLIB) $env(RBLIB)}

# check lib
if {![file exists $woz(RBLIB)]} {
  if {[info exists env(RBLIB)]} {
    tk_messageBox -type ok -message "FATAL ERROR:\n\n%RBLIB% ('$woz(RBLIB)') does not exist!"
  } else {
    tk_messageBox -type ok -message "FATAL ERROR:\n\n\'$woz(RBLIB)' does not exist! Please set %RBLIB%."
  }
  exit
}
regsub -all {\\} $woz(RBLIB) {/} woz(RBLIB)

# ----------------------------------------------------------------------- SNACK
# WOz needs snack >=2.2 to replay sound files
if {[catch {set woz(snack) [package require snack]}]} {
	set woz(snack) ""
	tk_messageBox -type ok -message "WARNING:\n\nPackage 'snack' is not installed!\nWOz cannot play soundfiles."
} elseif {$woz(snack)<"2.2"} {
	set woz(snack) ""
	tk_messageBox -type ok -message "WARNING:\n\nPackage 'snack' is too old, v2.2 is required!\nWOz cannot play soundfiles."
}

# ------------------------------------------------------------------------- DIR
# get script root
set woz(DIR) "[file dirname [info script]]"
#set woz(DIR) "[pwd]"
#set woz(DIR) "."
if {$woz(DIR)==""} {
  # correct this if you want to source...
  set woz(DIR) .
}

#tk_messageBox -type ok -message "DIR is $woz(DIR)"

# check script root
if {![file exists $woz(DIR)/resource/woz.ini]} {
  tk_messageBox -type ok -message "FATAL ERROR:\n\nCannot determine script root directory!"
}

#-------------------------------------------------------------------------- RES
set woz(RES) $woz(DIR)/resource

#---------------------------------------------------------------------- Default
proc optExcDefault {} {
  global options
  
  set options(exc_nu) 5
  set options(exc_nr) 2
  set options(exc_tl) 1
  set options(exc_re) 6

	set options(sc_max_occurrences) 1
	set options(sc_ends_at_end) 1
	set options(sc_min_length) 1
	set options(sc_max_length) 999
	set options(sc_mandatory_states) {}
}

optExcDefault

#---------------------------------------------------------------- Splash Screen
proc splash {{ms 0}} {
    global woz
    update idletasks
    if {[winfo exists .x]} return
    toplevel .x -bd 3 -relief raised
    wm withdraw .x
    set sw [winfo screenwidth .]
    set sh [winfo screenheight .]
    image create photo "title" -file $woz(RES)/woz.gif
    wm overrideredirect .x 1
    label .x.l -image title -bd 1 -relief sunken
    frame .x.f
    label .x.f.a -bd 1 -relief raised -background yellow -text "[res::Str about] - [res::Str date]"
    button .x.f.b -command {catch {grab release .x; destroy .x}} -textvar label(close)
    pack .x.l -side top -expand 1 -fill both
    pack .x.f.a -side left -expand 1 -fill both
    pack .x.f.b -side left
    pack .x.f -side top -fill x
    set x [expr {($sw - [image width title])/2}]
    set y [expr {($sh - [image height title])/2}]
    wm geometry .x +$x+$y
    wm deiconify .x
    raise .x
    focus .x
    if {$ms==0} {
	    bind .x <Key-Return> {.x.f.b invoke}
	    bind .x <Key-Escape> {.x.f.b invoke}
    }
    update idletasks
    if {$ms>0} {
      after $ms {catch {destroy .x}}
    } else {
      grab .x
      tkwait window .x
    }
}

#========================================================================= MAIN
cd $woz(DIR)
source src/plug.tcl
source src/prj.tcl
source src/menu.tcl
source src/log.tcl
source src/dia.tcl
source src/win.tcl
source src/canvas.tcl
source src/play.tcl
source src/layout.tcl
source src/snapshot.tcl
source src/ops.tcl
source src/tools.tcl
source src/scall.tcl
source src/ylex_bnf2srgs.tcl
source src/yeti_bnf2srgs.tcl

source $woz(RBLIB)/res.tcl
source $woz(RBLIB)/ini.tcl
source $woz(RBLIB)/util.tcl
source $woz(RBLIB)/date.tcl
source $woz(RBLIB)/set.tcl
source $woz(RBLIB)/balloon.tcl
source $woz(RBLIB)/graf.tcl
source $woz(RBLIB)/replace.tcl
source $woz(RBLIB)/move.tcl

ini::Read $woz(RES)/woz.ini $woz(RES)/defaults.ini
res::Read $woz(RES)/[ini::Str files.resourceFile]

createCanvas
initCanvas

set woz(tcom) ""
set woz(sapi) ""
if {[ini::Str common.tts]==1} {
	# ----------------------------------------------------------------------- TCOM
	# WOz needs tcom >=3.7 to create TTS output
	if {[catch {set woz(tcom) [package require tcom]}]} {
		set woz(tcom) ""
		tk_messageBox -type ok -message "WARNING:\n\nPackage 'tcom' is not installed!\nWOz cannot play TTS prompts."
	} elseif {$woz(tcom)<"3.7"} {
		set woz(tcom) ""
		tk_messageBox -type ok -message "WARNING:\n\nPackage 'tcom' is too old, v2.2 is required!\nWOz cannot play TTS prompts."
	}
	
	# ----------------------------------------------------------------------- SAPI
	if {$woz(tcom)!=""} {
		if {[catch {set woz(sapi) [::tcom::ref createobject Sapi.SpVoice]}]} {
			set woz(sapi) ""
			tk_messageBox -type ok -message "WARNING:\n\nNo SAPI voice is installed!\nWOz cannot play TTS prompts."
		}
	}
}

# Windows, defaults, labels, colors, and baloon help
foreach n {ok cancel all none close apply default changed question prompt concept loaded \
           yes no append_p append_q barge_in endstate reachable vxml} {
  set label($n) [res::Str label_$n]
}
foreach n {create_header create_missing_obj create_new_obj create_new_connections create_new_concepts \
					 update_header update_calls	update_design do_nothing sync_header sync \
					 max_occurrences ends_at_end min_length max_length mandatory_states} {
  set label(sc_$n) [res::Str sc_label_$n]
}
foreach n {changed loaded bar} {
  balloon $widget(status,$n) [res::Str b_label_$n]
}
foreach n [array names widget label,c_*] {
	$widget($n) configure -background [ini::Str common.colorC]
}
foreach n [array names widget label,p_*] {
	$widget($n) configure -background [ini::Str common.colorP]
}
foreach n [array names widget label,q_*] {
	$widget($n) configure -background [ini::Str common.colorQ]
}

# get the default export directory
set woz(EXPDIR) [ini::Str files.expDir]

wm title $widget(winopt) [res::Str win_opt]
wm title $widget(property,p) [res::Str win_propertyp]
wm title $widget(property,q) [res::Str win_propertyq]
wm title $widget(property,c) [res::Str win_propertyc]
wm title $widget(property,o) [res::Str win_propertyo]
wm title $widget(property,s) [res::Str win_propertys]
wm title $widget(main) [res::Str win_main [res::Str no_project] ""]
menuCommand init

# inspired by http://wiki.tcl.tk/2267
wm protocol $widget(main) WM_DELETE_WINDOW {menuCommand file,exit}

# bindings for commands
bind $widget(main) <Control-O> {menuCommand file,open}
bind $widget(main) <Control-o> {menuCommand file,open}
bind $widget(main) <Control-N> {menuCommand file,new}
bind $widget(main) <Control-n> {menuCommand file,new}
bind $widget(main) <Control-S> {menuCommand file,save}
bind $widget(main) <Control-s> {menuCommand file,save}
bind $widget(main) <Control-M> {menuCommand file,merge}
bind $widget(main) <Control-m> {menuCommand file,merge}

bind $widget(main) <Alt-C> {menuCommand edit,concept}
bind $widget(main) <Alt-c> {menuCommand edit,concept}
bind $widget(main) <Alt-P> {menuCommand edit,prompt}
bind $widget(main) <Alt-p> {menuCommand edit,prompt}
bind $widget(main) <Alt-Q> {menuCommand edit,question}
bind $widget(main) <Alt-q> {menuCommand edit,question}

bind $widget(main) <F1> {menuCommand help,docs}
bind $widget(main) <F2> {menuCommand run,analyze}
bind $widget(main) <F5> {menuCommand view,refresh}
bind $widget(main) <F6> {menuCommand run,run}

image create photo "pic.p" -file $woz(RES)/icons/pic_p.gif
image create photo "pic.q" -file $woz(RES)/icons/pic_q.gif

image create photo s_delete   -file $woz(RES)/icons/delete.gif
image create photo s_up       -file $woz(RES)/icons/up.gif
image create photo s_down     -file $woz(RES)/icons/down.gif
image create photo s_append_p -file $woz(RES)/icons/p.gif
image create photo s_append_q -file $woz(RES)/icons/q.gif
image create photo s_undo     -file $woz(RES)/icons/undo.gif
image create photo s_redo     -file $woz(RES)/icons/redo.gif
image create photo s_undo_all -file $woz(RES)/icons/undo_all.gif
image create photo s_redo_all -file $woz(RES)/icons/redo_all.gif

$widget(s_append_p) configure -image s_append_p
$widget(s_append_q) configure -image s_append_q
$widget(s_undo)     configure -image s_undo
$widget(s_redo)     configure -image s_redo
$widget(s_undo_all) configure -image s_undo_all
$widget(s_redo_all) configure -image s_redo_all

image create photo "play" -file $woz(RES)/icons/play.gif
image create photo "playsmall" -file $woz(RES)/icons/playsmall.gif
foreach n {q_init q_nu1 q_nu2 q_nu3 q_nr1 q_nr2 q_nr3 q_tl1 q_tl2 q_tl3 q_ctxhelp p_prompt} {
	$widget(ls,$n) configure -image "play" -command "playPrompt $n"
}

set woz(win_choose) 	[res::Str win_chaudio]
set woz(win_entertts) [res::Str win_entertts]
set woz(wav_dir) 			[ini::Str files.wavDir]

splash 2500

# open project from the command line, if it exists
update
menuCommand autostart
